<?php

return [
    ':+1:' => '👍',
    ':-1:' => '👎',
    ':8ball:' => '🎱',
    ':100:' => '💯',
    ':1234:' => '🔢',
    ':ab:' => '🆎',
    ':abacus:' => '🧮',
    ':abc:' => '🔤',
    ':abcd:' => '🔡',
    ':accept:' => '🉑',
    ':accordion:' => '🪗',
    ':adhesive-bandage:' => '🩹',
    ':adult:' => '🧑',
    ':aerial-tramway:' => '🚡',
    ':airplane-arriving:' => '🛬',
    ':airplane-departure:' => '🛫',
    ':alarm-clock:' => '⏰',
    ':alien:' => '👽',
    ':ambulance:' => '🚑',
    ':amphora:' => '🏺',
    ':anatomical-heart:' => '🫀',
    ':anchor:' => '⚓',
    ':angel:' => '👼',
    ':anger:' => '💢',
    ':angry:' => '😠',
    ':anguished:' => '😧',
    ':ant:' => '🐜',
    ':apple:' => '🍎',
    ':aquarius:' => '♒',
    ':aries:' => '♈',
    ':arrow-double-down:' => '⏬',
    ':arrow-double-up:' => '⏫',
    ':arrow-down-small:' => '🔽',
    ':arrow-up-small:' => '🔼',
    ':arrows-clockwise:' => '🔃',
    ':arrows-counterclockwise:' => '🔄',
    ':art:' => '🎨',
    ':articulated-lorry:' => '🚛',
    ':astonished:' => '😲',
    ':athletic-shoe:' => '👟',
    ':atm:' => '🏧',
    ':auto-rickshaw:' => '🛺',
    ':avocado:' => '🥑',
    ':axe:' => '🪓',
    ':baby:' => '👶',
    ':baby-bottle:' => '🍼',
    ':baby-chick:' => '🐤',
    ':baby-symbol:' => '🚼',
    ':back:' => '🔙',
    ':bacon:' => '🥓',
    ':badger:' => '🦡',
    ':badminton-racquet-and-shuttlecock:' => '🏸',
    ':bagel:' => '🥯',
    ':baggage-claim:' => '🛄',
    ':baguette-bread:' => '🥖',
    ':ballet-shoes:' => '🩰',
    ':balloon:' => '🎈',
    ':bamboo:' => '🎍',
    ':banana:' => '🍌',
    ':banjo:' => '🪕',
    ':bank:' => '🏦',
    ':bar-chart:' => '📊',
    ':barber:' => '💈',
    ':baseball:' => '⚾',
    ':basket:' => '🧺',
    ':basketball:' => '🏀',
    ':bat:' => '🦇',
    ':bath:' => '🛀',
    ':bathtub:' => '🛁',
    ':battery:' => '🔋',
    ':beans:' => '🫘',
    ':bear:' => '🐻',
    ':bearded-person:' => '🧔',
    ':beaver:' => '🦫',
    ':bee:' => '🐝',
    ':beer:' => '🍺',
    ':beers:' => '🍻',
    ':beetle:' => '🪲',
    ':beginner:' => '🔰',
    ':bell:' => '🔔',
    ':bell-pepper:' => '🫑',
    ':bento:' => '🍱',
    ':beverage-box:' => '🧃',
    ':bicyclist:' => '🚴',
    ':bike:' => '🚲',
    ':bikini:' => '👙',
    ':billed-cap:' => '🧢',
    ':bird:' => '🐦',
    ':birthday:' => '🎂',
    ':bison:' => '🦬',
    ':biting-lip:' => '🫦',
    ':black-circle:' => '⚫',
    ':black-heart:' => '🖤',
    ':black-joker:' => '🃏',
    ':black-large-square:' => '⬛',
    ':black-medium-small-square:' => '◾',
    ':black-square-button:' => '🔲',
    ':blossom:' => '🌼',
    ':blowfish:' => '🐡',
    ':blue-book:' => '📘',
    ':blue-car:' => '🚙',
    ':blue-heart:' => '💙',
    ':blueberries:' => '🫐',
    ':blush:' => '😊',
    ':boar:' => '🐗',
    ':boat:' => '⛵',
    ':bomb:' => '💣',
    ':bone:' => '🦴',
    ':book:' => '📖',
    ':bookmark:' => '🔖',
    ':bookmark-tabs:' => '📑',
    ':books:' => '📚',
    ':boom:' => '💥',
    ':boomerang:' => '🪃',
    ':boot:' => '👢',
    ':bouquet:' => '💐',
    ':bow:' => '🙇',
    ':bow-and-arrow:' => '🏹',
    ':bowl-with-spoon:' => '🥣',
    ':bowling:' => '🎳',
    ':boxing-glove:' => '🥊',
    ':boy:' => '👦',
    ':brain:' => '🧠',
    ':bread:' => '🍞',
    ':breast-feeding:' => '🤱',
    ':bricks:' => '🧱',
    ':bride-with-veil:' => '👰‍♀',
    ':bridge-at-night:' => '🌉',
    ':briefcase:' => '💼',
    ':briefs:' => '🩲',
    ':broccoli:' => '🥦',
    ':broken-heart:' => '💔',
    ':broom:' => '🧹',
    ':brown-heart:' => '🤎',
    ':bubble-tea:' => '🧋',
    ':bubbles:' => '🫧',
    ':bucket:' => '🪣',
    ':bug:' => '🐛',
    ':bulb:' => '💡',
    ':bullettrain-front:' => '🚅',
    ':bullettrain-side:' => '🚄',
    ':burrito:' => '🌯',
    ':bus:' => '🚌',
    ':busstop:' => '🚏',
    ':bust-in-silhouette:' => '👤',
    ':busts-in-silhouette:' => '👥',
    ':butter:' => '🧈',
    ':butterfly:' => '🦋',
    ':cactus:' => '🌵',
    ':cake:' => '🍰',
    ':calendar:' => '📆',
    ':call-me-hand:' => '🤙',
    ':calling:' => '📲',
    ':camel:' => '🐫',
    ':camera:' => '📷',
    ':camera-with-flash:' => '📸',
    ':cancer:' => '♋',
    ':candy:' => '🍬',
    ':canned-food:' => '🥫',
    ':canoe:' => '🛶',
    ':capital-abcd:' => '🔠',
    ':capricorn:' => '♑',
    ':car:' => '🚗',
    ':card-index:' => '📇',
    ':carousel-horse:' => '🎠',
    ':carpentry-saw:' => '🪚',
    ':carrot:' => '🥕',
    ':cat:' => '🐱',
    ':cat2:' => '🐈',
    ':cd:' => '💿',
    ':chair:' => '🪑',
    ':champagne:' => '🍾',
    ':chart:' => '💹',
    ':chart-with-downwards-trend:' => '📉',
    ':chart-with-upwards-trend:' => '📈',
    ':checkered-flag:' => '🏁',
    ':cheese-wedge:' => '🧀',
    ':cherries:' => '🍒',
    ':cherry-blossom:' => '🌸',
    ':chestnut:' => '🌰',
    ':chicken:' => '🐔',
    ':child:' => '🧒',
    ':children-crossing:' => '🚸',
    ':chocolate-bar:' => '🍫',
    ':chopsticks:' => '🥢',
    ':christmas-tree:' => '🎄',
    ':church:' => '⛪',
    ':cinema:' => '🎦',
    ':circus-tent:' => '🎪',
    ':city-sunrise:' => '🌇',
    ':city-sunset:' => '🌆',
    ':cl:' => '🆑',
    ':clap:' => '👏',
    ':clapper:' => '🎬',
    ':clinking-glasses:' => '🥂',
    ':clipboard:' => '📋',
    ':clock1:' => '🕐',
    ':clock2:' => '🕑',
    ':clock3:' => '🕒',
    ':clock4:' => '🕓',
    ':clock5:' => '🕔',
    ':clock6:' => '🕕',
    ':clock7:' => '🕖',
    ':clock8:' => '🕗',
    ':clock9:' => '🕘',
    ':clock10:' => '🕙',
    ':clock11:' => '🕚',
    ':clock12:' => '🕛',
    ':clock130:' => '🕜',
    ':clock230:' => '🕝',
    ':clock330:' => '🕞',
    ':clock430:' => '🕟',
    ':clock530:' => '🕠',
    ':clock630:' => '🕡',
    ':clock730:' => '🕢',
    ':clock830:' => '🕣',
    ':clock930:' => '🕤',
    ':clock1030:' => '🕥',
    ':clock1130:' => '🕦',
    ':clock1230:' => '🕧',
    ':closed-book:' => '📕',
    ':closed-lock-with-key:' => '🔐',
    ':closed-umbrella:' => '🌂',
    ':clown-face:' => '🤡',
    ':coat:' => '🧥',
    ':cockroach:' => '🪳',
    ':cocktail:' => '🍸',
    ':coconut:' => '🥥',
    ':coffee:' => '☕',
    ':coin:' => '🪙',
    ':cold-face:' => '🥶',
    ':cold-sweat:' => '😰',
    ':collision:' => '💥',
    ':compass:' => '🧭',
    ':computer:' => '💻',
    ':confetti-ball:' => '🎊',
    ':confounded:' => '😖',
    ':confused:' => '😕',
    ':construction:' => '🚧',
    ':construction-worker:' => '👷',
    ':convenience-store:' => '🏪',
    ':cookie:' => '🍪',
    ':cooking:' => '🍳',
    ':cool:' => '🆒',
    ':cop:' => '👮',
    ':coral:' => '🪸',
    ':corn:' => '🌽',
    ':couple:' => '👫',
    ':couple-with-heart:' => '💑',
    ':couplekiss:' => '💏',
    ':cow:' => '🐮',
    ':cow2:' => '🐄',
    ':crab:' => '🦀',
    ':credit-card:' => '💳',
    ':crescent-moon:' => '🌙',
    ':cricket:' => '🦗',
    ':cricket-bat-and-ball:' => '🏏',
    ':crocodile:' => '🐊',
    ':croissant:' => '🥐',
    ':crossed-fingers:' => '🤞',
    ':crossed-flags:' => '🎌',
    ':crown:' => '👑',
    ':crutch:' => '🩼',
    ':cry:' => '😢',
    ':crying-cat-face:' => '😿',
    ':crystal-ball:' => '🔮',
    ':cucumber:' => '🥒',
    ':cup-with-straw:' => '🥤',
    ':cupcake:' => '🧁',
    ':cupid:' => '💘',
    ':curling-stone:' => '🥌',
    ':curly-loop:' => '➰',
    ':currency-exchange:' => '💱',
    ':curry:' => '🍛',
    ':custard:' => '🍮',
    ':customs:' => '🛃',
    ':cut-of-meat:' => '🥩',
    ':cyclone:' => '🌀',
    ':dancer:' => '💃',
    ':dancers:' => '👯',
    ':dango:' => '🍡',
    ':dart:' => '🎯',
    ':dash:' => '💨',
    ':date:' => '📅',
    ':deaf-person:' => '🧏',
    ':deciduous-tree:' => '🌳',
    ':deer:' => '🦌',
    ':department-store:' => '🏬',
    ':diamond-shape-with-a-dot-inside:' => '💠',
    ':disappointed:' => '😞',
    ':disappointed-relieved:' => '😥',
    ':disguised-face:' => '🥸',
    ':diving-mask:' => '🤿',
    ':diya-lamp:' => '🪔',
    ':dizzy:' => '💫',
    ':dizzy-face:' => '😵',
    ':dna:' => '🧬',
    ':do-not-litter:' => '🚯',
    ':dodo:' => '🦤',
    ':dog:' => '🐶',
    ':dog2:' => '🐕',
    ':dollar:' => '💵',
    ':dolls:' => '🎎',
    ':dolphin:' => '🐬',
    ':donkey:' => '🫏',
    ':door:' => '🚪',
    ':dotted-line-face:' => '🫥',
    ':doughnut:' => '🍩',
    ':dragon:' => '🐉',
    ':dragon-face:' => '🐲',
    ':dress:' => '👗',
    ':dromedary-camel:' => '🐪',
    ':drooling-face:' => '🤤',
    ':drop-of-blood:' => '🩸',
    ':droplet:' => '💧',
    ':drum-with-drumsticks:' => '🥁',
    ':duck:' => '🦆',
    ':dumpling:' => '🥟',
    ':dvd:' => '📀',
    ':e-mail:' => '📧',
    ':eagle:' => '🦅',
    ':ear:' => '👂',
    ':ear-of-rice:' => '🌾',
    ':ear-with-hearing-aid:' => '🦻',
    ':earth-africa:' => '🌍',
    ':earth-americas:' => '🌎',
    ':earth-asia:' => '🌏',
    ':egg:' => '🥚',
    ':eggplant:' => '🍆',
    ':electric-plug:' => '🔌',
    ':elephant:' => '🐘',
    ':elevator:' => '🛗',
    ':elf:' => '🧝',
    ':empty-nest:' => '🪹',
    ':end:' => '🔚',
    ':envelope-with-arrow:' => '📩',
    ':euro:' => '💶',
    ':european-castle:' => '🏰',
    ':european-post-office:' => '🏤',
    ':evergreen-tree:' => '🌲',
    ':exclamation:' => '❗',
    ':exploding-head:' => '🤯',
    ':expressionless:' => '😑',
    ':eyeglasses:' => '👓',
    ':eyes:' => '👀',
    ':face-holding-back-tears:' => '🥹',
    ':face-palm:' => '🤦',
    ':face-vomiting:' => '🤮',
    ':face-with-cowboy-hat:' => '🤠',
    ':face-with-diagonal-mouth:' => '🫤',
    ':face-with-finger-covering-closed-lips:' => '🤫',
    ':face-with-hand-over-mouth:' => '🤭',
    ':face-with-head-bandage:' => '🤕',
    ':face-with-monocle:' => '🧐',
    ':face-with-one-eyebrow-raised:' => '🤨',
    ':face-with-open-eyes-and-hand-over-mouth:' => '🫢',
    ':face-with-open-mouth-vomiting:' => '🤮',
    ':face-with-peeking-eye:' => '🫣',
    ':face-with-raised-eyebrow:' => '🤨',
    ':face-with-rolling-eyes:' => '🙄',
    ':face-with-symbols-on-mouth:' => '🤬',
    ':face-with-thermometer:' => '🤒',
    ':facepunch:' => '👊',
    ':factory:' => '🏭',
    ':fairy:' => '🧚',
    ':falafel:' => '🧆',
    ':fallen-leaf:' => '🍂',
    ':family:' => '👪',
    ':fast-forward:' => '⏩',
    ':fax:' => '📠',
    ':fearful:' => '😨',
    ':feather:' => '🪶',
    ':feet:' => '🐾',
    ':fencer:' => '🤺',
    ':ferris-wheel:' => '🎡',
    ':field-hockey-stick-and-ball:' => '🏑',
    ':file-folder:' => '📁',
    ':fire:' => '🔥',
    ':fire-engine:' => '🚒',
    ':fire-extinguisher:' => '🧯',
    ':firecracker:' => '🧨',
    ':fireworks:' => '🎆',
    ':first-place-medal:' => '🥇',
    ':first-quarter-moon:' => '🌓',
    ':first-quarter-moon-with-face:' => '🌛',
    ':fish:' => '🐟',
    ':fish-cake:' => '🍥',
    ':fishing-pole-and-fish:' => '🎣',
    ':fist:' => '✊',
    ':flags:' => '🎏',
    ':flamingo:' => '🦩',
    ':flashlight:' => '🔦',
    ':flatbread:' => '🫓',
    ':flipper:' => '🐬',
    ':floppy-disk:' => '💾',
    ':flower-playing-cards:' => '🎴',
    ':flushed:' => '😳',
    ':flute:' => '🪈',
    ':fly:' => '🪰',
    ':flying-disc:' => '🥏',
    ':flying-saucer:' => '🛸',
    ':foggy:' => '🌁',
    ':folding-hand-fan:' => '🪭',
    ':fondue:' => '🫕',
    ':foot:' => '🦶',
    ':football:' => '🏈',
    ':footprints:' => '👣',
    ':fork-and-knife:' => '🍴',
    ':fortune-cookie:' => '🥠',
    ':fountain:' => '⛲',
    ':four-leaf-clover:' => '🍀',
    ':fox-face:' => '🦊',
    ':free:' => '🆓',
    ':fried-egg:' => '🍳',
    ':fried-shrimp:' => '🍤',
    ':fries:' => '🍟',
    ':frog:' => '🐸',
    ':frowning:' => '😦',
    ':fuelpump:' => '⛽',
    ':full-moon:' => '🌕',
    ':full-moon-with-face:' => '🌝',
    ':game-die:' => '🎲',
    ':garlic:' => '🧄',
    ':gem:' => '💎',
    ':gemini:' => '♊',
    ':genie:' => '🧞',
    ':ghost:' => '👻',
    ':gift:' => '🎁',
    ':gift-heart:' => '💝',
    ':ginger-root:' => '🫚',
    ':giraffe-face:' => '🦒',
    ':girl:' => '👧',
    ':glass-of-milk:' => '🥛',
    ':globe-with-meridians:' => '🌐',
    ':gloves:' => '🧤',
    ':goal-net:' => '🥅',
    ':goat:' => '🐐',
    ':goggles:' => '🥽',
    ':golf:' => '⛳',
    ':goose:' => '🪿',
    ':gorilla:' => '🦍',
    ':grapes:' => '🍇',
    ':green-apple:' => '🍏',
    ':green-book:' => '📗',
    ':green-heart:' => '💚',
    ':green-salad:' => '🥗',
    ':grey-exclamation:' => '❕',
    ':grey-heart:' => '🩶',
    ':grey-question:' => '❔',
    ':grimacing:' => '😬',
    ':grin:' => '😁',
    ':grinning:' => '😀',
    ':grinning-face-with-one-large-and-one-small-eye:' => '🤪',
    ':grinning-face-with-star-eyes:' => '🤩',
    ':guardsman:' => '💂‍♂',
    ':guide-dog:' => '🦮',
    ':guitar:' => '🎸',
    ':gun:' => '🔫',
    ':hair-pick:' => '🪮',
    ':haircut:' => '💇',
    ':hamburger:' => '🍔',
    ':hammer:' => '🔨',
    ':hamsa:' => '🪬',
    ':hamster:' => '🐹',
    ':hand:' => '✋',
    ':hand-with-index-and-middle-fingers-crossed:' => '🤞',
    ':hand-with-index-finger-and-thumb-crossed:' => '🫰',
    ':handbag:' => '👜',
    ':handball:' => '🤾',
    ':handshake:' => '🤝',
    ':hankey:' => '💩',
    ':hatched-chick:' => '🐥',
    ':hatching-chick:' => '🐣',
    ':headphones:' => '🎧',
    ':headstone:' => '🪦',
    ':hear-no-evil:' => '🙉',
    ':heart-decoration:' => '💟',
    ':heart-eyes:' => '😍',
    ':heart-eyes-cat:' => '😻',
    ':heart-hands:' => '🫶',
    ':heartbeat:' => '💓',
    ':heartpulse:' => '💗',
    ':heavy-division-sign:' => '➗',
    ':heavy-dollar-sign:' => '💲',
    ':heavy-equals-sign:' => '🟰',
    ':heavy-exclamation-mark:' => '❗',
    ':heavy-minus-sign:' => '➖',
    ':heavy-plus-sign:' => '➕',
    ':hedgehog:' => '🦔',
    ':helicopter:' => '🚁',
    ':herb:' => '🌿',
    ':hibiscus:' => '🌺',
    ':high-brightness:' => '🔆',
    ':high-heel:' => '👠',
    ':hiking-boot:' => '🥾',
    ':hindu-temple:' => '🛕',
    ':hippopotamus:' => '🦛',
    ':hocho:' => '🔪',
    ':honey-pot:' => '🍯',
    ':honeybee:' => '🐝',
    ':hook:' => '🪝',
    ':horse:' => '🐴',
    ':horse-racing:' => '🏇',
    ':hospital:' => '🏥',
    ':hot-face:' => '🥵',
    ':hotdog:' => '🌭',
    ':hotel:' => '🏨',
    ':hourglass:' => '⌛',
    ':hourglass-flowing-sand:' => '⏳',
    ':house:' => '🏠',
    ':house-with-garden:' => '🏡',
    ':hugging-face:' => '🤗',
    ':hushed:' => '😯',
    ':hut:' => '🛖',
    ':hyacinth:' => '🪻',
    ':i-love-you-hand-sign:' => '🤟',
    ':ice-cream:' => '🍨',
    ':ice-cube:' => '🧊',
    ':ice-hockey-stick-and-puck:' => '🏒',
    ':icecream:' => '🍦',
    ':id:' => '🆔',
    ':identification-card:' => '🪪',
    ':ideograph-advantage:' => '🉐',
    ':imp:' => '👿',
    ':inbox-tray:' => '📥',
    ':incoming-envelope:' => '📨',
    ':index-pointing-at-the-viewer:' => '🫵',
    ':information-desk-person:' => '💁',
    ':innocent:' => '😇',
    ':iphone:' => '📱',
    ':izakaya-lantern:' => '🏮',
    ':jack-o-lantern:' => '🎃',
    ':japan:' => '🗾',
    ':japanese-castle:' => '🏯',
    ':japanese-goblin:' => '👺',
    ':japanese-ogre:' => '👹',
    ':jar:' => '🫙',
    ':jeans:' => '👖',
    ':jellyfish:' => '🪼',
    ':jigsaw:' => '🧩',
    ':joy:' => '😂',
    ':joy-cat:' => '😹',
    ':juggling:' => '🤹',
    ':kaaba:' => '🕋',
    ':kangaroo:' => '🦘',
    ':key:' => '🔑',
    ':keycap-ten:' => '🔟',
    ':khanda:' => '🪯',
    ':kimono:' => '👘',
    ':kiss:' => '💋',
    ':kissing:' => '😗',
    ':kissing-cat:' => '😽',
    ':kissing-closed-eyes:' => '😚',
    ':kissing-heart:' => '😘',
    ':kissing-smiling-eyes:' => '😙',
    ':kite:' => '🪁',
    ':kiwifruit:' => '🥝',
    ':kneeling-person:' => '🧎',
    ':knife:' => '🔪',
    ':knot:' => '🪢',
    ':koala:' => '🐨',
    ':koko:' => '🈁',
    ':lab-coat:' => '🥼',
    ':lacrosse:' => '🥍',
    ':ladder:' => '🪜',
    ':lady-beetle:' => '🐞',
    ':ladybug:' => '🐞',
    ':lantern:' => '🏮',
    ':large-blue-circle:' => '🔵',
    ':large-blue-diamond:' => '🔷',
    ':large-blue-square:' => '🟦',
    ':large-brown-circle:' => '🟤',
    ':large-brown-square:' => '🟫',
    ':large-green-circle:' => '🟢',
    ':large-green-square:' => '🟩',
    ':large-orange-circle:' => '🟠',
    ':large-orange-diamond:' => '🔶',
    ':large-orange-square:' => '🟧',
    ':large-purple-circle:' => '🟣',
    ':large-purple-square:' => '🟪',
    ':large-red-square:' => '🟥',
    ':large-yellow-circle:' => '🟡',
    ':large-yellow-square:' => '🟨',
    ':last-quarter-moon:' => '🌗',
    ':last-quarter-moon-with-face:' => '🌜',
    ':laughing:' => '😆',
    ':leafy-green:' => '🥬',
    ':leaves:' => '🍃',
    ':ledger:' => '📒',
    ':left-facing-fist:' => '🤛',
    ':left-luggage:' => '🛅',
    ':leftwards-hand:' => '🫲',
    ':leftwards-pushing-hand:' => '🫷',
    ':leg:' => '🦵',
    ':lemon:' => '🍋',
    ':leo:' => '♌',
    ':leopard:' => '🐆',
    ':libra:' => '♎',
    ':light-blue-heart:' => '🩵',
    ':light-rail:' => '🚈',
    ':link:' => '🔗',
    ':lion-face:' => '🦁',
    ':lips:' => '👄',
    ':lipstick:' => '💄',
    ':lizard:' => '🦎',
    ':llama:' => '🦙',
    ':lobster:' => '🦞',
    ':lock:' => '🔒',
    ':lock-with-ink-pen:' => '🔏',
    ':lollipop:' => '🍭',
    ':long-drum:' => '🪘',
    ':loop:' => '➿',
    ':lotion-bottle:' => '🧴',
    ':lotus:' => '🪷',
    ':loud-sound:' => '🔊',
    ':loudspeaker:' => '📢',
    ':love-hotel:' => '🏩',
    ':love-letter:' => '💌',
    ':low-battery:' => '🪫',
    ':low-brightness:' => '🔅',
    ':luggage:' => '🧳',
    ':lungs:' => '🫁',
    ':lying-face:' => '🤥',
    ':mag:' => '🔍',
    ':mag-right:' => '🔎',
    ':mage:' => '🧙',
    ':magic-wand:' => '🪄',
    ':magnet:' => '🧲',
    ':mahjong:' => '🀄',
    ':mailbox:' => '📫',
    ':mailbox-closed:' => '📪',
    ':mailbox-with-mail:' => '📬',
    ':mailbox-with-no-mail:' => '📭',
    ':mammoth:' => '🦣',
    ':man:' => '👨',
    ':man-and-woman-holding-hands:' => '👫',
    ':man-dancing:' => '🕺',
    ':man-with-gua-pi-mao:' => '👲',
    ':man-with-turban:' => '👳‍♂',
    ':mango:' => '🥭',
    ':mans-shoe:' => '👞',
    ':manual-wheelchair:' => '🦽',
    ':maple-leaf:' => '🍁',
    ':maracas:' => '🪇',
    ':martial-arts-uniform:' => '🥋',
    ':mask:' => '😷',
    ':massage:' => '💆',
    ':mate-drink:' => '🧉',
    ':meat-on-bone:' => '🍖',
    ':mechanical-arm:' => '🦾',
    ':mechanical-leg:' => '🦿',
    ':mega:' => '📣',
    ':melon:' => '🍈',
    ':melting-face:' => '🫠',
    ':memo:' => '📝',
    ':men-holding-hands:' => '👬',
    ':menorah-with-nine-branches:' => '🕎',
    ':mens:' => '🚹',
    ':merperson:' => '🧜',
    ':metro:' => '🚇',
    ':microbe:' => '🦠',
    ':microphone:' => '🎤',
    ':microscope:' => '🔬',
    ':middle-finger:' => '🖕',
    ':military-helmet:' => '🪖',
    ':milky-way:' => '🌌',
    ':minibus:' => '🚐',
    ':minidisc:' => '💽',
    ':mirror:' => '🪞',
    ':mirror-ball:' => '🪩',
    ':mobile-phone-off:' => '📴',
    ':money-mouth-face:' => '🤑',
    ':money-with-wings:' => '💸',
    ':moneybag:' => '💰',
    ':monkey:' => '🐒',
    ':monkey-face:' => '🐵',
    ':monorail:' => '🚝',
    ':moon:' => '🌔',
    ':moon-cake:' => '🥮',
    ':moose:' => '🫎',
    ':mortar-board:' => '🎓',
    ':mosque:' => '🕌',
    ':mosquito:' => '🦟',
    ':mother-christmas:' => '🤶',
    ':motor-scooter:' => '🛵',
    ':motorized-wheelchair:' => '🦼',
    ':mount-fuji:' => '🗻',
    ':mountain-bicyclist:' => '🚵',
    ':mountain-cableway:' => '🚠',
    ':mountain-railway:' => '🚞',
    ':mouse:' => '🐭',
    ':mouse-trap:' => '🪤',
    ':mouse2:' => '🐁',
    ':movie-camera:' => '🎥',
    ':moyai:' => '🗿',
    ':mrs-claus:' => '🤶',
    ':muscle:' => '💪',
    ':mushroom:' => '🍄',
    ':musical-keyboard:' => '🎹',
    ':musical-note:' => '🎵',
    ':musical-score:' => '🎼',
    ':mute:' => '🔇',
    ':nail-care:' => '💅',
    ':name-badge:' => '📛',
    ':nauseated-face:' => '🤢',
    ':nazar-amulet:' => '🧿',
    ':necktie:' => '👔',
    ':negative-squared-cross-mark:' => '❎',
    ':nerd-face:' => '🤓',
    ':nest-with-eggs:' => '🪺',
    ':nesting-dolls:' => '🪆',
    ':neutral-face:' => '😐',
    ':new:' => '🆕',
    ':new-moon:' => '🌑',
    ':new-moon-with-face:' => '🌚',
    ':newspaper:' => '📰',
    ':ng:' => '🆖',
    ':night-with-stars:' => '🌃',
    ':ninja:' => '🥷',
    ':no-bell:' => '🔕',
    ':no-bicycles:' => '🚳',
    ':no-entry:' => '⛔',
    ':no-entry-sign:' => '🚫',
    ':no-good:' => '🙅',
    ':no-mobile-phones:' => '📵',
    ':no-mouth:' => '😶',
    ':no-pedestrians:' => '🚷',
    ':no-smoking:' => '🚭',
    ':non-potable-water:' => '🚱',
    ':nose:' => '👃',
    ':notebook:' => '📓',
    ':notebook-with-decorative-cover:' => '📔',
    ':notes:' => '🎶',
    ':nut-and-bolt:' => '🔩',
    ':o:' => '⭕',
    ':ocean:' => '🌊',
    ':octagonal-sign:' => '🛑',
    ':octopus:' => '🐙',
    ':oden:' => '🍢',
    ':office:' => '🏢',
    ':ok:' => '🆗',
    ':ok-hand:' => '👌',
    ':ok-woman:' => '🙆‍♀',
    ':older-adult:' => '🧓',
    ':older-man:' => '👴',
    ':older-woman:' => '👵',
    ':olive:' => '🫒',
    ':on:' => '🔛',
    ':oncoming-automobile:' => '🚘',
    ':oncoming-bus:' => '🚍',
    ':oncoming-police-car:' => '🚔',
    ':oncoming-taxi:' => '🚖',
    ':one-piece-swimsuit:' => '🩱',
    ':onion:' => '🧅',
    ':open-book:' => '📖',
    ':open-file-folder:' => '📂',
    ':open-hands:' => '👐',
    ':open-mouth:' => '😮',
    ':ophiuchus:' => '⛎',
    ':orange-book:' => '📙',
    ':orange-heart:' => '🧡',
    ':orangutan:' => '🦧',
    ':otter:' => '🦦',
    ':outbox-tray:' => '📤',
    ':owl:' => '🦉',
    ':ox:' => '🐂',
    ':oyster:' => '🦪',
    ':package:' => '📦',
    ':page-facing-up:' => '📄',
    ':page-with-curl:' => '📃',
    ':pager:' => '📟',
    ':palm-down-hand:' => '🫳',
    ':palm-tree:' => '🌴',
    ':palm-up-hand:' => '🫴',
    ':palms-up-together:' => '🤲',
    ':pancakes:' => '🥞',
    ':panda-face:' => '🐼',
    ':paperclip:' => '📎',
    ':parachute:' => '🪂',
    ':parrot:' => '🦜',
    ':partly-sunny:' => '⛅',
    ':partying-face:' => '🥳',
    ':passport-control:' => '🛂',
    ':paw-prints:' => '🐾',
    ':pea-pod:' => '🫛',
    ':peach:' => '🍑',
    ':peacock:' => '🦚',
    ':peanuts:' => '🥜',
    ':pear:' => '🍐',
    ':pencil:' => '📝',
    ':penguin:' => '🐧',
    ':pensive:' => '😔',
    ':people-hugging:' => '🫂',
    ':performing-arts:' => '🎭',
    ':persevere:' => '😣',
    ':person-climbing:' => '🧗',
    ':person-doing-cartwheel:' => '🤸',
    ':person-frowning:' => '🙍',
    ':person-in-lotus-position:' => '🧘',
    ':person-in-steamy-room:' => '🧖',
    ':person-in-tuxedo:' => '🤵',
    ':person-with-blond-hair:' => '👱',
    ':person-with-crown:' => '🫅',
    ':person-with-headscarf:' => '🧕',
    ':person-with-pouting-face:' => '🙎',
    ':petri-dish:' => '🧫',
    ':pickup-truck:' => '🛻',
    ':pie:' => '🥧',
    ':pig:' => '🐷',
    ':pig-nose:' => '🐽',
    ':pig2:' => '🐖',
    ':pill:' => '💊',
    ':pinata:' => '🪅',
    ':pinched-fingers:' => '🤌',
    ':pinching-hand:' => '🤏',
    ':pineapple:' => '🍍',
    ':pink-heart:' => '🩷',
    ':pisces:' => '♓',
    ':pizza:' => '🍕',
    ':placard:' => '🪧',
    ':place-of-worship:' => '🛐',
    ':playground-slide:' => '🛝',
    ':pleading-face:' => '🥺',
    ':plunger:' => '🪠',
    ':point-down:' => '👇',
    ':point-left:' => '👈',
    ':point-right:' => '👉',
    ':point-up-2:' => '👆',
    ':police-car:' => '🚓',
    ':poodle:' => '🐩',
    ':poop:' => '💩',
    ':popcorn:' => '🍿',
    ':post-office:' => '🏣',
    ':postal-horn:' => '📯',
    ':postbox:' => '📮',
    ':potable-water:' => '🚰',
    ':potato:' => '🥔',
    ':potted-plant:' => '🪴',
    ':pouch:' => '👝',
    ':poultry-leg:' => '🍗',
    ':pound:' => '💷',
    ':pouring-liquid:' => '🫗',
    ':pouting-cat:' => '😾',
    ':pray:' => '🙏',
    ':prayer-beads:' => '📿',
    ':pregnant-man:' => '🫃',
    ':pregnant-person:' => '🫄',
    ':pregnant-woman:' => '🤰',
    ':pretzel:' => '🥨',
    ':prince:' => '🤴',
    ':princess:' => '👸',
    ':probing-cane:' => '🦯',
    ':punch:' => '👊',
    ':purple-heart:' => '💜',
    ':purse:' => '👛',
    ':pushpin:' => '📌',
    ':put-litter-in-its-place:' => '🚮',
    ':question:' => '❓',
    ':rabbit:' => '🐰',
    ':rabbit2:' => '🐇',
    ':raccoon:' => '🦝',
    ':racehorse:' => '🐎',
    ':radio:' => '📻',
    ':radio-button:' => '🔘',
    ':rage:' => '😡',
    ':railway-car:' => '🚃',
    ':rainbow:' => '🌈',
    ':raised-back-of-hand:' => '🤚',
    ':raised-hand:' => '✋',
    ':raised-hands:' => '🙌',
    ':raising-hand:' => '🙋',
    ':ram:' => '🐏',
    ':ramen:' => '🍜',
    ':rat:' => '🐀',
    ':razor:' => '🪒',
    ':receipt:' => '🧾',
    ':red-car:' => '🚗',
    ':red-circle:' => '🔴',
    ':red-envelope:' => '🧧',
    ':relieved:' => '😌',
    ':repeat:' => '🔁',
    ':repeat-one:' => '🔂',
    ':restroom:' => '🚻',
    ':reversed-hand-with-middle-finger-extended:' => '🖕',
    ':revolving-hearts:' => '💞',
    ':rewind:' => '⏪',
    ':rhinoceros:' => '🦏',
    ':ribbon:' => '🎀',
    ':rice:' => '🍚',
    ':rice-ball:' => '🍙',
    ':rice-cracker:' => '🍘',
    ':rice-scene:' => '🎑',
    ':right-facing-fist:' => '🤜',
    ':rightwards-hand:' => '🫱',
    ':rightwards-pushing-hand:' => '🫸',
    ':ring:' => '💍',
    ':ring-buoy:' => '🛟',
    ':ringed-planet:' => '🪐',
    ':robot-face:' => '🤖',
    ':rock:' => '🪨',
    ':rocket:' => '🚀',
    ':roll-of-paper:' => '🧻',
    ':roller-coaster:' => '🎢',
    ':roller-skate:' => '🛼',
    ':rolling-on-the-floor-laughing:' => '🤣',
    ':rooster:' => '🐓',
    ':rose:' => '🌹',
    ':rotating-light:' => '🚨',
    ':round-pushpin:' => '📍',
    ':rowboat:' => '🚣',
    ':rugby-football:' => '🏉',
    ':runner:' => '🏃',
    ':running:' => '🏃',
    ':running-shirt-with-sash:' => '🎽',
    ':safety-pin:' => '🧷',
    ':safety-vest:' => '🦺',
    ':sagittarius:' => '♐',
    ':sailboat:' => '⛵',
    ':sake:' => '🍶',
    ':salt:' => '🧂',
    ':saluting-face:' => '🫡',
    ':sandal:' => '👡',
    ':sandwich:' => '🥪',
    ':santa:' => '🎅',
    ':sari:' => '🥻',
    ':satellite-antenna:' => '📡',
    ':satisfied:' => '😆',
    ':sauropod:' => '🦕',
    ':saxophone:' => '🎷',
    ':scarf:' => '🧣',
    ':school:' => '🏫',
    ':school-satchel:' => '🎒',
    ':scooter:' => '🛴',
    ':scorpion:' => '🦂',
    ':scorpius:' => '♏',
    ':scream:' => '😱',
    ':scream-cat:' => '🙀',
    ':screwdriver:' => '🪛',
    ':scroll:' => '📜',
    ':seal:' => '🦭',
    ':seat:' => '💺',
    ':second-place-medal:' => '🥈',
    ':see-no-evil:' => '🙈',
    ':seedling:' => '🌱',
    ':selfie:' => '🤳',
    ':serious-face-with-symbols-covering-mouth:' => '🤬',
    ':sewing-needle:' => '🪡',
    ':shaking-face:' => '🫨',
    ':shallow-pan-of-food:' => '🥘',
    ':shark:' => '🦈',
    ':shaved-ice:' => '🍧',
    ':sheep:' => '🐑',
    ':shell:' => '🐚',
    ':ship:' => '🚢',
    ':shirt:' => '👕',
    ':shit:' => '💩',
    ':shocked-face-with-exploding-head:' => '🤯',
    ':shoe:' => '👞',
    ':shopping-trolley:' => '🛒',
    ':shorts:' => '🩳',
    ':shower:' => '🚿',
    ':shrimp:' => '🦐',
    ':shrug:' => '🤷',
    ':shushing-face:' => '🤫',
    ':sign-of-the-horns:' => '🤘',
    ':signal-strength:' => '📶',
    ':six-pointed-star:' => '🔯',
    ':skateboard:' => '🛹',
    ':ski:' => '🎿',
    ':skin-tone-2:' => '🏻',
    ':skin-tone-3:' => '🏼',
    ':skin-tone-4:' => '🏽',
    ':skin-tone-5:' => '🏾',
    ':skin-tone-6:' => '🏿',
    ':skull:' => '💀',
    ':skunk:' => '🦨',
    ':sled:' => '🛷',
    ':sleeping:' => '😴',
    ':sleeping-accommodation:' => '🛌',
    ':sleepy:' => '😪',
    ':slightly-frowning-face:' => '🙁',
    ':slightly-smiling-face:' => '🙂',
    ':slot-machine:' => '🎰',
    ':sloth:' => '🦥',
    ':small-blue-diamond:' => '🔹',
    ':small-orange-diamond:' => '🔸',
    ':small-red-triangle:' => '🔺',
    ':small-red-triangle-down:' => '🔻',
    ':smile:' => '😄',
    ':smile-cat:' => '😸',
    ':smiley:' => '😃',
    ':smiley-cat:' => '😺',
    ':smiling-face-with-3-hearts:' => '🥰',
    ':smiling-face-with-smiling-eyes-and-hand-covering-mouth:' => '🤭',
    ':smiling-face-with-tear:' => '🥲',
    ':smiling-imp:' => '😈',
    ':smirk:' => '😏',
    ':smirk-cat:' => '😼',
    ':smoking:' => '🚬',
    ':snail:' => '🐌',
    ':snake:' => '🐍',
    ':sneezing-face:' => '🤧',
    ':snowboarder:' => '🏂',
    ':snowman-without-snow:' => '⛄',
    ':soap:' => '🧼',
    ':sob:' => '😭',
    ':soccer:' => '⚽',
    ':socks:' => '🧦',
    ':softball:' => '🥎',
    ':soon:' => '🔜',
    ':sos:' => '🆘',
    ':sound:' => '🔉',
    ':space-invader:' => '👾',
    ':spaghetti:' => '🍝',
    ':sparkler:' => '🎇',
    ':sparkles:' => '✨',
    ':sparkling-heart:' => '💖',
    ':speak-no-evil:' => '🙊',
    ':speaker:' => '🔈',
    ':speech-balloon:' => '💬',
    ':speedboat:' => '🚤',
    ':spock-hand:' => '🖖',
    ':sponge:' => '🧽',
    ':spoon:' => '🥄',
    ':sports-medal:' => '🏅',
    ':squid:' => '🦑',
    ':standing-person:' => '🧍',
    ':star:' => '⭐',
    ':star-struck:' => '🤩',
    ':star2:' => '🌟',
    ':stars:' => '🌠',
    ':station:' => '🚉',
    ':statue-of-liberty:' => '🗽',
    ':steam-locomotive:' => '🚂',
    ':stethoscope:' => '🩺',
    ':stew:' => '🍲',
    ':straight-ruler:' => '📏',
    ':strawberry:' => '🍓',
    ':stuck-out-tongue:' => '😛',
    ':stuck-out-tongue-closed-eyes:' => '😝',
    ':stuck-out-tongue-winking-eye:' => '😜',
    ':stuffed-flatbread:' => '🥙',
    ':sun-with-face:' => '🌞',
    ':sunflower:' => '🌻',
    ':sunglasses:' => '😎',
    ':sunrise:' => '🌅',
    ':sunrise-over-mountains:' => '🌄',
    ':superhero:' => '🦸',
    ':supervillain:' => '🦹',
    ':surfer:' => '🏄',
    ':sushi:' => '🍣',
    ':suspension-railway:' => '🚟',
    ':swan:' => '🦢',
    ':sweat:' => '😓',
    ':sweat-drops:' => '💦',
    ':sweat-smile:' => '😅',
    ':sweet-potato:' => '🍠',
    ':swimmer:' => '🏊',
    ':symbols:' => '🔣',
    ':synagogue:' => '🕍',
    ':syringe:' => '💉',
    ':t-rex:' => '🦖',
    ':table-tennis-paddle-and-ball:' => '🏓',
    ':taco:' => '🌮',
    ':tada:' => '🎉',
    ':takeout-box:' => '🥡',
    ':tamale:' => '🫔',
    ':tanabata-tree:' => '🎋',
    ':tangerine:' => '🍊',
    ':taurus:' => '♉',
    ':taxi:' => '🚕',
    ':tea:' => '🍵',
    ':teapot:' => '🫖',
    ':teddy-bear:' => '🧸',
    ':telephone-receiver:' => '📞',
    ':telescope:' => '🔭',
    ':tennis:' => '🎾',
    ':tent:' => '⛺',
    ':test-tube:' => '🧪',
    ':the-horns:' => '🤘',
    ':thinking-face:' => '🤔',
    ':third-place-medal:' => '🥉',
    ':thong-sandal:' => '🩴',
    ':thought-balloon:' => '💭',
    ':thread:' => '🧵',
    ':thumbsdown:' => '👎',
    ':thumbsup:' => '👍',
    ':ticket:' => '🎫',
    ':tiger:' => '🐯',
    ':tiger2:' => '🐅',
    ':tired-face:' => '😫',
    ':toilet:' => '🚽',
    ':tokyo-tower:' => '🗼',
    ':tomato:' => '🍅',
    ':tongue:' => '👅',
    ':toolbox:' => '🧰',
    ':tooth:' => '🦷',
    ':toothbrush:' => '🪥',
    ':top:' => '🔝',
    ':tophat:' => '🎩',
    ':tractor:' => '🚜',
    ':traffic-light:' => '🚥',
    ':train:' => '🚋',
    ':train2:' => '🚆',
    ':tram:' => '🚊',
    ':triangular-flag-on-post:' => '🚩',
    ':triangular-ruler:' => '📐',
    ':trident:' => '🔱',
    ':triumph:' => '😤',
    ':troll:' => '🧌',
    ':trolleybus:' => '🚎',
    ':trophy:' => '🏆',
    ':tropical-drink:' => '🍹',
    ':tropical-fish:' => '🐠',
    ':truck:' => '🚚',
    ':trumpet:' => '🎺',
    ':tshirt:' => '👕',
    ':tulip:' => '🌷',
    ':tumbler-glass:' => '🥃',
    ':turkey:' => '🦃',
    ':turtle:' => '🐢',
    ':tv:' => '📺',
    ':twisted-rightwards-arrows:' => '🔀',
    ':two-hearts:' => '💕',
    ':two-men-holding-hands:' => '👬',
    ':two-women-holding-hands:' => '👭',
    ':u6e80:' => '🈵',
    ':u7a7a:' => '🈳',
    ':u55b6:' => '🈺',
    ':u5272:' => '🈹',
    ':u5408:' => '🈴',
    ':u6307:' => '🈯',
    ':u6709:' => '🈶',
    ':u7121:' => '🈚',
    ':u7533:' => '🈸',
    ':u7981:' => '🈲',
    ':umbrella-with-rain-drops:' => '☔',
    ':unamused:' => '😒',
    ':underage:' => '🔞',
    ':unicorn-face:' => '🦄',
    ':unlock:' => '🔓',
    ':up:' => '🆙',
    ':upside-down-face:' => '🙃',
    ':vampire:' => '🧛',
    ':vertical-traffic-light:' => '🚦',
    ':vhs:' => '📼',
    ':vibration-mode:' => '📳',
    ':video-camera:' => '📹',
    ':video-game:' => '🎮',
    ':violin:' => '🎻',
    ':virgo:' => '♍',
    ':volcano:' => '🌋',
    ':volleyball:' => '🏐',
    ':vs:' => '🆚',
    ':waffle:' => '🧇',
    ':walking:' => '🚶',
    ':waning-crescent-moon:' => '🌘',
    ':waning-gibbous-moon:' => '🌖',
    ':watch:' => '⌚',
    ':water-buffalo:' => '🐃',
    ':water-polo:' => '🤽',
    ':watermelon:' => '🍉',
    ':wave:' => '👋',
    ':waving-black-flag:' => '🏴',
    ':waxing-crescent-moon:' => '🌒',
    ':waxing-gibbous-moon:' => '🌔',
    ':wc:' => '🚾',
    ':weary:' => '😩',
    ':wedding:' => '💒',
    ':whale:' => '🐳',
    ':whale2:' => '🐋',
    ':wheel:' => '🛞',
    ':wheelchair:' => '♿',
    ':white-check-mark:' => '✅',
    ':white-circle:' => '⚪',
    ':white-flower:' => '💮',
    ':white-heart:' => '🤍',
    ':white-large-square:' => '⬜',
    ':white-medium-small-square:' => '◽',
    ':white-square-button:' => '🔳',
    ':wilted-flower:' => '🥀',
    ':wind-chime:' => '🎐',
    ':window:' => '🪟',
    ':wine-glass:' => '🍷',
    ':wing:' => '🪽',
    ':wink:' => '😉',
    ':wireless:' => '🛜',
    ':wolf:' => '🐺',
    ':woman:' => '👩',
    ':woman-and-man-holding-hands:' => '👫',
    ':womans-clothes:' => '👚',
    ':womans-flat-shoe:' => '🥿',
    ':womans-hat:' => '👒',
    ':women-holding-hands:' => '👭',
    ':womens:' => '🚺',
    ':wood:' => '🪵',
    ':woozy-face:' => '🥴',
    ':worm:' => '🪱',
    ':worried:' => '😟',
    ':wrench:' => '🔧',
    ':wrestlers:' => '🤼',
    ':x:' => '❌',
    ':x-ray:' => '🩻',
    ':yarn:' => '🧶',
    ':yawning-face:' => '🥱',
    ':yellow-heart:' => '💛',
    ':yen:' => '💴',
    ':yo-yo:' => '🪀',
    ':yum:' => '😋',
    ':zany-face:' => '🤪',
    ':zap:' => '⚡',
    ':zebra-face:' => '🦓',
    ':zipper-mouth-face:' => '🤐',
    ':zombie:' => '🧟',
    ':zzz:' => '💤',
    ':1st-place-medal:' => '🥇',
    ':2nd-place-medal:' => '🥈',
    ':3rd-place-medal:' => '🥉',
    ':a:' => '🅰️',
    ':airplane:' => '✈️',
    ':alembic:' => '⚗️',
    ':arrow-backward:' => '◀️',
    ':arrow-down:' => '⬇️',
    ':arrow-forward:' => '▶️',
    ':arrow-heading-down:' => '⤵️',
    ':arrow-heading-up:' => '⤴️',
    ':arrow-left:' => '⬅️',
    ':arrow-lower-left:' => '↙️',
    ':arrow-lower-right:' => '↘️',
    ':arrow-right:' => '➡️',
    ':arrow-right-hook:' => '↪️',
    ':arrow-up:' => '⬆️',
    ':arrow-up-down:' => '↕️',
    ':arrow-upper-left:' => '↖️',
    ':arrow-upper-right:' => '↗️',
    ':artificial-satellite:' => '🛰',
    ':atom-symbol:' => '⚛️',
    ':b:' => '🅱️',
    ':badminton:' => '🏸',
    ':balance-scale:' => '⚖',
    ':bald:' => '🦲',
    ':ballot-box:' => '🗳️',
    ':ballot-box-with-check:' => '☑️',
    ':bangbang:' => '‼️',
    ':beach-umbrella:' => '⛱️',
    ':bed:' => '🛏️',
    ':bellhop-bell:' => '🛎️',
    ':biohazard:' => '☣️',
    ':black-flag:' => '🏴',
    ':black-medium-square:' => '◼️',
    ':black-nib:' => '✒️',
    ':black-small-square:' => '▪️',
    ':blond-haired-person:' => '👱',
    ':blue-square:' => '🟦',
    ':bouncing-ball-person:' => '⛹',
    ':brick:' => '🧱',
    ':brown-circle:' => '🟤',
    ':brown-square:' => '🟫',
    ':building-construction:' => '🏗️',
    ':business-suit-levitating:' => '🕴',
    ':call-me:' => '🤙',
    ':camera-flash:' => '📸',
    ':camping:' => '🏕️',
    ':candle:' => '🕯️',
    ':card-file-box:' => '🗃️',
    ':card-index-dividers:' => '🗂️',
    ':cartwheel:' => '🤸',
    ':cartwheeling:' => '🤸',
    ':chains:' => '⛓️',
    ':champagne-glass:' => '🥂',
    ':cheese:' => '🧀',
    ':chess-pawn:' => '♟️',
    ':chipmunk:' => '🐿️',
    ':city-dusk:' => '🌆',
    ':cityscape:' => '🏙️',
    ':clamp:' => '🗜',
    ':classical-building:' => '🏛️',
    ':climbing:' => '🧗',
    ':cloud:' => '☁️',
    ':cloud-with-lightning:' => '🌩',
    ':cloud-with-lightning-and-rain:' => '⛈',
    ':cloud-with-rain:' => '🌧',
    ':cloud-with-snow:' => '🌨',
    ':clown:' => '🤡',
    ':clubs:' => '♣️',
    ':coffin:' => '⚰️',
    ':comet:' => '☄️',
    ':computer-mouse:' => '🖱',
    ':congratulations:' => '㊗️',
    ':control-knobs:' => '🎛️',
    ':copyright:' => '©️',
    ':couch-and-lamp:' => '🛋️',
    ':cowboy:' => '🤠',
    ':cowboy-hat-face:' => '🤠',
    ':crayon:' => '🖍️',
    ':cricket-game:' => '🏏',
    ':crossed-swords:' => '⚔️',
    ':curly-hair:' => '🦱',
    ':cursing-face:' => '🤬',
    ':dagger:' => '🗡️',
    ':dark-sunglasses:' => '🕶️',
    ':derelict-house:' => '🏚',
    ':desert:' => '🏜️',
    ':desert-island:' => '🏝️',
    ':desktop-computer:' => '🖥️',
    ':detective:' => '🕵',
    ':diamonds:' => '♦️',
    ':dove:' => '🕊️',
    ':drum:' => '🥁',
    ':eight-pointed-black-star:' => '✴️',
    ':eight-spoked-asterisk:' => '✳️',
    ':eject-button:' => '⏏',
    ':email:' => '✉️',
    ':envelope:' => '✉️',
    ':eye:' => '👁️',
    ':facepalm:' => '🤦',
    ':female-sign:' => '♀️',
    ':ferry:' => '⛴️',
    ':field-hockey:' => '🏑',
    ':file-cabinet:' => '🗄️',
    ':film-projector:' => '📽️',
    ':film-strip:' => '🎞',
    ':fingers-crossed:' => '🤞',
    ':first-place:' => '🥇',
    ':fist-left:' => '🤛',
    ':fist-oncoming:' => '👊',
    ':fist-raised:' => '✊',
    ':fist-right:' => '🤜',
    ':flag-black:' => '🏴',
    ':flat-shoe:' => '🥿',
    ':fleur-de-lis:' => '⚜️',
    ':flight-arrival:' => '🛬',
    ':flight-departure:' => '🛫',
    ':fog:' => '🌫️',
    ':fountain-pen:' => '🖋',
    ':fox:' => '🦊',
    ':framed-picture:' => '🖼',
    ':french-bread:' => '🥖',
    ':frowning-face:' => '☹',
    ':frowning-person:' => '🙍',
    ':fu:' => '🖕',
    ':funeral-urn:' => '⚱️',
    ':gear:' => '⚙️',
    ':giraffe:' => '🦒',
    ':goal:' => '🥅',
    ':golfing:' => '🏌',
    ':green-circle:' => '🟢',
    ':green-square:' => '🟩',
    ':guard:' => '💂',
    ':hammer-and-pick:' => '⚒️',
    ':hammer-and-wrench:' => '🛠️',
    ':hand-over-mouth:' => '🤭',
    ':handball-person:' => '🤾',
    ':head-bandage:' => '🤕',
    ':heart:' => '❤️',
    ':hearts:' => '♥️',
    ':heavy-check-mark:' => '✔️',
    ':heavy-heart-exclamation:' => '❣',
    ':heavy-multiplication-x:' => '✖️',
    ':hockey:' => '🏒',
    ':hole:' => '🕳️',
    ':hot-pepper:' => '🌶️',
    ':hotsprings:' => '♨️',
    ':houses:' => '🏘',
    ':hugging:' => '🤗',
    ':hugs:' => '🤗',
    ':ice:' => '🧊',
    ':ice-hockey:' => '🏒',
    ':ice-skate:' => '⛸️',
    ':infinity:' => '♾️',
    ':information-source:' => 'ℹ️',
    ':interrobang:' => '⁉️',
    ':joystick:' => '🕹️',
    ':juggling-person:' => '🤹',
    ':keyboard:' => '⌨️',
    ':kick-scooter:' => '🛴',
    ':kiwi:' => '🥝',
    ':kiwi-fruit:' => '🥝',
    ':label:' => '🏷️',
    ':latin-cross:' => '✝️',
    ':left-right-arrow:' => '↔️',
    ':left-speech-bubble:' => '🗨️',
    ':leftwards-arrow-with-hook:' => '↩️',
    ':level-slider:' => '🎚️',
    ':lion:' => '🦁',
    ':lotus-position:' => '🧘',
    ':love-you-gesture:' => '🤟',
    ':m:' => 'Ⓜ️',
    ':male-sign:' => '♂️',
    ':mandarin:' => '🍊',
    ':mantelpiece-clock:' => '🕰️',
    ':mate:' => '🧉',
    ':medal:' => '🎖️',
    ':medal-military:' => '🎖',
    ':medal-sports:' => '🏅',
    ':medical-symbol:' => '⚕️',
    ':menorah:' => '🕎',
    ':metal:' => '🤘',
    ':milk:' => '🥛',
    ':milk-glass:' => '🥛',
    ':money-mouth:' => '🤑',
    ':monocle-face:' => '🧐',
    ':motor-boat:' => '🛥️',
    ':motorcycle:' => '🏍️',
    ':motorway:' => '🛣️',
    ':mountain:' => '⛰️',
    ':mountain-snow:' => '🏔️',
    ':national-park:' => '🏞️',
    ':nerd:' => '🤓',
    ':newspaper-roll:' => '🗞',
    ':next-track-button:' => '⏭',
    ':o2:' => '🅾️',
    ':oil-drum:' => '🛢️',
    ':ok-person:' => '🙆',
    ':old-key:' => '🗝️',
    ':older-person:' => '🧓',
    ':om:' => '🕉',
    ':open-umbrella:' => '☂',
    ':orange:' => '🍊',
    ':orange-circle:' => '🟠',
    ':orange-square:' => '🟧',
    ':orthodox-cross:' => '☦️',
    ':paintbrush:' => '🖌️',
    ':paperclips:' => '🖇️',
    ':parasol-on-ground:' => '⛱',
    ':parking:' => '🅿️',
    ':part-alternation-mark:' => '〽️',
    ':passenger-ship:' => '🛳️',
    ':pause-button:' => '⏸️',
    ':peace-symbol:' => '☮️',
    ':pen:' => '🖊',
    ':pencil2:' => '✏️',
    ':person:' => '🧑',
    ':person-beard:' => '🧔',
    ':person-fencing:' => '🤺',
    ':person-kneeling:' => '🧎',
    ':person-standing:' => '🧍',
    ':person-with-turban:' => '👳',
    ':person-with-veil:' => '👰',
    ':phone:' => '☎️',
    ':pick:' => '⛏️',
    ':ping-pong:' => '🏓',
    ':plate-with-cutlery:' => '🍽',
    ':play-or-pause-button:' => '⏯',
    ':point-up:' => '☝️',
    ':police-officer:' => '👮',
    ':pout:' => '😡',
    ':pouting-face:' => '🙎',
    ':previous-track-button:' => '⏮',
    ':printer:' => '🖨️',
    ':purple-circle:' => '🟣',
    ':purple-square:' => '🟪',
    ':puzzle-piece:' => '🧩',
    ':racing-car:' => '🏎️',
    ':radioactive:' => '☢️',
    ':railway-track:' => '🛤️',
    ':raised-eyebrow:' => '🤨',
    ':raised-hand-with-fingers-splayed:' => '🖐️',
    ':record-button:' => '⏺️',
    ':recycle:' => '♻️',
    ':red-hair:' => '🦰',
    ':red-square:' => '🟥',
    ':registered:' => '®️',
    ':relaxed:' => '☺️',
    ':reminder-ribbon:' => '🎗️',
    ':rescue-worker-helmet:' => '⛑',
    ':rhino:' => '🦏',
    ':right-anger-bubble:' => '🗯️',
    ':robot:' => '🤖',
    ':rofl:' => '🤣',
    ':roll-eyes:' => '🙄',
    ':rolling-eyes:' => '🙄',
    ':rosette:' => '🏵️',
    ':sa:' => '🈂️',
    ':salad:' => '🥗',
    ':satellite:' => '🛰️',
    ':sauna-person:' => '🧖',
    ':scissors:' => '✂️',
    ':second-place:' => '🥈',
    ':secret:' => '㊙️',
    ':shamrock:' => '☘️',
    ':shield:' => '🛡️',
    ':shinto-shrine:' => '⛩️',
    ':shopping:' => '🛍',
    ':shopping-cart:' => '🛒',
    ':skier:' => '⛷️',
    ':skull-and-crossbones:' => '☠️',
    ':sleeping-bed:' => '🛌',
    ':slight-frown:' => '🙁',
    ':slight-smile:' => '🙂',
    ':small-airplane:' => '🛩️',
    ':smiling-face-with-hearts:' => '🥰',
    ':smiling-face-with-three-hearts:' => '🥰',
    ':snowflake:' => '❄️',
    ':snowman:' => '☃️',
    ':snowman-with-snow:' => '☃',
    ':spades:' => '♠️',
    ':sparkle:' => '❇️',
    ':speaking-head:' => '🗣️',
    ':spider:' => '🕷️',
    ':spider-web:' => '🕸️',
    ':spiral-calendar:' => '🗓',
    ':spiral-notepad:' => '🗒',
    ':stadium:' => '🏟️',
    ':star-and-crescent:' => '☪️',
    ':star-of-david:' => '✡️',
    ':stop-button:' => '⏹️',
    ':stop-sign:' => '🛑',
    ':stopwatch:' => '⏱️',
    ':studio-microphone:' => '🎙️',
    ':sun-behind-large-cloud:' => '🌥',
    ':sun-behind-rain-cloud:' => '🌦️',
    ':sun-behind-small-cloud:' => '🌤',
    ':sunny:' => '☀️',
    ':swim-brief:' => '🩲',
    ':telephone:' => '☎️',
    ':ten:' => '🔟',
    ':thermometer:' => '🌡️',
    ':thermometer-face:' => '🤒',
    ':thinking:' => '🤔',
    ':third-place:' => '🥉',
    ':tickets:' => '🎟️',
    ':timer-clock:' => '⏲️',
    ':tipping-hand-person:' => '💁',
    ':tm:' => '™️',
    ':tone1:' => '🏻',
    ':tone2:' => '🏼',
    ':tone3:' => '🏽',
    ':tone4:' => '🏾',
    ':tone5:' => '🏿',
    ':tornado:' => '🌪️',
    ':trackball:' => '🖲️',
    ':transgender-symbol:' => '⚧️',
    ':u6708:' => '🈷️',
    ':umbrella:' => '☂️',
    ':unicorn:' => '🦄',
    ':upside-down:' => '🙃',
    ':v:' => '✌️',
    ':vomiting-face:' => '🤮',
    ':vulcan:' => '🖖',
    ':vulcan-salute:' => '🖖',
    ':warning:' => '⚠️',
    ':wastebasket:' => '🗑️',
    ':wavy-dash:' => '〰️',
    ':weight-lifting:' => '🏋',
    ':wheel-of-dharma:' => '☸️',
    ':white-cane:' => '🦯',
    ':white-flag:' => '🏳',
    ':white-hair:' => '🦳',
    ':white-medium-square:' => '◻️',
    ':white-small-square:' => '▫️',
    ':wilted-rose:' => '🥀',
    ':wind-face:' => '🌬',
    ':woman-dancing:' => '💃',
    ':woman-with-headscarf:' => '🧕',
    ':world-map:' => '🗺️',
    ':wrestling:' => '🤼',
    ':writing-hand:' => '✍️',
    ':yellow-circle:' => '🟡',
    ':yellow-square:' => '🟨',
    ':yin-yang:' => '☯️',
    ':zebra:' => '🦓',
    ':zipper-mouth:' => '🤐',
    ':admission-tickets:' => '🎟️',
    ':ballot-box-with-ballot:' => '🗳️',
    ':barely-sunny:' => '🌥️',
    ':beach-with-umbrella:' => '🏖️',
    ':biohazard-sign:' => '☣️',
    ':black-circle-for-record:' => '⏺️',
    ':black-left-pointing-double-triangle-with-vertical-bar:' => '⏮️',
    ':black-right-pointing-double-triangle-with-vertical-bar:' => '⏭️',
    ':black-right-pointing-triangle-with-double-vertical-bar:' => '⏯️',
    ':black-square-for-stop:' => '⏹️',
    ':cn:' => '🇨🇳',
    ':compression:' => '🗜️',
    ':dagger-knife:' => '🗡️',
    ':de:' => '🇩🇪',
    ':derelict-house-building:' => '🏚️',
    ':double-vertical-bar:' => '⏸️',
    ':dove-of-peace:' => '🕊️',
    ':eject:' => '⏏️',
    ':es:' => '🇪🇸',
    ':film-frames:' => '🎞️',
    ':flag-ac:' => '🇦🇨',
    ':flag-ad:' => '🇦🇩',
    ':flag-ae:' => '🇦🇪',
    ':flag-af:' => '🇦🇫',
    ':flag-ag:' => '🇦🇬',
    ':flag-ai:' => '🇦🇮',
    ':flag-al:' => '🇦🇱',
    ':flag-am:' => '🇦🇲',
    ':flag-ao:' => '🇦🇴',
    ':flag-aq:' => '🇦🇶',
    ':flag-ar:' => '🇦🇷',
    ':flag-as:' => '🇦🇸',
    ':flag-at:' => '🇦🇹',
    ':flag-au:' => '🇦🇺',
    ':flag-aw:' => '🇦🇼',
    ':flag-ax:' => '🇦🇽',
    ':flag-az:' => '🇦🇿',
    ':flag-ba:' => '🇧🇦',
    ':flag-bb:' => '🇧🇧',
    ':flag-bd:' => '🇧🇩',
    ':flag-be:' => '🇧🇪',
    ':flag-bf:' => '🇧🇫',
    ':flag-bg:' => '🇧🇬',
    ':flag-bh:' => '🇧🇭',
    ':flag-bi:' => '🇧🇮',
    ':flag-bj:' => '🇧🇯',
    ':flag-bl:' => '🇧🇱',
    ':flag-bm:' => '🇧🇲',
    ':flag-bn:' => '🇧🇳',
    ':flag-bo:' => '🇧🇴',
    ':flag-bq:' => '🇧🇶',
    ':flag-br:' => '🇧🇷',
    ':flag-bs:' => '🇧🇸',
    ':flag-bt:' => '🇧🇹',
    ':flag-bv:' => '🇧🇻',
    ':flag-bw:' => '🇧🇼',
    ':flag-by:' => '🇧🇾',
    ':flag-bz:' => '🇧🇿',
    ':flag-ca:' => '🇨🇦',
    ':flag-cc:' => '🇨🇨',
    ':flag-cd:' => '🇨🇩',
    ':flag-cf:' => '🇨🇫',
    ':flag-cg:' => '🇨🇬',
    ':flag-ch:' => '🇨🇭',
    ':flag-ci:' => '🇨🇮',
    ':flag-ck:' => '🇨🇰',
    ':flag-cl:' => '🇨🇱',
    ':flag-cm:' => '🇨🇲',
    ':flag-cn:' => '🇨🇳',
    ':flag-co:' => '🇨🇴',
    ':flag-cp:' => '🇨🇵',
    ':flag-cr:' => '🇨🇷',
    ':flag-cu:' => '🇨🇺',
    ':flag-cv:' => '🇨🇻',
    ':flag-cw:' => '🇨🇼',
    ':flag-cx:' => '🇨🇽',
    ':flag-cy:' => '🇨🇾',
    ':flag-cz:' => '🇨🇿',
    ':flag-de:' => '🇩🇪',
    ':flag-dg:' => '🇩🇬',
    ':flag-dj:' => '🇩🇯',
    ':flag-dk:' => '🇩🇰',
    ':flag-dm:' => '🇩🇲',
    ':flag-do:' => '🇩🇴',
    ':flag-dz:' => '🇩🇿',
    ':flag-ea:' => '🇪🇦',
    ':flag-ec:' => '🇪🇨',
    ':flag-ee:' => '🇪🇪',
    ':flag-eg:' => '🇪🇬',
    ':flag-eh:' => '🇪🇭',
    ':flag-er:' => '🇪🇷',
    ':flag-es:' => '🇪🇸',
    ':flag-et:' => '🇪🇹',
    ':flag-eu:' => '🇪🇺',
    ':flag-fi:' => '🇫🇮',
    ':flag-fj:' => '🇫🇯',
    ':flag-fk:' => '🇫🇰',
    ':flag-fm:' => '🇫🇲',
    ':flag-fo:' => '🇫🇴',
    ':flag-fr:' => '🇫🇷',
    ':flag-ga:' => '🇬🇦',
    ':flag-gb:' => '🇬🇧',
    ':flag-gd:' => '🇬🇩',
    ':flag-ge:' => '🇬🇪',
    ':flag-gf:' => '🇬🇫',
    ':flag-gg:' => '🇬🇬',
    ':flag-gh:' => '🇬🇭',
    ':flag-gi:' => '🇬🇮',
    ':flag-gl:' => '🇬🇱',
    ':flag-gm:' => '🇬🇲',
    ':flag-gn:' => '🇬🇳',
    ':flag-gp:' => '🇬🇵',
    ':flag-gq:' => '🇬🇶',
    ':flag-gr:' => '🇬🇷',
    ':flag-gs:' => '🇬🇸',
    ':flag-gt:' => '🇬🇹',
    ':flag-gu:' => '🇬🇺',
    ':flag-gw:' => '🇬🇼',
    ':flag-gy:' => '🇬🇾',
    ':flag-hk:' => '🇭🇰',
    ':flag-hm:' => '🇭🇲',
    ':flag-hn:' => '🇭🇳',
    ':flag-hr:' => '🇭🇷',
    ':flag-ht:' => '🇭🇹',
    ':flag-hu:' => '🇭🇺',
    ':flag-ic:' => '🇮🇨',
    ':flag-id:' => '🇮🇩',
    ':flag-ie:' => '🇮🇪',
    ':flag-il:' => '🇮🇱',
    ':flag-im:' => '🇮🇲',
    ':flag-in:' => '🇮🇳',
    ':flag-io:' => '🇮🇴',
    ':flag-iq:' => '🇮🇶',
    ':flag-ir:' => '🇮🇷',
    ':flag-is:' => '🇮🇸',
    ':flag-it:' => '🇮🇹',
    ':flag-je:' => '🇯🇪',
    ':flag-jm:' => '🇯🇲',
    ':flag-jo:' => '🇯🇴',
    ':flag-jp:' => '🇯🇵',
    ':flag-ke:' => '🇰🇪',
    ':flag-kg:' => '🇰🇬',
    ':flag-kh:' => '🇰🇭',
    ':flag-ki:' => '🇰🇮',
    ':flag-km:' => '🇰🇲',
    ':flag-kn:' => '🇰🇳',
    ':flag-kp:' => '🇰🇵',
    ':flag-kr:' => '🇰🇷',
    ':flag-kw:' => '🇰🇼',
    ':flag-ky:' => '🇰🇾',
    ':flag-kz:' => '🇰🇿',
    ':flag-la:' => '🇱🇦',
    ':flag-lb:' => '🇱🇧',
    ':flag-lc:' => '🇱🇨',
    ':flag-li:' => '🇱🇮',
    ':flag-lk:' => '🇱🇰',
    ':flag-lr:' => '🇱🇷',
    ':flag-ls:' => '🇱🇸',
    ':flag-lt:' => '🇱🇹',
    ':flag-lu:' => '🇱🇺',
    ':flag-lv:' => '🇱🇻',
    ':flag-ly:' => '🇱🇾',
    ':flag-ma:' => '🇲🇦',
    ':flag-mc:' => '🇲🇨',
    ':flag-md:' => '🇲🇩',
    ':flag-me:' => '🇲🇪',
    ':flag-mf:' => '🇲🇫',
    ':flag-mg:' => '🇲🇬',
    ':flag-mh:' => '🇲🇭',
    ':flag-mk:' => '🇲🇰',
    ':flag-ml:' => '🇲🇱',
    ':flag-mm:' => '🇲🇲',
    ':flag-mn:' => '🇲🇳',
    ':flag-mo:' => '🇲🇴',
    ':flag-mp:' => '🇲🇵',
    ':flag-mq:' => '🇲🇶',
    ':flag-mr:' => '🇲🇷',
    ':flag-ms:' => '🇲🇸',
    ':flag-mt:' => '🇲🇹',
    ':flag-mu:' => '🇲🇺',
    ':flag-mv:' => '🇲🇻',
    ':flag-mw:' => '🇲🇼',
    ':flag-mx:' => '🇲🇽',
    ':flag-my:' => '🇲🇾',
    ':flag-mz:' => '🇲🇿',
    ':flag-na:' => '🇳🇦',
    ':flag-nc:' => '🇳🇨',
    ':flag-ne:' => '🇳🇪',
    ':flag-nf:' => '🇳🇫',
    ':flag-ng:' => '🇳🇬',
    ':flag-ni:' => '🇳🇮',
    ':flag-nl:' => '🇳🇱',
    ':flag-no:' => '🇳🇴',
    ':flag-np:' => '🇳🇵',
    ':flag-nr:' => '🇳🇷',
    ':flag-nu:' => '🇳🇺',
    ':flag-nz:' => '🇳🇿',
    ':flag-om:' => '🇴🇲',
    ':flag-pa:' => '🇵🇦',
    ':flag-pe:' => '🇵🇪',
    ':flag-pf:' => '🇵🇫',
    ':flag-pg:' => '🇵🇬',
    ':flag-ph:' => '🇵🇭',
    ':flag-pk:' => '🇵🇰',
    ':flag-pl:' => '🇵🇱',
    ':flag-pm:' => '🇵🇲',
    ':flag-pn:' => '🇵🇳',
    ':flag-pr:' => '🇵🇷',
    ':flag-ps:' => '🇵🇸',
    ':flag-pt:' => '🇵🇹',
    ':flag-pw:' => '🇵🇼',
    ':flag-py:' => '🇵🇾',
    ':flag-qa:' => '🇶🇦',
    ':flag-re:' => '🇷🇪',
    ':flag-ro:' => '🇷🇴',
    ':flag-rs:' => '🇷🇸',
    ':flag-ru:' => '🇷🇺',
    ':flag-rw:' => '🇷🇼',
    ':flag-sa:' => '🇸🇦',
    ':flag-sb:' => '🇸🇧',
    ':flag-sc:' => '🇸🇨',
    ':flag-sd:' => '🇸🇩',
    ':flag-se:' => '🇸🇪',
    ':flag-sg:' => '🇸🇬',
    ':flag-sh:' => '🇸🇭',
    ':flag-si:' => '🇸🇮',
    ':flag-sj:' => '🇸🇯',
    ':flag-sk:' => '🇸🇰',
    ':flag-sl:' => '🇸🇱',
    ':flag-sm:' => '🇸🇲',
    ':flag-sn:' => '🇸🇳',
    ':flag-so:' => '🇸🇴',
    ':flag-sr:' => '🇸🇷',
    ':flag-ss:' => '🇸🇸',
    ':flag-st:' => '🇸🇹',
    ':flag-sv:' => '🇸🇻',
    ':flag-sx:' => '🇸🇽',
    ':flag-sy:' => '🇸🇾',
    ':flag-sz:' => '🇸🇿',
    ':flag-ta:' => '🇹🇦',
    ':flag-tc:' => '🇹🇨',
    ':flag-td:' => '🇹🇩',
    ':flag-tf:' => '🇹🇫',
    ':flag-tg:' => '🇹🇬',
    ':flag-th:' => '🇹🇭',
    ':flag-tj:' => '🇹🇯',
    ':flag-tk:' => '🇹🇰',
    ':flag-tl:' => '🇹🇱',
    ':flag-tm:' => '🇹🇲',
    ':flag-tn:' => '🇹🇳',
    ':flag-to:' => '🇹🇴',
    ':flag-tr:' => '🇹🇷',
    ':flag-tt:' => '🇹🇹',
    ':flag-tv:' => '🇹🇻',
    ':flag-tw:' => '🇹🇼',
    ':flag-tz:' => '🇹🇿',
    ':flag-ua:' => '🇺🇦',
    ':flag-ug:' => '🇺🇬',
    ':flag-um:' => '🇺🇲',
    ':flag-un:' => '🇺🇳',
    ':flag-us:' => '🇺🇸',
    ':flag-uy:' => '🇺🇾',
    ':flag-uz:' => '🇺🇿',
    ':flag-va:' => '🇻🇦',
    ':flag-vc:' => '🇻🇨',
    ':flag-ve:' => '🇻🇪',
    ':flag-vg:' => '🇻🇬',
    ':flag-vi:' => '🇻🇮',
    ':flag-vn:' => '🇻🇳',
    ':flag-vu:' => '🇻🇺',
    ':flag-wf:' => '🇼🇫',
    ':flag-ws:' => '🇼🇸',
    ':flag-xk:' => '🇽🇰',
    ':flag-ye:' => '🇾🇪',
    ':flag-yt:' => '🇾🇹',
    ':flag-za:' => '🇿🇦',
    ':flag-zm:' => '🇿🇲',
    ':flag-zw:' => '🇿🇼',
    ':fr:' => '🇫🇷',
    ':frame-with-picture:' => '🖼️',
    ':gb:' => '🇬🇧',
    ':golfer:' => '🏌️',
    ':heavy-heart-exclamation-mark-ornament:' => '❣️',
    ':helmet-with-white-cross:' => '⛑️',
    ':house-buildings:' => '🏘️',
    ':it:' => '🇮🇹',
    ':jp:' => '🇯🇵',
    ':knife-fork-plate:' => '🍽️',
    ':kr:' => '🇰🇷',
    ':lightning:' => '🌩️',
    ':lightning-cloud:' => '🌩️',
    ':linked-paperclips:' => '🖇️',
    ':lower-left-ballpoint-pen:' => '🖊️',
    ':lower-left-crayon:' => '🖍️',
    ':lower-left-fountain-pen:' => '🖋️',
    ':lower-left-paintbrush:' => '🖌️',
    ':man-in-business-suit-levitating:' => '🕴️',
    ':mostly-sunny:' => '🌤️',
    ':om-symbol:' => '🕉️',
    ':partly-sunny-rain:' => '🌦️',
    ':person-with-ball:' => '⛹️',
    ':racing-motorcycle:' => '🏍️',
    ':radioactive-sign:' => '☢️',
    ':rain-cloud:' => '🌧️',
    ':rolled-up-newspaper:' => '🗞️',
    ':ru:' => '🇷🇺',
    ':scales:' => '⚖️',
    ':shopping-bags:' => '🛍️',
    ':sleuth-or-spy:' => '🕵️',
    ':snow-capped-mountain:' => '🏔️',
    ':snow-cloud:' => '🌨️',
    ':speaking-head-in-silhouette:' => '🗣️',
    ':spiral-calendar-pad:' => '🗓️',
    ':spiral-note-pad:' => '🗒️',
    ':staff-of-aesculapius:' => '⚕️',
    ':sun-behind-cloud:' => '🌥️',
    ':sun-small-cloud:' => '🌤️',
    ':three-button-mouse:' => '🖱️',
    ':thunder-cloud-and-rain:' => '⛈️',
    ':tornado-cloud:' => '🌪️',
    ':uk:' => '🇬🇧',
    ':umbrella-on-ground:' => '⛱️',
    ':us:' => '🇺🇸',
    ':waving-white-flag:' => '🏳️',
    ':weight-lifter:' => '🏋️',
    ':white-frowning-face:' => '☹️',
    ':wind-blowing-face:' => '🌬️',
    ':afghanistan:' => '🇦🇫',
    ':airplane-small:' => '🛩️',
    ':aland-islands:' => '🇦🇽',
    ':albania:' => '🇦🇱',
    ':algeria:' => '🇩🇿',
    ':american-samoa:' => '🇦🇸',
    ':andorra:' => '🇦🇩',
    ':angel-tone1:' => '👼🏻',
    ':angel-tone2:' => '👼🏼',
    ':angel-tone3:' => '👼🏽',
    ':angel-tone4:' => '👼🏾',
    ':angel-tone5:' => '👼🏿',
    ':anger-right:' => '🗯️',
    ':angola:' => '🇦🇴',
    ':anguilla:' => '🇦🇮',
    ':antarctica:' => '🇦🇶',
    ':antigua-barbuda:' => '🇦🇬',
    ':argentina:' => '🇦🇷',
    ':armenia:' => '🇦🇲',
    ':aruba:' => '🇦🇼',
    ':ascension-island:' => '🇦🇨',
    ':asterisk:' => '*️⃣',
    ':atom:' => '⚛️',
    ':australia:' => '🇦🇺',
    ':austria:' => '🇦🇹',
    ':azerbaijan:' => '🇦🇿',
    ':baby-tone1:' => '👶🏻',
    ':baby-tone2:' => '👶🏼',
    ':baby-tone3:' => '👶🏽',
    ':baby-tone4:' => '👶🏾',
    ':baby-tone5:' => '👶🏿',
    ':bahamas:' => '🇧🇸',
    ':bahrain:' => '🇧🇭',
    ':bangladesh:' => '🇧🇩',
    ':barbados:' => '🇧🇧',
    ':basketball-player:' => '⛹️',
    ':basketball-player-tone1:' => '⛹🏻',
    ':basketball-player-tone2:' => '⛹🏼',
    ':basketball-player-tone3:' => '⛹🏽',
    ':basketball-player-tone4:' => '⛹🏾',
    ':basketball-player-tone5:' => '⛹🏿',
    ':bath-tone1:' => '🛀🏻',
    ':bath-tone2:' => '🛀🏼',
    ':bath-tone3:' => '🛀🏽',
    ':bath-tone4:' => '🛀🏾',
    ':bath-tone5:' => '🛀🏿',
    ':beach:' => '🏖️',
    ':belarus:' => '🇧🇾',
    ':belgium:' => '🇧🇪',
    ':belize:' => '🇧🇿',
    ':bellhop:' => '🛎️',
    ':benin:' => '🇧🇯',
    ':bermuda:' => '🇧🇲',
    ':bhutan:' => '🇧🇹',
    ':bicyclist-tone1:' => '🚴🏻',
    ':bicyclist-tone2:' => '🚴🏼',
    ':bicyclist-tone3:' => '🚴🏽',
    ':bicyclist-tone4:' => '🚴🏾',
    ':bicyclist-tone5:' => '🚴🏿',
    ':bolivia:' => '🇧🇴',
    ':bosnia-herzegovina:' => '🇧🇦',
    ':botswana:' => '🇧🇼',
    ':bouvet-island:' => '🇧🇻',
    ':bow-tone1:' => '🙇🏻',
    ':bow-tone2:' => '🙇🏼',
    ':bow-tone3:' => '🙇🏽',
    ':bow-tone4:' => '🙇🏾',
    ':bow-tone5:' => '🙇🏿',
    ':boy-tone1:' => '👦🏻',
    ':boy-tone2:' => '👦🏼',
    ':boy-tone3:' => '👦🏽',
    ':boy-tone4:' => '👦🏾',
    ':boy-tone5:' => '👦🏿',
    ':brazil:' => '🇧🇷',
    ':breast-feeding-dark-skin-tone:' => '🤱🏿',
    ':breast-feeding-light-skin-tone:' => '🤱🏻',
    ':breast-feeding-medium-dark-skin-tone:' => '🤱🏾',
    ':breast-feeding-medium-light-skin-tone:' => '🤱🏼',
    ':breast-feeding-medium-skin-tone:' => '🤱🏽',
    ':bride-with-veil-tone1:' => '👰🏻',
    ':bride-with-veil-tone2:' => '👰🏼',
    ':bride-with-veil-tone3:' => '👰🏽',
    ':bride-with-veil-tone4:' => '👰🏾',
    ':bride-with-veil-tone5:' => '👰🏿',
    ':british-indian-ocean-territory:' => '🇮🇴',
    ':british-virgin-islands:' => '🇻🇬',
    ':brunei:' => '🇧🇳',
    ':bulgaria:' => '🇧🇬',
    ':burkina-faso:' => '🇧🇫',
    ':burundi:' => '🇧🇮',
    ':calendar-spiral:' => '🗓️',
    ':call-me-tone1:' => '🤙🏻',
    ':call-me-tone2:' => '🤙🏼',
    ':call-me-tone3:' => '🤙🏽',
    ':call-me-tone4:' => '🤙🏾',
    ':call-me-tone5:' => '🤙🏿',
    ':cambodia:' => '🇰🇭',
    ':cameroon:' => '🇨🇲',
    ':canada:' => '🇨🇦',
    ':canary-islands:' => '🇮🇨',
    ':cape-verde:' => '🇨🇻',
    ':card-box:' => '🗃️',
    ':caribbean-netherlands:' => '🇧🇶',
    ':cartwheel-tone1:' => '🤸🏻',
    ':cartwheel-tone2:' => '🤸🏼',
    ':cartwheel-tone3:' => '🤸🏽',
    ':cartwheel-tone4:' => '🤸🏾',
    ':cartwheel-tone5:' => '🤸🏿',
    ':cayman-islands:' => '🇰🇾',
    ':central-african-republic:' => '🇨🇫',
    ':ceuta-melilla:' => '🇪🇦',
    ':chad:' => '🇹🇩',
    ':child-dark-skin-tone:' => '🧒🏿',
    ':child-light-skin-tone:' => '🧒🏻',
    ':child-medium-dark-skin-tone:' => '🧒🏾',
    ':child-medium-light-skin-tone:' => '🧒🏼',
    ':child-medium-skin-tone:' => '🧒🏽',
    ':chile:' => '🇨🇱',
    ':christmas-island:' => '🇨🇽',
    ':clap-tone1:' => '👏🏻',
    ':clap-tone2:' => '👏🏼',
    ':clap-tone3:' => '👏🏽',
    ':clap-tone4:' => '👏🏾',
    ':clap-tone5:' => '👏🏿',
    ':clipperton-island:' => '🇨🇵',
    ':clock:' => '🕰️',
    ':cloud-lightning:' => '🌩️',
    ':cloud-rain:' => '🌧️',
    ':cloud-snow:' => '🌨️',
    ':cloud-tornado:' => '🌪️',
    ':cocos-islands:' => '🇨🇨',
    ':colombia:' => '🇨🇴',
    ':comoros:' => '🇰🇲',
    ':congo-brazzaville:' => '🇨🇬',
    ':congo-kinshasa:' => '🇨🇩',
    ':construction-site:' => '🏗️',
    ':construction-worker-tone1:' => '👷🏻',
    ':construction-worker-tone2:' => '👷🏼',
    ':construction-worker-tone3:' => '👷🏽',
    ':construction-worker-tone4:' => '👷🏾',
    ':construction-worker-tone5:' => '👷🏿',
    ':cook-islands:' => '🇨🇰',
    ':cop-tone1:' => '👮🏻',
    ':cop-tone2:' => '👮🏼',
    ':cop-tone3:' => '👮🏽',
    ':cop-tone4:' => '👮🏾',
    ':cop-tone5:' => '👮🏿',
    ':costa-rica:' => '🇨🇷',
    ':cote-divoire:' => '🇨🇮',
    ':couch:' => '🛋️',
    ':couple-with-heart-dark-skin-tone:' => '💑🏿',
    ':couple-with-heart-light-skin-tone:' => '💑🏻',
    ':couple-with-heart-medium-dark-skin-tone:' => '💑🏾',
    ':couple-with-heart-medium-light-skin-tone:' => '💑🏼',
    ':couple-with-heart-medium-skin-tone:' => '💑🏽',
    ':croatia:' => '🇭🇷',
    ':cross:' => '✝️',
    ':cruise-ship:' => '🛳️',
    ':cuba:' => '🇨🇺',
    ':curacao:' => '🇨🇼',
    ':cyprus:' => '🇨🇾',
    ':czech-republic:' => '🇨🇿',
    ':dancer-tone1:' => '💃🏻',
    ':dancer-tone2:' => '💃🏼',
    ':dancer-tone3:' => '💃🏽',
    ':dancer-tone4:' => '💃🏾',
    ':dancer-tone5:' => '💃🏿',
    ':deaf-person-dark-skin-tone:' => '🧏🏿',
    ':deaf-person-light-skin-tone:' => '🧏🏻',
    ':deaf-person-medium-dark-skin-tone:' => '🧏🏾',
    ':deaf-person-medium-light-skin-tone:' => '🧏🏼',
    ':deaf-person-medium-skin-tone:' => '🧏🏽',
    ':denmark:' => '🇩🇰',
    ':desktop:' => '🖥️',
    ':diego-garcia:' => '🇩🇬',
    ':dividers:' => '🗂️',
    ':djibouti:' => '🇩🇯',
    ':dominica:' => '🇩🇲',
    ':dominican-republic:' => '🇩🇴',
    ':ear-tone1:' => '👂🏻',
    ':ear-tone2:' => '👂🏼',
    ':ear-tone3:' => '👂🏽',
    ':ear-tone4:' => '👂🏾',
    ':ear-tone5:' => '👂🏿',
    ':ear-with-hearing-aid-dark-skin-tone:' => '🦻🏿',
    ':ear-with-hearing-aid-light-skin-tone:' => '🦻🏻',
    ':ear-with-hearing-aid-medium-dark-skin-tone:' => '🦻🏾',
    ':ear-with-hearing-aid-medium-light-skin-tone:' => '🦻🏼',
    ':ear-with-hearing-aid-medium-skin-tone:' => '🦻🏽',
    ':ecuador:' => '🇪🇨',
    ':egypt:' => '🇪🇬',
    ':eight:' => '8️⃣',
    ':el-salvador:' => '🇸🇻',
    ':elf-dark-skin-tone:' => '🧝🏿',
    ':elf-light-skin-tone:' => '🧝🏻',
    ':elf-medium-dark-skin-tone:' => '🧝🏾',
    ':elf-medium-light-skin-tone:' => '🧝🏼',
    ':elf-medium-skin-tone:' => '🧝🏽',
    ':equatorial-guinea:' => '🇬🇶',
    ':eritrea:' => '🇪🇷',
    ':estonia:' => '🇪🇪',
    ':ethiopia:' => '🇪🇹',
    ':eu:' => '🇪🇺',
    ':european-union:' => '🇪🇺',
    ':face-palm-tone1:' => '🤦🏻',
    ':face-palm-tone2:' => '🤦🏼',
    ':face-palm-tone3:' => '🤦🏽',
    ':face-palm-tone4:' => '🤦🏾',
    ':face-palm-tone5:' => '🤦🏿',
    ':fairy-dark-skin-tone:' => '🧚🏿',
    ':fairy-light-skin-tone:' => '🧚🏻',
    ':fairy-medium-dark-skin-tone:' => '🧚🏾',
    ':fairy-medium-light-skin-tone:' => '🧚🏼',
    ':fairy-medium-skin-tone:' => '🧚🏽',
    ':falkland-islands:' => '🇫🇰',
    ':faroe-islands:' => '🇫🇴',
    ':fiji:' => '🇫🇯',
    ':fingers-crossed-tone1:' => '🤞🏻',
    ':fingers-crossed-tone2:' => '🤞🏼',
    ':fingers-crossed-tone3:' => '🤞🏽',
    ':fingers-crossed-tone4:' => '🤞🏾',
    ':fingers-crossed-tone5:' => '🤞🏿',
    ':finland:' => '🇫🇮',
    ':fist-tone1:' => '✊🏻',
    ':fist-tone2:' => '✊🏼',
    ':fist-tone3:' => '✊🏽',
    ':fist-tone4:' => '✊🏾',
    ':fist-tone5:' => '✊🏿',
    ':five:' => '5️⃣',
    ':flag-united-nations:' => '🇺🇳',
    ':flag-white:' => '🏳️',
    ':foot-dark-skin-tone:' => '🦶🏿',
    ':foot-light-skin-tone:' => '🦶🏻',
    ':foot-medium-dark-skin-tone:' => '🦶🏾',
    ':foot-medium-light-skin-tone:' => '🦶🏼',
    ':foot-medium-skin-tone:' => '🦶🏽',
    ':fork-knife-plate:' => '🍽️',
    ':four:' => '4️⃣',
    ':frame-photo:' => '🖼️',
    ':french-guiana:' => '🇬🇫',
    ':french-polynesia:' => '🇵🇫',
    ':french-southern-territories:' => '🇹🇫',
    ':frowning2:' => '☹️',
    ':gabon:' => '🇬🇦',
    ':gambia:' => '🇬🇲',
    ':georgia:' => '🇬🇪',
    ':ghana:' => '🇬🇭',
    ':gibraltar:' => '🇬🇮',
    ':girl-tone1:' => '👧🏻',
    ':girl-tone2:' => '👧🏼',
    ':girl-tone3:' => '👧🏽',
    ':girl-tone4:' => '👧🏾',
    ':girl-tone5:' => '👧🏿',
    ':greece:' => '🇬🇷',
    ':greenland:' => '🇬🇱',
    ':grenada:' => '🇬🇩',
    ':guadeloupe:' => '🇬🇵',
    ':guam:' => '🇬🇺',
    ':guardsman-tone1:' => '💂🏻',
    ':guardsman-tone2:' => '💂🏼',
    ':guardsman-tone3:' => '💂🏽',
    ':guardsman-tone4:' => '💂🏾',
    ':guardsman-tone5:' => '💂🏿',
    ':guatemala:' => '🇬🇹',
    ':guernsey:' => '🇬🇬',
    ':guinea:' => '🇬🇳',
    ':guinea-bissau:' => '🇬🇼',
    ':guyana:' => '🇬🇾',
    ':haircut-tone1:' => '💇🏻',
    ':haircut-tone2:' => '💇🏼',
    ':haircut-tone3:' => '💇🏽',
    ':haircut-tone4:' => '💇🏾',
    ':haircut-tone5:' => '💇🏿',
    ':haiti:' => '🇭🇹',
    ':hammer-pick:' => '⚒️',
    ':hand-splayed:' => '🖐️',
    ':hand-splayed-tone1:' => '🖐🏻',
    ':hand-splayed-tone2:' => '🖐🏼',
    ':hand-splayed-tone3:' => '🖐🏽',
    ':hand-splayed-tone4:' => '🖐🏾',
    ':hand-splayed-tone5:' => '🖐🏿',
    ':hand-with-index-finger-and-thumb-crossed-dark-skin-tone:' => '🫰🏿',
    ':hand-with-index-finger-and-thumb-crossed-light-skin-tone:' => '🫰🏻',
    ':hand-with-index-finger-and-thumb-crossed-medium-dark-skin-tone:' => '🫰🏾',
    ':hand-with-index-finger-and-thumb-crossed-medium-light-skin-tone:' => '🫰🏼',
    ':hand-with-index-finger-and-thumb-crossed-medium-skin-tone:' => '🫰🏽',
    ':handball-tone1:' => '🤾🏻',
    ':handball-tone2:' => '🤾🏼',
    ':handball-tone3:' => '🤾🏽',
    ':handball-tone4:' => '🤾🏾',
    ':handball-tone5:' => '🤾🏿',
    ':handshake-tone1:' => '🤝🏻',
    ':handshake-tone2:' => '🤝🏼',
    ':handshake-tone3:' => '🤝🏽',
    ':handshake-tone4:' => '🤝🏾',
    ':handshake-tone5:' => '🤝🏿',
    ':hash:' => '#️⃣',
    ':heard-mcdonald-islands:' => '🇭🇲',
    ':heart-exclamation:' => '❣️',
    ':heart-hands-dark-skin-tone:' => '🫶🏿',
    ':heart-hands-light-skin-tone:' => '🫶🏻',
    ':heart-hands-medium-dark-skin-tone:' => '🫶🏾',
    ':heart-hands-medium-light-skin-tone:' => '🫶🏼',
    ':heart-hands-medium-skin-tone:' => '🫶🏽',
    ':helmet-with-cross:' => '⛑️',
    ':homes:' => '🏘️',
    ':honduras:' => '🇭🇳',
    ':hong-kong:' => '🇭🇰',
    ':horse-racing-tone1:' => '🏇🏻',
    ':horse-racing-tone2:' => '🏇🏼',
    ':horse-racing-tone3:' => '🏇🏽',
    ':horse-racing-tone4:' => '🏇🏾',
    ':horse-racing-tone5:' => '🏇🏿',
    ':house-abandoned:' => '🏚️',
    ':hungary:' => '🇭🇺',
    ':iceland:' => '🇮🇸',
    ':index-pointing-at-the-viewer-dark-skin-tone:' => '🫵🏿',
    ':index-pointing-at-the-viewer-light-skin-tone:' => '🫵🏻',
    ':index-pointing-at-the-viewer-medium-dark-skin-tone:' => '🫵🏾',
    ':index-pointing-at-the-viewer-medium-light-skin-tone:' => '🫵🏼',
    ':index-pointing-at-the-viewer-medium-skin-tone:' => '🫵🏽',
    ':india:' => '🇮🇳',
    ':indonesia:' => '🇮🇩',
    ':information-desk-person-tone1:' => '💁🏻',
    ':information-desk-person-tone2:' => '💁🏼',
    ':information-desk-person-tone3:' => '💁🏽',
    ':information-desk-person-tone4:' => '💁🏾',
    ':information-desk-person-tone5:' => '💁🏿',
    ':iran:' => '🇮🇷',
    ':iraq:' => '🇮🇶',
    ':ireland:' => '🇮🇪',
    ':island:' => '🏝️',
    ':isle-of-man:' => '🇮🇲',
    ':israel:' => '🇮🇱',
    ':jamaica:' => '🇯🇲',
    ':jersey:' => '🇯🇪',
    ':jordan:' => '🇯🇴',
    ':juggling-tone1:' => '🤹🏻',
    ':juggling-tone2:' => '🤹🏼',
    ':juggling-tone3:' => '🤹🏽',
    ':juggling-tone4:' => '🤹🏾',
    ':juggling-tone5:' => '🤹🏿',
    ':kazakhstan:' => '🇰🇿',
    ':kenya:' => '🇰🇪',
    ':key2:' => '🗝️',
    ':kiribati:' => '🇰🇮',
    ':kiss-dark-skin-tone:' => '💏🏿',
    ':kiss-light-skin-tone:' => '💏🏻',
    ':kiss-medium-dark-skin-tone:' => '💏🏾',
    ':kiss-medium-light-skin-tone:' => '💏🏼',
    ':kiss-medium-skin-tone:' => '💏🏽',
    ':kosovo:' => '🇽🇰',
    ':kuwait:' => '🇰🇼',
    ':kyrgyzstan:' => '🇰🇬',
    ':laos:' => '🇱🇦',
    ':latvia:' => '🇱🇻',
    ':lebanon:' => '🇱🇧',
    ':left-facing-fist-tone1:' => '🤛🏻',
    ':left-facing-fist-tone2:' => '🤛🏼',
    ':left-facing-fist-tone3:' => '🤛🏽',
    ':left-facing-fist-tone4:' => '🤛🏾',
    ':left-facing-fist-tone5:' => '🤛🏿',
    ':leftwards-hand-dark-skin-tone:' => '🫲🏿',
    ':leftwards-hand-light-skin-tone:' => '🫲🏻',
    ':leftwards-hand-medium-dark-skin-tone:' => '🫲🏾',
    ':leftwards-hand-medium-light-skin-tone:' => '🫲🏼',
    ':leftwards-hand-medium-skin-tone:' => '🫲🏽',
    ':leftwards-pushing-hand-dark-skin-tone:' => '🫷🏿',
    ':leftwards-pushing-hand-light-skin-tone:' => '🫷🏻',
    ':leftwards-pushing-hand-medium-dark-skin-tone:' => '🫷🏾',
    ':leftwards-pushing-hand-medium-light-skin-tone:' => '🫷🏼',
    ':leftwards-pushing-hand-medium-skin-tone:' => '🫷🏽',
    ':leg-dark-skin-tone:' => '🦵🏿',
    ':leg-light-skin-tone:' => '🦵🏻',
    ':leg-medium-dark-skin-tone:' => '🦵🏾',
    ':leg-medium-light-skin-tone:' => '🦵🏼',
    ':leg-medium-skin-tone:' => '🦵🏽',
    ':lesotho:' => '🇱🇸',
    ':levitate:' => '🕴️',
    ':liberia:' => '🇱🇷',
    ':libya:' => '🇱🇾',
    ':liechtenstein:' => '🇱🇮',
    ':lifter:' => '🏋️',
    ':lifter-tone1:' => '🏋🏻',
    ':lifter-tone2:' => '🏋🏼',
    ':lifter-tone3:' => '🏋🏽',
    ':lifter-tone4:' => '🏋🏾',
    ':lifter-tone5:' => '🏋🏿',
    ':lithuania:' => '🇱🇹',
    ':love-you-gesture-dark-skin-tone:' => '🤟🏿',
    ':love-you-gesture-light-skin-tone:' => '🤟🏻',
    ':love-you-gesture-medium-dark-skin-tone:' => '🤟🏾',
    ':love-you-gesture-medium-light-skin-tone:' => '🤟🏼',
    ':love-you-gesture-medium-skin-tone:' => '🤟🏽',
    ':luxembourg:' => '🇱🇺',
    ':macau:' => '🇲🇴',
    ':macedonia:' => '🇲🇰',
    ':madagascar:' => '🇲🇬',
    ':mage-dark-skin-tone:' => '🧙🏿',
    ':mage-light-skin-tone:' => '🧙🏻',
    ':mage-medium-dark-skin-tone:' => '🧙🏾',
    ':mage-medium-light-skin-tone:' => '🧙🏼',
    ':mage-medium-skin-tone:' => '🧙🏽',
    ':malawi:' => '🇲🇼',
    ':malaysia:' => '🇲🇾',
    ':maldives:' => '🇲🇻',
    ':mali:' => '🇲🇱',
    ':malta:' => '🇲🇹',
    ':man-dancing-tone1:' => '🕺🏻',
    ':man-dancing-tone2:' => '🕺🏼',
    ':man-dancing-tone3:' => '🕺🏽',
    ':man-dancing-tone4:' => '🕺🏾',
    ':man-dancing-tone5:' => '🕺🏿',
    ':man-in-tuxedo-tone1:' => '🤵🏻',
    ':man-in-tuxedo-tone2:' => '🤵🏼',
    ':man-in-tuxedo-tone3:' => '🤵🏽',
    ':man-in-tuxedo-tone4:' => '🤵🏾',
    ':man-in-tuxedo-tone5:' => '🤵🏿',
    ':man-tone1:' => '👨🏻',
    ':man-tone2:' => '👨🏼',
    ':man-tone3:' => '👨🏽',
    ':man-tone4:' => '👨🏾',
    ':man-tone5:' => '👨🏿',
    ':man-with-gua-pi-mao-tone1:' => '👲🏻',
    ':man-with-gua-pi-mao-tone2:' => '👲🏼',
    ':man-with-gua-pi-mao-tone3:' => '👲🏽',
    ':man-with-gua-pi-mao-tone4:' => '👲🏾',
    ':man-with-gua-pi-mao-tone5:' => '👲🏿',
    ':man-with-turban-tone1:' => '👳🏻',
    ':man-with-turban-tone2:' => '👳🏼',
    ':man-with-turban-tone3:' => '👳🏽',
    ':man-with-turban-tone4:' => '👳🏾',
    ':man-with-turban-tone5:' => '👳🏿',
    ':map:' => '🗺️',
    ':marshall-islands:' => '🇲🇭',
    ':martinique:' => '🇲🇶',
    ':massage-tone1:' => '💆🏻',
    ':massage-tone2:' => '💆🏼',
    ':massage-tone3:' => '💆🏽',
    ':massage-tone4:' => '💆🏾',
    ':massage-tone5:' => '💆🏿',
    ':mauritania:' => '🇲🇷',
    ':mauritius:' => '🇲🇺',
    ':mayotte:' => '🇾🇹',
    ':men-holding-hands-dark-skin-tone:' => '👬🏿',
    ':men-holding-hands-light-skin-tone:' => '👬🏻',
    ':men-holding-hands-medium-dark-skin-tone:' => '👬🏾',
    ':men-holding-hands-medium-light-skin-tone:' => '👬🏼',
    ':men-holding-hands-medium-skin-tone:' => '👬🏽',
    ':merperson-dark-skin-tone:' => '🧜🏿',
    ':merperson-light-skin-tone:' => '🧜🏻',
    ':merperson-medium-dark-skin-tone:' => '🧜🏾',
    ':merperson-medium-light-skin-tone:' => '🧜🏼',
    ':merperson-medium-skin-tone:' => '🧜🏽',
    ':metal-tone1:' => '🤘🏻',
    ':metal-tone2:' => '🤘🏼',
    ':metal-tone3:' => '🤘🏽',
    ':metal-tone4:' => '🤘🏾',
    ':metal-tone5:' => '🤘🏿',
    ':mexico:' => '🇲🇽',
    ':micronesia:' => '🇫🇲',
    ':microphone2:' => '🎙️',
    ':middle-finger-tone1:' => '🖕🏻',
    ':middle-finger-tone2:' => '🖕🏼',
    ':middle-finger-tone3:' => '🖕🏽',
    ':middle-finger-tone4:' => '🖕🏾',
    ':middle-finger-tone5:' => '🖕🏿',
    ':military-medal:' => '🎖️',
    ':moldova:' => '🇲🇩',
    ':monaco:' => '🇲🇨',
    ':mongolia:' => '🇲🇳',
    ':montenegro:' => '🇲🇪',
    ':montserrat:' => '🇲🇸',
    ':morocco:' => '🇲🇦',
    ':motorboat:' => '🛥️',
    ':mountain-bicyclist-tone1:' => '🚵🏻',
    ':mountain-bicyclist-tone2:' => '🚵🏼',
    ':mountain-bicyclist-tone3:' => '🚵🏽',
    ':mountain-bicyclist-tone4:' => '🚵🏾',
    ':mountain-bicyclist-tone5:' => '🚵🏿',
    ':mouse-three-button:' => '🖱️',
    ':mozambique:' => '🇲🇿',
    ':mrs-claus-tone1:' => '🤶🏻',
    ':mrs-claus-tone2:' => '🤶🏼',
    ':mrs-claus-tone3:' => '🤶🏽',
    ':mrs-claus-tone4:' => '🤶🏾',
    ':mrs-claus-tone5:' => '🤶🏿',
    ':muscle-tone1:' => '💪🏻',
    ':muscle-tone2:' => '💪🏼',
    ':muscle-tone3:' => '💪🏽',
    ':muscle-tone4:' => '💪🏾',
    ':muscle-tone5:' => '💪🏿',
    ':myanmar:' => '🇲🇲',
    ':nail-care-tone1:' => '💅🏻',
    ':nail-care-tone2:' => '💅🏼',
    ':nail-care-tone3:' => '💅🏽',
    ':nail-care-tone4:' => '💅🏾',
    ':nail-care-tone5:' => '💅🏿',
    ':namibia:' => '🇳🇦',
    ':nauru:' => '🇳🇷',
    ':nepal:' => '🇳🇵',
    ':netherlands:' => '🇳🇱',
    ':new-caledonia:' => '🇳🇨',
    ':new-zealand:' => '🇳🇿',
    ':newspaper2:' => '🗞️',
    ':nicaragua:' => '🇳🇮',
    ':niger:' => '🇳🇪',
    ':nigeria:' => '🇳🇬',
    ':nine:' => '9️⃣',
    ':ninja-dark-skin-tone:' => '🥷🏿',
    ':ninja-light-skin-tone:' => '🥷🏻',
    ':ninja-medium-dark-skin-tone:' => '🥷🏾',
    ':ninja-medium-light-skin-tone:' => '🥷🏼',
    ':ninja-medium-skin-tone:' => '🥷🏽',
    ':niue:' => '🇳🇺',
    ':no-good-tone1:' => '🙅🏻',
    ':no-good-tone2:' => '🙅🏼',
    ':no-good-tone3:' => '🙅🏽',
    ':no-good-tone4:' => '🙅🏾',
    ':no-good-tone5:' => '🙅🏿',
    ':norfolk-island:' => '🇳🇫',
    ':north-korea:' => '🇰🇵',
    ':northern-mariana-islands:' => '🇲🇵',
    ':norway:' => '🇳🇴',
    ':nose-tone1:' => '👃🏻',
    ':nose-tone2:' => '👃🏼',
    ':nose-tone3:' => '👃🏽',
    ':nose-tone4:' => '👃🏾',
    ':nose-tone5:' => '👃🏿',
    ':notepad-spiral:' => '🗒️',
    ':oil:' => '🛢️',
    ':ok-hand-tone1:' => '👌🏻',
    ':ok-hand-tone2:' => '👌🏼',
    ':ok-hand-tone3:' => '👌🏽',
    ':ok-hand-tone4:' => '👌🏾',
    ':ok-hand-tone5:' => '👌🏿',
    ':ok-woman-tone1:' => '🙆🏻',
    ':ok-woman-tone2:' => '🙆🏼',
    ':ok-woman-tone3:' => '🙆🏽',
    ':ok-woman-tone4:' => '🙆🏾',
    ':ok-woman-tone5:' => '🙆🏿',
    ':older-man-tone1:' => '👴🏻',
    ':older-man-tone2:' => '👴🏼',
    ':older-man-tone3:' => '👴🏽',
    ':older-man-tone4:' => '👴🏾',
    ':older-man-tone5:' => '👴🏿',
    ':older-person-dark-skin-tone:' => '🧓🏿',
    ':older-person-light-skin-tone:' => '🧓🏻',
    ':older-person-medium-dark-skin-tone:' => '🧓🏾',
    ':older-person-medium-light-skin-tone:' => '🧓🏼',
    ':older-person-medium-skin-tone:' => '🧓🏽',
    ':older-woman-tone1:' => '👵🏻',
    ':older-woman-tone2:' => '👵🏼',
    ':older-woman-tone3:' => '👵🏽',
    ':older-woman-tone4:' => '👵🏾',
    ':older-woman-tone5:' => '👵🏿',
    ':oman:' => '🇴🇲',
    ':one:' => '1️⃣',
    ':open-hands-tone1:' => '👐🏻',
    ':open-hands-tone2:' => '👐🏼',
    ':open-hands-tone3:' => '👐🏽',
    ':open-hands-tone4:' => '👐🏾',
    ':open-hands-tone5:' => '👐🏿',
    ':pakistan:' => '🇵🇰',
    ':palau:' => '🇵🇼',
    ':palestinian-territories:' => '🇵🇸',
    ':palm-down-hand-dark-skin-tone:' => '🫳🏿',
    ':palm-down-hand-light-skin-tone:' => '🫳🏻',
    ':palm-down-hand-medium-dark-skin-tone:' => '🫳🏾',
    ':palm-down-hand-medium-light-skin-tone:' => '🫳🏼',
    ':palm-down-hand-medium-skin-tone:' => '🫳🏽',
    ':palm-up-hand-dark-skin-tone:' => '🫴🏿',
    ':palm-up-hand-light-skin-tone:' => '🫴🏻',
    ':palm-up-hand-medium-dark-skin-tone:' => '🫴🏾',
    ':palm-up-hand-medium-light-skin-tone:' => '🫴🏼',
    ':palm-up-hand-medium-skin-tone:' => '🫴🏽',
    ':palms-up-together-dark-skin-tone:' => '🤲🏿',
    ':palms-up-together-light-skin-tone:' => '🤲🏻',
    ':palms-up-together-medium-dark-skin-tone:' => '🤲🏾',
    ':palms-up-together-medium-light-skin-tone:' => '🤲🏼',
    ':palms-up-together-medium-skin-tone:' => '🤲🏽',
    ':panama:' => '🇵🇦',
    ':papua-new-guinea:' => '🇵🇬',
    ':paraguay:' => '🇵🇾',
    ':park:' => '🏞️',
    ':peace:' => '☮️',
    ':pen-ballpoint:' => '🖊️',
    ':pen-fountain:' => '🖋️',
    ':person-climbing-dark-skin-tone:' => '🧗🏿',
    ':person-climbing-light-skin-tone:' => '🧗🏻',
    ':person-climbing-medium-dark-skin-tone:' => '🧗🏾',
    ':person-climbing-medium-light-skin-tone:' => '🧗🏼',
    ':person-climbing-medium-skin-tone:' => '🧗🏽',
    ':person-dark-skin-tone:' => '🧑🏿',
    ':person-dark-skin-tone-beard:' => '🧔🏿',
    ':person-frowning-tone1:' => '🙍🏻',
    ':person-frowning-tone2:' => '🙍🏼',
    ':person-frowning-tone3:' => '🙍🏽',
    ':person-frowning-tone4:' => '🙍🏾',
    ':person-frowning-tone5:' => '🙍🏿',
    ':person-golfing-dark-skin-tone:' => '🏌🏿',
    ':person-golfing-light-skin-tone:' => '🏌🏻',
    ':person-golfing-medium-dark-skin-tone:' => '🏌🏾',
    ':person-golfing-medium-light-skin-tone:' => '🏌🏼',
    ':person-golfing-medium-skin-tone:' => '🏌🏽',
    ':person-in-bed-dark-skin-tone:' => '🛌🏿',
    ':person-in-bed-light-skin-tone:' => '🛌🏻',
    ':person-in-bed-medium-dark-skin-tone:' => '🛌🏾',
    ':person-in-bed-medium-light-skin-tone:' => '🛌🏼',
    ':person-in-bed-medium-skin-tone:' => '🛌🏽',
    ':person-in-lotus-position-dark-skin-tone:' => '🧘🏿',
    ':person-in-lotus-position-light-skin-tone:' => '🧘🏻',
    ':person-in-lotus-position-medium-dark-skin-tone:' => '🧘🏾',
    ':person-in-lotus-position-medium-light-skin-tone:' => '🧘🏼',
    ':person-in-lotus-position-medium-skin-tone:' => '🧘🏽',
    ':person-in-steamy-room-dark-skin-tone:' => '🧖🏿',
    ':person-in-steamy-room-light-skin-tone:' => '🧖🏻',
    ':person-in-steamy-room-medium-dark-skin-tone:' => '🧖🏾',
    ':person-in-steamy-room-medium-light-skin-tone:' => '🧖🏼',
    ':person-in-steamy-room-medium-skin-tone:' => '🧖🏽',
    ':person-in-suit-levitating-dark-skin-tone:' => '🕴🏿',
    ':person-in-suit-levitating-light-skin-tone:' => '🕴🏻',
    ':person-in-suit-levitating-medium-dark-skin-tone:' => '🕴🏾',
    ':person-in-suit-levitating-medium-light-skin-tone:' => '🕴🏼',
    ':person-in-suit-levitating-medium-skin-tone:' => '🕴🏽',
    ':person-kneeling-dark-skin-tone:' => '🧎🏿',
    ':person-kneeling-light-skin-tone:' => '🧎🏻',
    ':person-kneeling-medium-dark-skin-tone:' => '🧎🏾',
    ':person-kneeling-medium-light-skin-tone:' => '🧎🏼',
    ':person-kneeling-medium-skin-tone:' => '🧎🏽',
    ':person-light-skin-tone:' => '🧑🏻',
    ':person-light-skin-tone-beard:' => '🧔🏻',
    ':person-medium-dark-skin-tone:' => '🧑🏾',
    ':person-medium-dark-skin-tone-beard:' => '🧔🏾',
    ':person-medium-light-skin-tone:' => '🧑🏼',
    ':person-medium-light-skin-tone-beard:' => '🧔🏼',
    ':person-medium-skin-tone:' => '🧑🏽',
    ':person-medium-skin-tone-beard:' => '🧔🏽',
    ':person-standing-dark-skin-tone:' => '🧍🏿',
    ':person-standing-light-skin-tone:' => '🧍🏻',
    ':person-standing-medium-dark-skin-tone:' => '🧍🏾',
    ':person-standing-medium-light-skin-tone:' => '🧍🏼',
    ':person-standing-medium-skin-tone:' => '🧍🏽',
    ':person-with-blond-hair-tone1:' => '👱🏻',
    ':person-with-blond-hair-tone2:' => '👱🏼',
    ':person-with-blond-hair-tone3:' => '👱🏽',
    ':person-with-blond-hair-tone4:' => '👱🏾',
    ':person-with-blond-hair-tone5:' => '👱🏿',
    ':person-with-crown-dark-skin-tone:' => '🫅🏿',
    ':person-with-crown-light-skin-tone:' => '🫅🏻',
    ':person-with-crown-medium-dark-skin-tone:' => '🫅🏾',
    ':person-with-crown-medium-light-skin-tone:' => '🫅🏼',
    ':person-with-crown-medium-skin-tone:' => '🫅🏽',
    ':person-with-pouting-face-tone1:' => '🙎🏻',
    ':person-with-pouting-face-tone2:' => '🙎🏼',
    ':person-with-pouting-face-tone3:' => '🙎🏽',
    ':person-with-pouting-face-tone4:' => '🙎🏾',
    ':person-with-pouting-face-tone5:' => '🙎🏿',
    ':peru:' => '🇵🇪',
    ':philippines:' => '🇵🇭',
    ':pinched-fingers-dark-skin-tone:' => '🤌🏿',
    ':pinched-fingers-light-skin-tone:' => '🤌🏻',
    ':pinched-fingers-medium-dark-skin-tone:' => '🤌🏾',
    ':pinched-fingers-medium-light-skin-tone:' => '🤌🏼',
    ':pinched-fingers-medium-skin-tone:' => '🤌🏽',
    ':pinching-hand-dark-skin-tone:' => '🤏🏿',
    ':pinching-hand-light-skin-tone:' => '🤏🏻',
    ':pinching-hand-medium-dark-skin-tone:' => '🤏🏾',
    ':pinching-hand-medium-light-skin-tone:' => '🤏🏼',
    ':pinching-hand-medium-skin-tone:' => '🤏🏽',
    ':pitcairn-islands:' => '🇵🇳',
    ':play-pause:' => '⏯️',
    ':point-down-tone1:' => '👇🏻',
    ':point-down-tone2:' => '👇🏼',
    ':point-down-tone3:' => '👇🏽',
    ':point-down-tone4:' => '👇🏾',
    ':point-down-tone5:' => '👇🏿',
    ':point-left-tone1:' => '👈🏻',
    ':point-left-tone2:' => '👈🏼',
    ':point-left-tone3:' => '👈🏽',
    ':point-left-tone4:' => '👈🏾',
    ':point-left-tone5:' => '👈🏿',
    ':point-right-tone1:' => '👉🏻',
    ':point-right-tone2:' => '👉🏼',
    ':point-right-tone3:' => '👉🏽',
    ':point-right-tone4:' => '👉🏾',
    ':point-right-tone5:' => '👉🏿',
    ':point-up-2-tone1:' => '👆🏻',
    ':point-up-2-tone2:' => '👆🏼',
    ':point-up-2-tone3:' => '👆🏽',
    ':point-up-2-tone4:' => '👆🏾',
    ':point-up-2-tone5:' => '👆🏿',
    ':point-up-tone1:' => '☝🏻',
    ':point-up-tone2:' => '☝🏼',
    ':point-up-tone3:' => '☝🏽',
    ':point-up-tone4:' => '☝🏾',
    ':point-up-tone5:' => '☝🏿',
    ':poland:' => '🇵🇱',
    ':portugal:' => '🇵🇹',
    ':pray-tone1:' => '🙏🏻',
    ':pray-tone2:' => '🙏🏼',
    ':pray-tone3:' => '🙏🏽',
    ':pray-tone4:' => '🙏🏾',
    ':pray-tone5:' => '🙏🏿',
    ':pregnant-man-dark-skin-tone:' => '🫃🏿',
    ':pregnant-man-light-skin-tone:' => '🫃🏻',
    ':pregnant-man-medium-dark-skin-tone:' => '🫃🏾',
    ':pregnant-man-medium-light-skin-tone:' => '🫃🏼',
    ':pregnant-man-medium-skin-tone:' => '🫃🏽',
    ':pregnant-person-dark-skin-tone:' => '🫄🏿',
    ':pregnant-person-light-skin-tone:' => '🫄🏻',
    ':pregnant-person-medium-dark-skin-tone:' => '🫄🏾',
    ':pregnant-person-medium-light-skin-tone:' => '🫄🏼',
    ':pregnant-person-medium-skin-tone:' => '🫄🏽',
    ':pregnant-woman-tone1:' => '🤰🏻',
    ':pregnant-woman-tone2:' => '🤰🏼',
    ':pregnant-woman-tone3:' => '🤰🏽',
    ':pregnant-woman-tone4:' => '🤰🏾',
    ':pregnant-woman-tone5:' => '🤰🏿',
    ':prince-tone1:' => '🤴🏻',
    ':prince-tone2:' => '🤴🏼',
    ':prince-tone3:' => '🤴🏽',
    ':prince-tone4:' => '🤴🏾',
    ':prince-tone5:' => '🤴🏿',
    ':princess-tone1:' => '👸🏻',
    ':princess-tone2:' => '👸🏼',
    ':princess-tone3:' => '👸🏽',
    ':princess-tone4:' => '👸🏾',
    ':princess-tone5:' => '👸🏿',
    ':projector:' => '📽️',
    ':puerto-rico:' => '🇵🇷',
    ':punch-tone1:' => '👊🏻',
    ':punch-tone2:' => '👊🏼',
    ':punch-tone3:' => '👊🏽',
    ':punch-tone4:' => '👊🏾',
    ':punch-tone5:' => '👊🏿',
    ':qatar:' => '🇶🇦',
    ':race-car:' => '🏎️',
    ':raised-back-of-hand-tone1:' => '🤚🏻',
    ':raised-back-of-hand-tone2:' => '🤚🏼',
    ':raised-back-of-hand-tone3:' => '🤚🏽',
    ':raised-back-of-hand-tone4:' => '🤚🏾',
    ':raised-back-of-hand-tone5:' => '🤚🏿',
    ':raised-hand-tone1:' => '✋🏻',
    ':raised-hand-tone2:' => '✋🏼',
    ':raised-hand-tone3:' => '✋🏽',
    ':raised-hand-tone4:' => '✋🏾',
    ':raised-hand-tone5:' => '✋🏿',
    ':raised-hands-tone1:' => '🙌🏻',
    ':raised-hands-tone2:' => '🙌🏼',
    ':raised-hands-tone3:' => '🙌🏽',
    ':raised-hands-tone4:' => '🙌🏾',
    ':raised-hands-tone5:' => '🙌🏿',
    ':raising-hand-tone1:' => '🙋🏻',
    ':raising-hand-tone2:' => '🙋🏼',
    ':raising-hand-tone3:' => '🙋🏽',
    ':raising-hand-tone4:' => '🙋🏾',
    ':raising-hand-tone5:' => '🙋🏿',
    ':reunion:' => '🇷🇪',
    ':right-facing-fist-tone1:' => '🤜🏻',
    ':right-facing-fist-tone2:' => '🤜🏼',
    ':right-facing-fist-tone3:' => '🤜🏽',
    ':right-facing-fist-tone4:' => '🤜🏾',
    ':right-facing-fist-tone5:' => '🤜🏿',
    ':rightwards-hand-dark-skin-tone:' => '🫱🏿',
    ':rightwards-hand-light-skin-tone:' => '🫱🏻',
    ':rightwards-hand-medium-dark-skin-tone:' => '🫱🏾',
    ':rightwards-hand-medium-light-skin-tone:' => '🫱🏼',
    ':rightwards-hand-medium-skin-tone:' => '🫱🏽',
    ':rightwards-pushing-hand-dark-skin-tone:' => '🫸🏿',
    ':rightwards-pushing-hand-light-skin-tone:' => '🫸🏻',
    ':rightwards-pushing-hand-medium-dark-skin-tone:' => '🫸🏾',
    ':rightwards-pushing-hand-medium-light-skin-tone:' => '🫸🏼',
    ':rightwards-pushing-hand-medium-skin-tone:' => '🫸🏽',
    ':romania:' => '🇷🇴',
    ':rowboat-tone1:' => '🚣🏻',
    ':rowboat-tone2:' => '🚣🏼',
    ':rowboat-tone3:' => '🚣🏽',
    ':rowboat-tone4:' => '🚣🏾',
    ':rowboat-tone5:' => '🚣🏿',
    ':runner-tone1:' => '🏃🏻',
    ':runner-tone2:' => '🏃🏼',
    ':runner-tone3:' => '🏃🏽',
    ':runner-tone4:' => '🏃🏾',
    ':runner-tone5:' => '🏃🏿',
    ':rwanda:' => '🇷🇼',
    ':samoa:' => '🇼🇸',
    ':san-marino:' => '🇸🇲',
    ':santa-tone1:' => '🎅🏻',
    ':santa-tone2:' => '🎅🏼',
    ':santa-tone3:' => '🎅🏽',
    ':santa-tone4:' => '🎅🏾',
    ':santa-tone5:' => '🎅🏿',
    ':sao-tome-principe:' => '🇸🇹',
    ':satellite-orbital:' => '🛰️',
    ':saudi-arabia:' => '🇸🇦',
    ':selfie-tone1:' => '🤳🏻',
    ':selfie-tone2:' => '🤳🏼',
    ':selfie-tone3:' => '🤳🏽',
    ':selfie-tone4:' => '🤳🏾',
    ':selfie-tone5:' => '🤳🏿',
    ':senegal:' => '🇸🇳',
    ':serbia:' => '🇷🇸',
    ':seven:' => '7️⃣',
    ':seychelles:' => '🇸🇨',
    ':shrug-tone1:' => '🤷🏻',
    ':shrug-tone2:' => '🤷🏼',
    ':shrug-tone3:' => '🤷🏽',
    ':shrug-tone4:' => '🤷🏾',
    ':shrug-tone5:' => '🤷🏿',
    ':sierra-leone:' => '🇸🇱',
    ':singapore:' => '🇸🇬',
    ':sint-maarten:' => '🇸🇽',
    ':six:' => '6️⃣',
    ':skull-crossbones:' => '☠️',
    ':slovakia:' => '🇸🇰',
    ':slovenia:' => '🇸🇮',
    ':snowboarder-dark-skin-tone:' => '🏂🏿',
    ':snowboarder-light-skin-tone:' => '🏂🏻',
    ':snowboarder-medium-dark-skin-tone:' => '🏂🏾',
    ':snowboarder-medium-light-skin-tone:' => '🏂🏼',
    ':snowboarder-medium-skin-tone:' => '🏂🏽',
    ':snowman2:' => '☃️',
    ':solomon-islands:' => '🇸🇧',
    ':somalia:' => '🇸🇴',
    ':south-africa:' => '🇿🇦',
    ':south-georgia-south-sandwich-islands:' => '🇬🇸',
    ':south-sudan:' => '🇸🇸',
    ':speech-left:' => '🗨️',
    ':spy:' => '🕵️',
    ':spy-tone1:' => '🕵🏻',
    ':spy-tone2:' => '🕵🏼',
    ':spy-tone3:' => '🕵🏽',
    ':spy-tone4:' => '🕵🏾',
    ':spy-tone5:' => '🕵🏿',
    ':sri-lanka:' => '🇱🇰',
    ':st-barthelemy:' => '🇧🇱',
    ':st-helena:' => '🇸🇭',
    ':st-kitts-nevis:' => '🇰🇳',
    ':st-lucia:' => '🇱🇨',
    ':st-martin:' => '🇲🇫',
    ':st-pierre-miquelon:' => '🇵🇲',
    ':st-vincent-grenadines:' => '🇻🇨',
    ':sudan:' => '🇸🇩',
    ':superhero-dark-skin-tone:' => '🦸🏿',
    ':superhero-light-skin-tone:' => '🦸🏻',
    ':superhero-medium-dark-skin-tone:' => '🦸🏾',
    ':superhero-medium-light-skin-tone:' => '🦸🏼',
    ':superhero-medium-skin-tone:' => '🦸🏽',
    ':supervillain-dark-skin-tone:' => '🦹🏿',
    ':supervillain-light-skin-tone:' => '🦹🏻',
    ':supervillain-medium-dark-skin-tone:' => '🦹🏾',
    ':supervillain-medium-light-skin-tone:' => '🦹🏼',
    ':supervillain-medium-skin-tone:' => '🦹🏽',
    ':surfer-tone1:' => '🏄🏻',
    ':surfer-tone2:' => '🏄🏼',
    ':surfer-tone3:' => '🏄🏽',
    ':surfer-tone4:' => '🏄🏾',
    ':surfer-tone5:' => '🏄🏿',
    ':suriname:' => '🇸🇷',
    ':svalbard-jan-mayen:' => '🇸🇯',
    ':swaziland:' => '🇸🇿',
    ':sweden:' => '🇸🇪',
    ':swimmer-tone1:' => '🏊🏻',
    ':swimmer-tone2:' => '🏊🏼',
    ':swimmer-tone3:' => '🏊🏽',
    ':swimmer-tone4:' => '🏊🏾',
    ':swimmer-tone5:' => '🏊🏿',
    ':switzerland:' => '🇨🇭',
    ':syria:' => '🇸🇾',
    ':taiwan:' => '🇹🇼',
    ':tajikistan:' => '🇹🇯',
    ':tanzania:' => '🇹🇿',
    ':thailand:' => '🇹🇭',
    ':three:' => '3️⃣',
    ':thumbsdown-tone1:' => '👎🏻',
    ':thumbsdown-tone2:' => '👎🏼',
    ':thumbsdown-tone3:' => '👎🏽',
    ':thumbsdown-tone4:' => '👎🏾',
    ':thumbsdown-tone5:' => '👎🏿',
    ':thumbsup-tone1:' => '👍🏻',
    ':thumbsup-tone2:' => '👍🏼',
    ':thumbsup-tone3:' => '👍🏽',
    ':thumbsup-tone4:' => '👍🏾',
    ':thumbsup-tone5:' => '👍🏿',
    ':thunder-cloud-rain:' => '⛈️',
    ':timer:' => '⏲️',
    ':timor-leste:' => '🇹🇱',
    ':togo:' => '🇹🇬',
    ':tokelau:' => '🇹🇰',
    ':tonga:' => '🇹🇴',
    ':tools:' => '🛠️',
    ':tr:' => '🇹🇷',
    ':track-next:' => '⏭️',
    ':track-previous:' => '⏮️',
    ':trinidad-tobago:' => '🇹🇹',
    ':tristan-da-cunha:' => '🇹🇦',
    ':tunisia:' => '🇹🇳',
    ':turkmenistan:' => '🇹🇲',
    ':turks-caicos-islands:' => '🇹🇨',
    ':tuvalu:' => '🇹🇻',
    ':two:' => '2️⃣',
    ':uganda:' => '🇺🇬',
    ':ukraine:' => '🇺🇦',
    ':umbrella2:' => '☂️',
    ':united-arab-emirates:' => '🇦🇪',
    ':united-nations:' => '🇺🇳',
    ':urn:' => '⚱️',
    ':uruguay:' => '🇺🇾',
    ':us-outlying-islands:' => '🇺🇲',
    ':us-virgin-islands:' => '🇻🇮',
    ':uzbekistan:' => '🇺🇿',
    ':v-tone1:' => '✌🏻',
    ':v-tone2:' => '✌🏼',
    ':v-tone3:' => '✌🏽',
    ':v-tone4:' => '✌🏾',
    ':v-tone5:' => '✌🏿',
    ':vampire-dark-skin-tone:' => '🧛🏿',
    ':vampire-light-skin-tone:' => '🧛🏻',
    ':vampire-medium-dark-skin-tone:' => '🧛🏾',
    ':vampire-medium-light-skin-tone:' => '🧛🏼',
    ':vampire-medium-skin-tone:' => '🧛🏽',
    ':vanuatu:' => '🇻🇺',
    ':vatican-city:' => '🇻🇦',
    ':venezuela:' => '🇻🇪',
    ':vietnam:' => '🇻🇳',
    ':vulcan-tone1:' => '🖖🏻',
    ':vulcan-tone2:' => '🖖🏼',
    ':vulcan-tone3:' => '🖖🏽',
    ':vulcan-tone4:' => '🖖🏾',
    ':vulcan-tone5:' => '🖖🏿',
    ':walking-tone1:' => '🚶🏻',
    ':walking-tone2:' => '🚶🏼',
    ':walking-tone3:' => '🚶🏽',
    ':walking-tone4:' => '🚶🏾',
    ':walking-tone5:' => '🚶🏿',
    ':wallis-futuna:' => '🇼🇫',
    ':water-polo-tone1:' => '🤽🏻',
    ':water-polo-tone2:' => '🤽🏼',
    ':water-polo-tone3:' => '🤽🏽',
    ':water-polo-tone4:' => '🤽🏾',
    ':water-polo-tone5:' => '🤽🏿',
    ':wave-tone1:' => '👋🏻',
    ':wave-tone2:' => '👋🏼',
    ':wave-tone3:' => '👋🏽',
    ':wave-tone4:' => '👋🏾',
    ':wave-tone5:' => '👋🏿',
    ':western-sahara:' => '🇪🇭',
    ':white-sun-cloud:' => '🌥️',
    ':white-sun-rain-cloud:' => '🌦️',
    ':white-sun-small-cloud:' => '🌤️',
    ':woman-and-man-holding-hands-dark-skin-tone:' => '👫🏿',
    ':woman-and-man-holding-hands-light-skin-tone:' => '👫🏻',
    ':woman-and-man-holding-hands-medium-dark-skin-tone:' => '👫🏾',
    ':woman-and-man-holding-hands-medium-light-skin-tone:' => '👫🏼',
    ':woman-and-man-holding-hands-medium-skin-tone:' => '👫🏽',
    ':woman-tone1:' => '👩🏻',
    ':woman-tone2:' => '👩🏼',
    ':woman-tone3:' => '👩🏽',
    ':woman-tone4:' => '👩🏾',
    ':woman-tone5:' => '👩🏿',
    ':woman-with-headscarf-dark-skin-tone:' => '🧕🏿',
    ':woman-with-headscarf-light-skin-tone:' => '🧕🏻',
    ':woman-with-headscarf-medium-dark-skin-tone:' => '🧕🏾',
    ':woman-with-headscarf-medium-light-skin-tone:' => '🧕🏼',
    ':woman-with-headscarf-medium-skin-tone:' => '🧕🏽',
    ':women-holding-hands-dark-skin-tone:' => '👭🏿',
    ':women-holding-hands-light-skin-tone:' => '👭🏻',
    ':women-holding-hands-medium-dark-skin-tone:' => '👭🏾',
    ':women-holding-hands-medium-light-skin-tone:' => '👭🏼',
    ':women-holding-hands-medium-skin-tone:' => '👭🏽',
    ':writing-hand-tone1:' => '✍🏻',
    ':writing-hand-tone2:' => '✍🏼',
    ':writing-hand-tone3:' => '✍🏽',
    ':writing-hand-tone4:' => '✍🏾',
    ':writing-hand-tone5:' => '✍🏿',
    ':yemen:' => '🇾🇪',
    ':zambia:' => '🇿🇲',
    ':zero:' => '0️⃣',
    ':zimbabwe:' => '🇿🇼',
    ':artist:' => '🧑‍🎨',
    ':astronaut:' => '🧑‍🚀',
    ':bald-man:' => '👨‍🦲',
    ':bald-person:' => '🧑‍🦲',
    ':bald-woman:' => '👩‍🦲',
    ':black-bird:' => '🐦‍⬛',
    ':black-cat:' => '🐈‍⬛',
    ':brown-mushroom:' => '🍄‍🟫',
    ':cook:' => '🧑‍🍳',
    ':curly-haired-man:' => '👨‍🦱',
    ':curly-haired-person:' => '🧑‍🦱',
    ':curly-haired-woman:' => '👩‍🦱',
    ':face-exhaling:' => '😮‍💨',
    ':face-with-spiral-eyes:' => '😵‍💫',
    ':factory-worker:' => '🧑‍🏭',
    ':family-adult-child:' => '🧑‍🧒',
    ':farmer:' => '🧑‍🌾',
    ':female-artist:' => '👩‍🎨',
    ':female-astronaut:' => '👩‍🚀',
    ':female-cook:' => '👩‍🍳',
    ':female-factory-worker:' => '👩‍🏭',
    ':female-farmer:' => '👩‍🌾',
    ':female-firefighter:' => '👩‍🚒',
    ':female-mechanic:' => '👩‍🔧',
    ':female-office-worker:' => '👩‍💼',
    ':female-scientist:' => '👩‍🔬',
    ':female-singer:' => '👩‍🎤',
    ':female-student:' => '👩‍🎓',
    ':female-teacher:' => '👩‍🏫',
    ':female-technologist:' => '👩‍💻',
    ':firefighter:' => '🧑‍🚒',
    ':keycap-star:' => '*️⃣',
    ':lime:' => '🍋‍🟩',
    ':male-artist:' => '👨‍🎨',
    ':male-astronaut:' => '👨‍🚀',
    ':male-cook:' => '👨‍🍳',
    ':male-factory-worker:' => '👨‍🏭',
    ':male-farmer:' => '👨‍🌾',
    ':male-firefighter:' => '👨‍🚒',
    ':male-mechanic:' => '👨‍🔧',
    ':male-office-worker:' => '👨‍💼',
    ':male-scientist:' => '👨‍🔬',
    ':male-singer:' => '👨‍🎤',
    ':male-student:' => '👨‍🎓',
    ':male-teacher:' => '👨‍🏫',
    ':male-technologist:' => '👨‍💻',
    ':man-boy:' => '👨‍👦',
    ':man-feeding-baby:' => '👨‍🍼',
    ':man-girl:' => '👨‍👧',
    ':man-in-manual-wheelchair:' => '👨‍🦽',
    ':man-in-motorized-wheelchair:' => '👨‍🦼',
    ':man-with-probing-cane:' => '👨‍🦯',
    ':mechanic:' => '🧑‍🔧',
    ':mx-claus:' => '🧑‍🎄',
    ':office-worker:' => '🧑‍💼',
    ':person-feeding-baby:' => '🧑‍🍼',
    ':person-in-manual-wheelchair:' => '🧑‍🦽',
    ':person-in-motorized-wheelchair:' => '🧑‍🦼',
    ':person-with-probing-cane:' => '🧑‍🦯',
    ':phoenix:' => '🐦‍🔥',
    ':red-haired-man:' => '👨‍🦰',
    ':red-haired-person:' => '🧑‍🦰',
    ':red-haired-woman:' => '👩‍🦰',
    ':scientist:' => '🧑‍🔬',
    ':service-dog:' => '🐕‍🦺',
    ':singer:' => '🧑‍🎤',
    ':student:' => '🧑‍🎓',
    ':teacher:' => '🧑‍🏫',
    ':technologist:' => '🧑‍💻',
    ':white-haired-man:' => '👨‍🦳',
    ':white-haired-person:' => '🧑‍🦳',
    ':white-haired-woman:' => '👩‍🦳',
    ':woman-boy:' => '👩‍👦',
    ':woman-feeding-baby:' => '👩‍🍼',
    ':woman-girl:' => '👩‍👧',
    ':woman-in-manual-wheelchair:' => '👩‍🦽',
    ':woman-in-motorized-wheelchair:' => '👩‍🦼',
    ':woman-with-probing-cane:' => '👩‍🦯',
    ':basketball-man:' => '⛹‍♂',
    ':basketball-woman:' => '⛹‍♀',
    ':biking-man:' => '🚴‍♂',
    ':biking-woman:' => '🚴‍♀',
    ':blond-haired-man:' => '👱‍♂️',
    ':blond-haired-woman:' => '👱‍♀️',
    ':blonde-woman:' => '👱‍♀',
    ':bouncing-ball-man:' => '⛹‍♂',
    ':bouncing-ball-woman:' => '⛹‍♀',
    ':bowing-man:' => '🙇‍♂',
    ':bowing-woman:' => '🙇‍♀',
    ':climbing-man:' => '🧗‍♂',
    ':climbing-woman:' => '🧗‍♀',
    ':construction-worker-man:' => '👷‍♂',
    ':construction-worker-woman:' => '👷‍♀',
    ':dancing-men:' => '👯‍♂',
    ':dancing-women:' => '👯‍♀',
    ':deaf-man:' => '🧏‍♂️',
    ':deaf-woman:' => '🧏‍♀️',
    ':elf-man:' => '🧝‍♂',
    ':elf-woman:' => '🧝‍♀',
    ':eye-speech-bubble:' => '👁‍🗨',
    ':face-in-clouds:' => '😶‍🌫️',
    ':fairy-man:' => '🧚‍♂',
    ':fairy-woman:' => '🧚‍♀',
    ':family-man-boy:' => '👨‍👦',
    ':family-man-girl:' => '👨‍👧',
    ':family-woman-boy:' => '👩‍👦',
    ':family-woman-girl:' => '👩‍👧',
    ':female-detective:' => '🕵️‍♀️',
    ':frowning-man:' => '🙍‍♂',
    ':frowning-woman:' => '🙍‍♀',
    ':genie-man:' => '🧞‍♂',
    ':genie-woman:' => '🧞‍♀',
    ':golfing-man:' => '🏌‍♂',
    ':golfing-woman:' => '🏌‍♀',
    ':guardswoman:' => '💂‍♀',
    ':haircut-man:' => '💇‍♂',
    ':haircut-woman:' => '💇‍♀',
    ':health-worker:' => '🧑‍⚕️',
    ':heart-on-fire:' => '❤️‍🔥',
    ':judge:' => '🧑‍⚖️',
    ':kneeling-man:' => '🧎‍♂',
    ':kneeling-woman:' => '🧎‍♀',
    ':lotus-position-man:' => '🧘‍♂',
    ':lotus-position-woman:' => '🧘‍♀',
    ':mage-man:' => '🧙‍♂',
    ':mage-woman:' => '🧙‍♀',
    ':male-detective:' => '🕵️‍♂️',
    ':man-artist:' => '👨‍🎨',
    ':man-astronaut:' => '👨‍🚀',
    ':man-bald:' => '👨‍🦲',
    ':man-beard:' => '🧔‍♂️',
    ':man-cartwheeling:' => '🤸‍♂️',
    ':man-cook:' => '👨‍🍳',
    ':man-curly-hair:' => '👨‍🦱',
    ':man-facepalming:' => '🤦‍♂️',
    ':man-factory-worker:' => '👨‍🏭',
    ':man-farmer:' => '👨‍🌾',
    ':man-firefighter:' => '👨‍🚒',
    ':man-health-worker:' => '👨‍⚕️',
    ':man-in-tuxedo:' => '🤵‍♂️',
    ':man-judge:' => '👨‍⚖️',
    ':man-juggling:' => '🤹‍♂️',
    ':man-mechanic:' => '👨‍🔧',
    ':man-office-worker:' => '👨‍💼',
    ':man-pilot:' => '👨‍✈️',
    ':man-playing-handball:' => '🤾‍♂️',
    ':man-playing-water-polo:' => '🤽‍♂️',
    ':man-red-hair:' => '👨‍🦰',
    ':man-scientist:' => '👨‍🔬',
    ':man-shrugging:' => '🤷‍♂️',
    ':man-singer:' => '👨‍🎤',
    ':man-student:' => '👨‍🎓',
    ':man-teacher:' => '👨‍🏫',
    ':man-technologist:' => '👨‍💻',
    ':man-white-hair:' => '👨‍🦳',
    ':man-with-veil:' => '👰‍♂️',
    ':man-with-white-cane:' => '👨‍🦯',
    ':massage-man:' => '💆‍♂',
    ':massage-woman:' => '💆‍♀',
    ':men-wrestling:' => '🤼‍♂️',
    ':mending-heart:' => '❤️‍🩹',
    ':mermaid:' => '🧜‍♀️',
    ':merman:' => '🧜‍♂️',
    ':mountain-biking-man:' => '🚵‍♂',
    ':mountain-biking-woman:' => '🚵‍♀',
    ':ng-man:' => '🙅‍♂',
    ':ng-woman:' => '🙅‍♀',
    ':no-good-man:' => '🙅‍♂',
    ':no-good-woman:' => '🙅‍♀',
    ':ok-man:' => '🙆‍♂',
    ':person-bald:' => '🧑‍🦲',
    ':person-curly-hair:' => '🧑‍🦱',
    ':person-red-hair:' => '🧑‍🦰',
    ':person-white-hair:' => '🧑‍🦳',
    ':person-with-white-cane:' => '🧑‍🦯',
    ':pilot:' => '🧑‍✈️',
    ':pirate-flag:' => '🏴‍☠️',
    ':polar-bear:' => '🐻‍❄️',
    ':policeman:' => '👮‍♂',
    ':policewoman:' => '👮‍♀',
    ':pouting-man:' => '🙎‍♂',
    ':pouting-woman:' => '🙎‍♀',
    ':rainbow-flag:' => '🏳️‍🌈',
    ':raising-hand-man:' => '🙋‍♂',
    ':raising-hand-woman:' => '🙋‍♀',
    ':rowing-man:' => '🚣‍♂',
    ':rowing-woman:' => '🚣‍♀',
    ':running-man:' => '🏃‍♂',
    ':running-woman:' => '🏃‍♀',
    ':sassy-man:' => '💁‍♂',
    ':sassy-woman:' => '💁‍♀',
    ':sauna-man:' => '🧖‍♂',
    ':sauna-woman:' => '🧖‍♀',
    ':standing-man:' => '🧍‍♂',
    ':standing-woman:' => '🧍‍♀',
    ':superhero-man:' => '🦸‍♂',
    ':superhero-woman:' => '🦸‍♀',
    ':supervillain-man:' => '🦹‍♂',
    ':supervillain-woman:' => '🦹‍♀',
    ':surfing-man:' => '🏄‍♂',
    ':surfing-woman:' => '🏄‍♀',
    ':swimming-man:' => '🏊‍♂',
    ':swimming-woman:' => '🏊‍♀',
    ':tipping-hand-man:' => '💁‍♂',
    ':tipping-hand-woman:' => '💁‍♀',
    ':transgender-flag:' => '🏳️‍⚧️',
    ':vampire-man:' => '🧛‍♂',
    ':vampire-woman:' => '🧛‍♀',
    ':walking-man:' => '🚶‍♂',
    ':walking-woman:' => '🚶‍♀',
    ':weight-lifting-man:' => '🏋‍♂',
    ':weight-lifting-woman:' => '🏋‍♀',
    ':woman-artist:' => '👩‍🎨',
    ':woman-astronaut:' => '👩‍🚀',
    ':woman-bald:' => '👩‍🦲',
    ':woman-beard:' => '🧔‍♀️',
    ':woman-cartwheeling:' => '🤸‍♀️',
    ':woman-cook:' => '👩‍🍳',
    ':woman-curly-hair:' => '👩‍🦱',
    ':woman-facepalming:' => '🤦‍♀️',
    ':woman-factory-worker:' => '👩‍🏭',
    ':woman-farmer:' => '👩‍🌾',
    ':woman-firefighter:' => '👩‍🚒',
    ':woman-health-worker:' => '👩‍⚕️',
    ':woman-in-tuxedo:' => '🤵‍♀️',
    ':woman-judge:' => '👩‍⚖️',
    ':woman-juggling:' => '🤹‍♀️',
    ':woman-mechanic:' => '👩‍🔧',
    ':woman-office-worker:' => '👩‍💼',
    ':woman-pilot:' => '👩‍✈️',
    ':woman-playing-handball:' => '🤾‍♀️',
    ':woman-playing-water-polo:' => '🤽‍♀️',
    ':woman-red-hair:' => '👩‍🦰',
    ':woman-scientist:' => '👩‍🔬',
    ':woman-shrugging:' => '🤷‍♀️',
    ':woman-singer:' => '👩‍🎤',
    ':woman-student:' => '👩‍🎓',
    ':woman-teacher:' => '👩‍🏫',
    ':woman-technologist:' => '👩‍💻',
    ':woman-white-hair:' => '👩‍🦳',
    ':woman-with-turban:' => '👳‍♀',
    ':woman-with-veil:' => '👰‍♀️',
    ':woman-with-white-cane:' => '👩‍🦯',
    ':women-wrestling:' => '🤼‍♀️',
    ':zombie-man:' => '🧟‍♂',
    ':zombie-woman:' => '🧟‍♀',
    ':broken-chain:' => '⛓️‍💥',
    ':female-construction-worker:' => '👷‍♀️',
    ':female-doctor:' => '👩‍⚕️',
    ':female-elf:' => '🧝‍♀️',
    ':female-fairy:' => '🧚‍♀️',
    ':female-genie:' => '🧞‍♀️',
    ':female-guard:' => '💂‍♀️',
    ':female-judge:' => '👩‍⚖️',
    ':female-mage:' => '🧙‍♀️',
    ':female-pilot:' => '👩‍✈️',
    ':female-police-officer:' => '👮‍♀️',
    ':female-superhero:' => '🦸‍♀️',
    ':female-supervillain:' => '🦹‍♀️',
    ':female-vampire:' => '🧛‍♀️',
    ':female-zombie:' => '🧟‍♀️',
    ':head-shaking-horizontally:' => '🙂‍↔️',
    ':head-shaking-vertically:' => '🙂‍↕️',
    ':male-construction-worker:' => '👷‍♂️',
    ':male-doctor:' => '👨‍⚕️',
    ':male-elf:' => '🧝‍♂️',
    ':male-fairy:' => '🧚‍♂️',
    ':male-genie:' => '🧞‍♂️',
    ':male-guard:' => '💂‍♂️',
    ':male-judge:' => '👨‍⚖️',
    ':male-mage:' => '🧙‍♂️',
    ':male-pilot:' => '👨‍✈️',
    ':male-police-officer:' => '👮‍♂️',
    ':male-superhero:' => '🦸‍♂️',
    ':male-supervillain:' => '🦹‍♂️',
    ':male-vampire:' => '🧛‍♂️',
    ':male-zombie:' => '🧟‍♂️',
    ':man-biking:' => '🚴‍♂️',
    ':man-bowing:' => '🙇‍♂️',
    ':man-climbing:' => '🧗‍♂️',
    ':man-frowning:' => '🙍‍♂️',
    ':man-gesturing-no:' => '🙅‍♂️',
    ':man-gesturing-ok:' => '🙆‍♂️',
    ':man-getting-haircut:' => '💇‍♂️',
    ':man-getting-massage:' => '💆‍♂️',
    ':man-in-lotus-position:' => '🧘‍♂️',
    ':man-in-steamy-room:' => '🧖‍♂️',
    ':man-kneeling:' => '🧎‍♂️',
    ':man-mountain-biking:' => '🚵‍♂️',
    ':man-pouting:' => '🙎‍♂️',
    ':man-raising-hand:' => '🙋‍♂️',
    ':man-rowing-boat:' => '🚣‍♂️',
    ':man-running:' => '🏃‍♂️',
    ':man-standing:' => '🧍‍♂️',
    ':man-surfing:' => '🏄‍♂️',
    ':man-swimming:' => '🏊‍♂️',
    ':man-tipping-hand:' => '💁‍♂️',
    ':man-walking:' => '🚶‍♂️',
    ':man-wearing-turban:' => '👳‍♂️',
    ':man-with-beard:' => '🧔‍♂️',
    ':man-with-bunny-ears-partying:' => '👯‍♂️',
    ':man-wrestling:' => '🤼‍♂️',
    ':men-with-bunny-ears-partying:' => '👯‍♂️',
    ':person-kneeling-facing-right:' => '🧎‍➡️',
    ':person-running-facing-right:' => '🏃‍➡️',
    ':person-walking-facing-right:' => '🚶‍➡️',
    ':woman-biking:' => '🚴‍♀️',
    ':woman-bowing:' => '🙇‍♀️',
    ':woman-climbing:' => '🧗‍♀️',
    ':woman-frowning:' => '🙍‍♀️',
    ':woman-gesturing-no:' => '🙅‍♀️',
    ':woman-gesturing-ok:' => '🙆‍♀️',
    ':woman-getting-haircut:' => '💇‍♀️',
    ':woman-getting-massage:' => '💆‍♀️',
    ':woman-in-lotus-position:' => '🧘‍♀️',
    ':woman-in-steamy-room:' => '🧖‍♀️',
    ':woman-kneeling:' => '🧎‍♀️',
    ':woman-mountain-biking:' => '🚵‍♀️',
    ':woman-pouting:' => '🙎‍♀️',
    ':woman-raising-hand:' => '🙋‍♀️',
    ':woman-rowing-boat:' => '🚣‍♀️',
    ':woman-running:' => '🏃‍♀️',
    ':woman-standing:' => '🧍‍♀️',
    ':woman-surfing:' => '🏄‍♀️',
    ':woman-swimming:' => '🏊‍♀️',
    ':woman-tipping-hand:' => '💁‍♀️',
    ':woman-walking:' => '🚶‍♀️',
    ':woman-wearing-turban:' => '👳‍♀️',
    ':woman-with-beard:' => '🧔‍♀️',
    ':woman-with-bunny-ears-partying:' => '👯‍♀️',
    ':woman-wrestling:' => '🤼‍♀️',
    ':women-with-bunny-ears-partying:' => '👯‍♀️',
    ':artist-dark-skin-tone:' => '🧑🏿‍🎨',
    ':artist-light-skin-tone:' => '🧑🏻‍🎨',
    ':artist-medium-dark-skin-tone:' => '🧑🏾‍🎨',
    ':artist-medium-light-skin-tone:' => '🧑🏼‍🎨',
    ':artist-medium-skin-tone:' => '🧑🏽‍🎨',
    ':astronaut-dark-skin-tone:' => '🧑🏿‍🚀',
    ':astronaut-light-skin-tone:' => '🧑🏻‍🚀',
    ':astronaut-medium-dark-skin-tone:' => '🧑🏾‍🚀',
    ':astronaut-medium-light-skin-tone:' => '🧑🏼‍🚀',
    ':astronaut-medium-skin-tone:' => '🧑🏽‍🚀',
    ':cook-dark-skin-tone:' => '🧑🏿‍🍳',
    ':cook-light-skin-tone:' => '🧑🏻‍🍳',
    ':cook-medium-dark-skin-tone:' => '🧑🏾‍🍳',
    ':cook-medium-light-skin-tone:' => '🧑🏼‍🍳',
    ':cook-medium-skin-tone:' => '🧑🏽‍🍳',
    ':factory-worker-dark-skin-tone:' => '🧑🏿‍🏭',
    ':factory-worker-light-skin-tone:' => '🧑🏻‍🏭',
    ':factory-worker-medium-dark-skin-tone:' => '🧑🏾‍🏭',
    ':factory-worker-medium-light-skin-tone:' => '🧑🏼‍🏭',
    ':factory-worker-medium-skin-tone:' => '🧑🏽‍🏭',
    ':farmer-dark-skin-tone:' => '🧑🏿‍🌾',
    ':farmer-light-skin-tone:' => '🧑🏻‍🌾',
    ':farmer-medium-dark-skin-tone:' => '🧑🏾‍🌾',
    ':farmer-medium-light-skin-tone:' => '🧑🏼‍🌾',
    ':farmer-medium-skin-tone:' => '🧑🏽‍🌾',
    ':firefighter-dark-skin-tone:' => '🧑🏿‍🚒',
    ':firefighter-light-skin-tone:' => '🧑🏻‍🚒',
    ':firefighter-medium-dark-skin-tone:' => '🧑🏾‍🚒',
    ':firefighter-medium-light-skin-tone:' => '🧑🏼‍🚒',
    ':firefighter-medium-skin-tone:' => '🧑🏽‍🚒',
    ':gay-pride-flag:' => '🏳️‍🌈',
    ':man-artist-dark-skin-tone:' => '👨🏿‍🎨',
    ':man-artist-light-skin-tone:' => '👨🏻‍🎨',
    ':man-artist-medium-dark-skin-tone:' => '👨🏾‍🎨',
    ':man-artist-medium-light-skin-tone:' => '👨🏼‍🎨',
    ':man-artist-medium-skin-tone:' => '👨🏽‍🎨',
    ':man-astronaut-dark-skin-tone:' => '👨🏿‍🚀',
    ':man-astronaut-light-skin-tone:' => '👨🏻‍🚀',
    ':man-astronaut-medium-dark-skin-tone:' => '👨🏾‍🚀',
    ':man-astronaut-medium-light-skin-tone:' => '👨🏼‍🚀',
    ':man-astronaut-medium-skin-tone:' => '👨🏽‍🚀',
    ':man-blond-hair:' => '👱‍♂️',
    ':man-construction-worker:' => '👷‍♂️',
    ':man-cook-dark-skin-tone:' => '👨🏿‍🍳',
    ':man-cook-light-skin-tone:' => '👨🏻‍🍳',
    ':man-cook-medium-dark-skin-tone:' => '👨🏾‍🍳',
    ':man-cook-medium-light-skin-tone:' => '👨🏼‍🍳',
    ':man-cook-medium-skin-tone:' => '👨🏽‍🍳',
    ':man-dark-skin-tone-bald:' => '👨🏿‍🦲',
    ':man-dark-skin-tone-curly-hair:' => '👨🏿‍🦱',
    ':man-dark-skin-tone-red-hair:' => '👨🏿‍🦰',
    ':man-dark-skin-tone-white-hair:' => '👨🏿‍🦳',
    ':man-elf:' => '🧝‍♂️',
    ':man-factory-worker-dark-skin-tone:' => '👨🏿‍🏭',
    ':man-factory-worker-light-skin-tone:' => '👨🏻‍🏭',
    ':man-factory-worker-medium-dark-skin-tone:' => '👨🏾‍🏭',
    ':man-factory-worker-medium-light-skin-tone:' => '👨🏼‍🏭',
    ':man-factory-worker-medium-skin-tone:' => '👨🏽‍🏭',
    ':man-fairy:' => '🧚‍♂️',
    ':man-farmer-dark-skin-tone:' => '👨🏿‍🌾',
    ':man-farmer-light-skin-tone:' => '👨🏻‍🌾',
    ':man-farmer-medium-dark-skin-tone:' => '👨🏾‍🌾',
    ':man-farmer-medium-light-skin-tone:' => '👨🏼‍🌾',
    ':man-farmer-medium-skin-tone:' => '👨🏽‍🌾',
    ':man-feeding-baby-dark-skin-tone:' => '👨🏿‍🍼',
    ':man-feeding-baby-light-skin-tone:' => '👨🏻‍🍼',
    ':man-feeding-baby-medium-dark-skin-tone:' => '👨🏾‍🍼',
    ':man-feeding-baby-medium-light-skin-tone:' => '👨🏼‍🍼',
    ':man-feeding-baby-medium-skin-tone:' => '👨🏽‍🍼',
    ':man-firefighter-dark-skin-tone:' => '👨🏿‍🚒',
    ':man-firefighter-light-skin-tone:' => '👨🏻‍🚒',
    ':man-firefighter-medium-dark-skin-tone:' => '👨🏾‍🚒',
    ':man-firefighter-medium-light-skin-tone:' => '👨🏼‍🚒',
    ':man-firefighter-medium-skin-tone:' => '👨🏽‍🚒',
    ':man-genie:' => '🧞‍♂️',
    ':man-guard:' => '💂‍♂️',
    ':man-in-manual-wheelchair-dark-skin-tone:' => '👨🏿‍🦽',
    ':man-in-manual-wheelchair-light-skin-tone:' => '👨🏻‍🦽',
    ':man-in-manual-wheelchair-medium-dark-skin-tone:' => '👨🏾‍🦽',
    ':man-in-manual-wheelchair-medium-light-skin-tone:' => '👨🏼‍🦽',
    ':man-in-manual-wheelchair-medium-skin-tone:' => '👨🏽‍🦽',
    ':man-in-motorized-wheelchair-dark-skin-tone:' => '👨🏿‍🦼',
    ':man-in-motorized-wheelchair-light-skin-tone:' => '👨🏻‍🦼',
    ':man-in-motorized-wheelchair-medium-dark-skin-tone:' => '👨🏾‍🦼',
    ':man-in-motorized-wheelchair-medium-light-skin-tone:' => '👨🏼‍🦼',
    ':man-in-motorized-wheelchair-medium-skin-tone:' => '👨🏽‍🦼',
    ':man-light-skin-tone-bald:' => '👨🏻‍🦲',
    ':man-light-skin-tone-curly-hair:' => '👨🏻‍🦱',
    ':man-light-skin-tone-red-hair:' => '👨🏻‍🦰',
    ':man-light-skin-tone-white-hair:' => '👨🏻‍🦳',
    ':man-mage:' => '🧙‍♂️',
    ':man-mechanic-dark-skin-tone:' => '👨🏿‍🔧',
    ':man-mechanic-light-skin-tone:' => '👨🏻‍🔧',
    ':man-mechanic-medium-dark-skin-tone:' => '👨🏾‍🔧',
    ':man-mechanic-medium-light-skin-tone:' => '👨🏼‍🔧',
    ':man-mechanic-medium-skin-tone:' => '👨🏽‍🔧',
    ':man-medium-dark-skin-tone-bald:' => '👨🏾‍🦲',
    ':man-medium-dark-skin-tone-curly-hair:' => '👨🏾‍🦱',
    ':man-medium-dark-skin-tone-red-hair:' => '👨🏾‍🦰',
    ':man-medium-dark-skin-tone-white-hair:' => '👨🏾‍🦳',
    ':man-medium-light-skin-tone-bald:' => '👨🏼‍🦲',
    ':man-medium-light-skin-tone-curly-hair:' => '👨🏼‍🦱',
    ':man-medium-light-skin-tone-red-hair:' => '👨🏼‍🦰',
    ':man-medium-light-skin-tone-white-hair:' => '👨🏼‍🦳',
    ':man-medium-skin-tone-bald:' => '👨🏽‍🦲',
    ':man-medium-skin-tone-curly-hair:' => '👨🏽‍🦱',
    ':man-medium-skin-tone-red-hair:' => '👨🏽‍🦰',
    ':man-medium-skin-tone-white-hair:' => '👨🏽‍🦳',
    ':man-office-worker-dark-skin-tone:' => '👨🏿‍💼',
    ':man-office-worker-light-skin-tone:' => '👨🏻‍💼',
    ':man-office-worker-medium-dark-skin-tone:' => '👨🏾‍💼',
    ':man-office-worker-medium-light-skin-tone:' => '👨🏼‍💼',
    ':man-office-worker-medium-skin-tone:' => '👨🏽‍💼',
    ':man-police-officer:' => '👮‍♂️',
    ':man-scientist-dark-skin-tone:' => '👨🏿‍🔬',
    ':man-scientist-light-skin-tone:' => '👨🏻‍🔬',
    ':man-scientist-medium-dark-skin-tone:' => '👨🏾‍🔬',
    ':man-scientist-medium-light-skin-tone:' => '👨🏼‍🔬',
    ':man-scientist-medium-skin-tone:' => '👨🏽‍🔬',
    ':man-singer-dark-skin-tone:' => '👨🏿‍🎤',
    ':man-singer-light-skin-tone:' => '👨🏻‍🎤',
    ':man-singer-medium-dark-skin-tone:' => '👨🏾‍🎤',
    ':man-singer-medium-light-skin-tone:' => '👨🏼‍🎤',
    ':man-singer-medium-skin-tone:' => '👨🏽‍🎤',
    ':man-student-dark-skin-tone:' => '👨🏿‍🎓',
    ':man-student-light-skin-tone:' => '👨🏻‍🎓',
    ':man-student-medium-dark-skin-tone:' => '👨🏾‍🎓',
    ':man-student-medium-light-skin-tone:' => '👨🏼‍🎓',
    ':man-student-medium-skin-tone:' => '👨🏽‍🎓',
    ':man-superhero:' => '🦸‍♂️',
    ':man-supervillain:' => '🦹‍♂️',
    ':man-teacher-dark-skin-tone:' => '👨🏿‍🏫',
    ':man-teacher-light-skin-tone:' => '👨🏻‍🏫',
    ':man-teacher-medium-dark-skin-tone:' => '👨🏾‍🏫',
    ':man-teacher-medium-light-skin-tone:' => '👨🏼‍🏫',
    ':man-teacher-medium-skin-tone:' => '👨🏽‍🏫',
    ':man-technologist-dark-skin-tone:' => '👨🏿‍💻',
    ':man-technologist-light-skin-tone:' => '👨🏻‍💻',
    ':man-technologist-medium-dark-skin-tone:' => '👨🏾‍💻',
    ':man-technologist-medium-light-skin-tone:' => '👨🏼‍💻',
    ':man-technologist-medium-skin-tone:' => '👨🏽‍💻',
    ':man-vampire:' => '🧛‍♂️',
    ':man-with-white-cane-dark-skin-tone:' => '👨🏿‍🦯',
    ':man-with-white-cane-light-skin-tone:' => '👨🏻‍🦯',
    ':man-with-white-cane-medium-dark-skin-tone:' => '👨🏾‍🦯',
    ':man-with-white-cane-medium-light-skin-tone:' => '👨🏼‍🦯',
    ':man-with-white-cane-medium-skin-tone:' => '👨🏽‍🦯',
    ':man-zombie:' => '🧟‍♂️',
    ':mechanic-dark-skin-tone:' => '🧑🏿‍🔧',
    ':mechanic-light-skin-tone:' => '🧑🏻‍🔧',
    ':mechanic-medium-dark-skin-tone:' => '🧑🏾‍🔧',
    ':mechanic-medium-light-skin-tone:' => '🧑🏼‍🔧',
    ':mechanic-medium-skin-tone:' => '🧑🏽‍🔧',
    ':men-with-bunny-ears:' => '👯‍♂️',
    ':mx-claus-dark-skin-tone:' => '🧑🏿‍🎄',
    ':mx-claus-light-skin-tone:' => '🧑🏻‍🎄',
    ':mx-claus-medium-dark-skin-tone:' => '🧑🏾‍🎄',
    ':mx-claus-medium-light-skin-tone:' => '🧑🏼‍🎄',
    ':mx-claus-medium-skin-tone:' => '🧑🏽‍🎄',
    ':office-worker-dark-skin-tone:' => '🧑🏿‍💼',
    ':office-worker-light-skin-tone:' => '🧑🏻‍💼',
    ':office-worker-medium-dark-skin-tone:' => '🧑🏾‍💼',
    ':office-worker-medium-light-skin-tone:' => '🧑🏼‍💼',
    ':office-worker-medium-skin-tone:' => '🧑🏽‍💼',
    ':person-dark-skin-tone-bald:' => '🧑🏿‍🦲',
    ':person-dark-skin-tone-curly-hair:' => '🧑🏿‍🦱',
    ':person-dark-skin-tone-red-hair:' => '🧑🏿‍🦰',
    ':person-dark-skin-tone-white-hair:' => '🧑🏿‍🦳',
    ':person-feeding-baby-dark-skin-tone:' => '🧑🏿‍🍼',
    ':person-feeding-baby-light-skin-tone:' => '🧑🏻‍🍼',
    ':person-feeding-baby-medium-dark-skin-tone:' => '🧑🏾‍🍼',
    ':person-feeding-baby-medium-light-skin-tone:' => '🧑🏼‍🍼',
    ':person-feeding-baby-medium-skin-tone:' => '🧑🏽‍🍼',
    ':person-in-manual-wheelchair-dark-skin-tone:' => '🧑🏿‍🦽',
    ':person-in-manual-wheelchair-light-skin-tone:' => '🧑🏻‍🦽',
    ':person-in-manual-wheelchair-medium-dark-skin-tone:' => '🧑🏾‍🦽',
    ':person-in-manual-wheelchair-medium-light-skin-tone:' => '🧑🏼‍🦽',
    ':person-in-manual-wheelchair-medium-skin-tone:' => '🧑🏽‍🦽',
    ':person-in-motorized-wheelchair-dark-skin-tone:' => '🧑🏿‍🦼',
    ':person-in-motorized-wheelchair-light-skin-tone:' => '🧑🏻‍🦼',
    ':person-in-motorized-wheelchair-medium-dark-skin-tone:' => '🧑🏾‍🦼',
    ':person-in-motorized-wheelchair-medium-light-skin-tone:' => '🧑🏼‍🦼',
    ':person-in-motorized-wheelchair-medium-skin-tone:' => '🧑🏽‍🦼',
    ':person-light-skin-tone-bald:' => '🧑🏻‍🦲',
    ':person-light-skin-tone-curly-hair:' => '🧑🏻‍🦱',
    ':person-light-skin-tone-red-hair:' => '🧑🏻‍🦰',
    ':person-light-skin-tone-white-hair:' => '🧑🏻‍🦳',
    ':person-medium-dark-skin-tone-bald:' => '🧑🏾‍🦲',
    ':person-medium-dark-skin-tone-curly-hair:' => '🧑🏾‍🦱',
    ':person-medium-dark-skin-tone-red-hair:' => '🧑🏾‍🦰',
    ':person-medium-dark-skin-tone-white-hair:' => '🧑🏾‍🦳',
    ':person-medium-light-skin-tone-bald:' => '🧑🏼‍🦲',
    ':person-medium-light-skin-tone-curly-hair:' => '🧑🏼‍🦱',
    ':person-medium-light-skin-tone-red-hair:' => '🧑🏼‍🦰',
    ':person-medium-light-skin-tone-white-hair:' => '🧑🏼‍🦳',
    ':person-medium-skin-tone-bald:' => '🧑🏽‍🦲',
    ':person-medium-skin-tone-curly-hair:' => '🧑🏽‍🦱',
    ':person-medium-skin-tone-red-hair:' => '🧑🏽‍🦰',
    ':person-medium-skin-tone-white-hair:' => '🧑🏽‍🦳',
    ':person-with-white-cane-dark-skin-tone:' => '🧑🏿‍🦯',
    ':person-with-white-cane-light-skin-tone:' => '🧑🏻‍🦯',
    ':person-with-white-cane-medium-dark-skin-tone:' => '🧑🏾‍🦯',
    ':person-with-white-cane-medium-light-skin-tone:' => '🧑🏼‍🦯',
    ':person-with-white-cane-medium-skin-tone:' => '🧑🏽‍🦯',
    ':scientist-dark-skin-tone:' => '🧑🏿‍🔬',
    ':scientist-light-skin-tone:' => '🧑🏻‍🔬',
    ':scientist-medium-dark-skin-tone:' => '🧑🏾‍🔬',
    ':scientist-medium-light-skin-tone:' => '🧑🏼‍🔬',
    ':scientist-medium-skin-tone:' => '🧑🏽‍🔬',
    ':singer-dark-skin-tone:' => '🧑🏿‍🎤',
    ':singer-light-skin-tone:' => '🧑🏻‍🎤',
    ':singer-medium-dark-skin-tone:' => '🧑🏾‍🎤',
    ':singer-medium-light-skin-tone:' => '🧑🏼‍🎤',
    ':singer-medium-skin-tone:' => '🧑🏽‍🎤',
    ':student-dark-skin-tone:' => '🧑🏿‍🎓',
    ':student-light-skin-tone:' => '🧑🏻‍🎓',
    ':student-medium-dark-skin-tone:' => '🧑🏾‍🎓',
    ':student-medium-light-skin-tone:' => '🧑🏼‍🎓',
    ':student-medium-skin-tone:' => '🧑🏽‍🎓',
    ':teacher-dark-skin-tone:' => '🧑🏿‍🏫',
    ':teacher-light-skin-tone:' => '🧑🏻‍🏫',
    ':teacher-medium-dark-skin-tone:' => '🧑🏾‍🏫',
    ':teacher-medium-light-skin-tone:' => '🧑🏼‍🏫',
    ':teacher-medium-skin-tone:' => '🧑🏽‍🏫',
    ':technologist-dark-skin-tone:' => '🧑🏿‍💻',
    ':technologist-light-skin-tone:' => '🧑🏻‍💻',
    ':technologist-medium-dark-skin-tone:' => '🧑🏾‍💻',
    ':technologist-medium-light-skin-tone:' => '🧑🏼‍💻',
    ':technologist-medium-skin-tone:' => '🧑🏽‍💻',
    ':woman-artist-dark-skin-tone:' => '👩🏿‍🎨',
    ':woman-artist-light-skin-tone:' => '👩🏻‍🎨',
    ':woman-artist-medium-dark-skin-tone:' => '👩🏾‍🎨',
    ':woman-artist-medium-light-skin-tone:' => '👩🏼‍🎨',
    ':woman-artist-medium-skin-tone:' => '👩🏽‍🎨',
    ':woman-astronaut-dark-skin-tone:' => '👩🏿‍🚀',
    ':woman-astronaut-light-skin-tone:' => '👩🏻‍🚀',
    ':woman-astronaut-medium-dark-skin-tone:' => '👩🏾‍🚀',
    ':woman-astronaut-medium-light-skin-tone:' => '👩🏼‍🚀',
    ':woman-astronaut-medium-skin-tone:' => '👩🏽‍🚀',
    ':woman-blond-hair:' => '👱‍♀️',
    ':woman-construction-worker:' => '👷‍♀️',
    ':woman-cook-dark-skin-tone:' => '👩🏿‍🍳',
    ':woman-cook-light-skin-tone:' => '👩🏻‍🍳',
    ':woman-cook-medium-dark-skin-tone:' => '👩🏾‍🍳',
    ':woman-cook-medium-light-skin-tone:' => '👩🏼‍🍳',
    ':woman-cook-medium-skin-tone:' => '👩🏽‍🍳',
    ':woman-dark-skin-tone-bald:' => '👩🏿‍🦲',
    ':woman-dark-skin-tone-curly-hair:' => '👩🏿‍🦱',
    ':woman-dark-skin-tone-red-hair:' => '👩🏿‍🦰',
    ':woman-dark-skin-tone-white-hair:' => '👩🏿‍🦳',
    ':woman-elf:' => '🧝‍♀️',
    ':woman-factory-worker-dark-skin-tone:' => '👩🏿‍🏭',
    ':woman-factory-worker-light-skin-tone:' => '👩🏻‍🏭',
    ':woman-factory-worker-medium-dark-skin-tone:' => '👩🏾‍🏭',
    ':woman-factory-worker-medium-light-skin-tone:' => '👩🏼‍🏭',
    ':woman-factory-worker-medium-skin-tone:' => '👩🏽‍🏭',
    ':woman-fairy:' => '🧚‍♀️',
    ':woman-farmer-dark-skin-tone:' => '👩🏿‍🌾',
    ':woman-farmer-light-skin-tone:' => '👩🏻‍🌾',
    ':woman-farmer-medium-dark-skin-tone:' => '👩🏾‍🌾',
    ':woman-farmer-medium-light-skin-tone:' => '👩🏼‍🌾',
    ':woman-farmer-medium-skin-tone:' => '👩🏽‍🌾',
    ':woman-feeding-baby-dark-skin-tone:' => '👩🏿‍🍼',
    ':woman-feeding-baby-light-skin-tone:' => '👩🏻‍🍼',
    ':woman-feeding-baby-medium-dark-skin-tone:' => '👩🏾‍🍼',
    ':woman-feeding-baby-medium-light-skin-tone:' => '👩🏼‍🍼',
    ':woman-feeding-baby-medium-skin-tone:' => '👩🏽‍🍼',
    ':woman-firefighter-dark-skin-tone:' => '👩🏿‍🚒',
    ':woman-firefighter-light-skin-tone:' => '👩🏻‍🚒',
    ':woman-firefighter-medium-dark-skin-tone:' => '👩🏾‍🚒',
    ':woman-firefighter-medium-light-skin-tone:' => '👩🏼‍🚒',
    ':woman-firefighter-medium-skin-tone:' => '👩🏽‍🚒',
    ':woman-genie:' => '🧞‍♀️',
    ':woman-guard:' => '💂‍♀️',
    ':woman-in-manual-wheelchair-dark-skin-tone:' => '👩🏿‍🦽',
    ':woman-in-manual-wheelchair-light-skin-tone:' => '👩🏻‍🦽',
    ':woman-in-manual-wheelchair-medium-dark-skin-tone:' => '👩🏾‍🦽',
    ':woman-in-manual-wheelchair-medium-light-skin-tone:' => '👩🏼‍🦽',
    ':woman-in-manual-wheelchair-medium-skin-tone:' => '👩🏽‍🦽',
    ':woman-in-motorized-wheelchair-dark-skin-tone:' => '👩🏿‍🦼',
    ':woman-in-motorized-wheelchair-light-skin-tone:' => '👩🏻‍🦼',
    ':woman-in-motorized-wheelchair-medium-dark-skin-tone:' => '👩🏾‍🦼',
    ':woman-in-motorized-wheelchair-medium-light-skin-tone:' => '👩🏼‍🦼',
    ':woman-in-motorized-wheelchair-medium-skin-tone:' => '👩🏽‍🦼',
    ':woman-light-skin-tone-bald:' => '👩🏻‍🦲',
    ':woman-light-skin-tone-curly-hair:' => '👩🏻‍🦱',
    ':woman-light-skin-tone-red-hair:' => '👩🏻‍🦰',
    ':woman-light-skin-tone-white-hair:' => '👩🏻‍🦳',
    ':woman-mage:' => '🧙‍♀️',
    ':woman-mechanic-dark-skin-tone:' => '👩🏿‍🔧',
    ':woman-mechanic-light-skin-tone:' => '👩🏻‍🔧',
    ':woman-mechanic-medium-dark-skin-tone:' => '👩🏾‍🔧',
    ':woman-mechanic-medium-light-skin-tone:' => '👩🏼‍🔧',
    ':woman-mechanic-medium-skin-tone:' => '👩🏽‍🔧',
    ':woman-medium-dark-skin-tone-bald:' => '👩🏾‍🦲',
    ':woman-medium-dark-skin-tone-curly-hair:' => '👩🏾‍🦱',
    ':woman-medium-dark-skin-tone-red-hair:' => '👩🏾‍🦰',
    ':woman-medium-dark-skin-tone-white-hair:' => '👩🏾‍🦳',
    ':woman-medium-light-skin-tone-bald:' => '👩🏼‍🦲',
    ':woman-medium-light-skin-tone-curly-hair:' => '👩🏼‍🦱',
    ':woman-medium-light-skin-tone-red-hair:' => '👩🏼‍🦰',
    ':woman-medium-light-skin-tone-white-hair:' => '👩🏼‍🦳',
    ':woman-medium-skin-tone-bald:' => '👩🏽‍🦲',
    ':woman-medium-skin-tone-curly-hair:' => '👩🏽‍🦱',
    ':woman-medium-skin-tone-red-hair:' => '👩🏽‍🦰',
    ':woman-medium-skin-tone-white-hair:' => '👩🏽‍🦳',
    ':woman-office-worker-dark-skin-tone:' => '👩🏿‍💼',
    ':woman-office-worker-light-skin-tone:' => '👩🏻‍💼',
    ':woman-office-worker-medium-dark-skin-tone:' => '👩🏾‍💼',
    ':woman-office-worker-medium-light-skin-tone:' => '👩🏼‍💼',
    ':woman-office-worker-medium-skin-tone:' => '👩🏽‍💼',
    ':woman-police-officer:' => '👮‍♀️',
    ':woman-scientist-dark-skin-tone:' => '👩🏿‍🔬',
    ':woman-scientist-light-skin-tone:' => '👩🏻‍🔬',
    ':woman-scientist-medium-dark-skin-tone:' => '👩🏾‍🔬',
    ':woman-scientist-medium-light-skin-tone:' => '👩🏼‍🔬',
    ':woman-scientist-medium-skin-tone:' => '👩🏽‍🔬',
    ':woman-singer-dark-skin-tone:' => '👩🏿‍🎤',
    ':woman-singer-light-skin-tone:' => '👩🏻‍🎤',
    ':woman-singer-medium-dark-skin-tone:' => '👩🏾‍🎤',
    ':woman-singer-medium-light-skin-tone:' => '👩🏼‍🎤',
    ':woman-singer-medium-skin-tone:' => '👩🏽‍🎤',
    ':woman-student-dark-skin-tone:' => '👩🏿‍🎓',
    ':woman-student-light-skin-tone:' => '👩🏻‍🎓',
    ':woman-student-medium-dark-skin-tone:' => '👩🏾‍🎓',
    ':woman-student-medium-light-skin-tone:' => '👩🏼‍🎓',
    ':woman-student-medium-skin-tone:' => '👩🏽‍🎓',
    ':woman-superhero:' => '🦸‍♀️',
    ':woman-supervillain:' => '🦹‍♀️',
    ':woman-teacher-dark-skin-tone:' => '👩🏿‍🏫',
    ':woman-teacher-light-skin-tone:' => '👩🏻‍🏫',
    ':woman-teacher-medium-dark-skin-tone:' => '👩🏾‍🏫',
    ':woman-teacher-medium-light-skin-tone:' => '👩🏼‍🏫',
    ':woman-teacher-medium-skin-tone:' => '👩🏽‍🏫',
    ':woman-technologist-dark-skin-tone:' => '👩🏿‍💻',
    ':woman-technologist-light-skin-tone:' => '👩🏻‍💻',
    ':woman-technologist-medium-dark-skin-tone:' => '👩🏾‍💻',
    ':woman-technologist-medium-light-skin-tone:' => '👩🏼‍💻',
    ':woman-technologist-medium-skin-tone:' => '👩🏽‍💻',
    ':woman-vampire:' => '🧛‍♀️',
    ':woman-with-white-cane-dark-skin-tone:' => '👩🏿‍🦯',
    ':woman-with-white-cane-light-skin-tone:' => '👩🏻‍🦯',
    ':woman-with-white-cane-medium-dark-skin-tone:' => '👩🏾‍🦯',
    ':woman-with-white-cane-medium-light-skin-tone:' => '👩🏼‍🦯',
    ':woman-with-white-cane-medium-skin-tone:' => '👩🏽‍🦯',
    ':woman-zombie:' => '🧟‍♀️',
    ':women-with-bunny-ears:' => '👯‍♀️',
    ':eye-in-speech-bubble:' => '👁️‍🗨️',
    ':family-adult-adult-child:' => '🧑‍🧑‍🧒',
    ':family-adult-child-child:' => '🧑‍🧒‍🧒',
    ':man-bouncing-ball:' => '⛹️‍♂️',
    ':man-boy-boy:' => '👨‍👦‍👦',
    ':man-girl-boy:' => '👨‍👧‍👦',
    ':man-girl-girl:' => '👨‍👧‍👧',
    ':man-golfing:' => '🏌️‍♂️',
    ':man-lifting-weights:' => '🏋️‍♂️',
    ':man-man-boy:' => '👨‍👨‍👦',
    ':man-man-girl:' => '👨‍👨‍👧',
    ':man-woman-boy:' => '👨‍👩‍👦',
    ':man-woman-girl:' => '👨‍👩‍👧',
    ':people-holding-hands:' => '🧑‍🤝‍🧑',
    ':woman-bouncing-ball:' => '⛹️‍♀️',
    ':woman-boy-boy:' => '👩‍👦‍👦',
    ':woman-girl-boy:' => '👩‍👧‍👦',
    ':woman-girl-girl:' => '👩‍👧‍👧',
    ':woman-golfing:' => '🏌️‍♀️',
    ':woman-lifting-weights:' => '🏋️‍♀️',
    ':woman-woman-boy:' => '👩‍👩‍👦',
    ':woman-woman-girl:' => '👩‍👩‍👧',
    ':couple-with-heart-man-man:' => '👨‍❤‍👨',
    ':couple-with-heart-woman-man:' => '👩‍❤️‍👨',
    ':couple-with-heart-woman-woman:' => '👩‍❤‍👩',
    ':deaf-man-dark-skin-tone:' => '🧏🏿‍♂️',
    ':deaf-man-light-skin-tone:' => '🧏🏻‍♂️',
    ':deaf-man-medium-dark-skin-tone:' => '🧏🏾‍♂️',
    ':deaf-man-medium-light-skin-tone:' => '🧏🏼‍♂️',
    ':deaf-man-medium-skin-tone:' => '🧏🏽‍♂️',
    ':deaf-woman-dark-skin-tone:' => '🧏🏿‍♀️',
    ':deaf-woman-light-skin-tone:' => '🧏🏻‍♀️',
    ':deaf-woman-medium-dark-skin-tone:' => '🧏🏾‍♀️',
    ':deaf-woman-medium-light-skin-tone:' => '🧏🏼‍♀️',
    ':deaf-woman-medium-skin-tone:' => '🧏🏽‍♀️',
    ':family-man-boy-boy:' => '👨‍👦‍👦',
    ':family-man-girl-boy:' => '👨‍👧‍👦',
    ':family-man-girl-girl:' => '👨‍👧‍👧',
    ':family-man-man-boy:' => '👨‍👨‍👦',
    ':family-man-man-girl:' => '👨‍👨‍👧',
    ':family-man-woman-boy:' => '👨‍👩‍👦',
    ':family-man-woman-girl:' => '👨‍👩‍👧',
    ':family-mmb:' => '👨‍👨‍👦',
    ':family-mmg:' => '👨‍👨‍👧',
    ':family-mwg:' => '👨‍👩‍👧',
    ':family-woman-boy-boy:' => '👩‍👦‍👦',
    ':family-woman-girl-boy:' => '👩‍👧‍👦',
    ':family-woman-girl-girl:' => '👩‍👧‍👧',
    ':family-woman-woman-boy:' => '👩‍👩‍👦',
    ':family-woman-woman-girl:' => '👩‍👩‍👧',
    ':family-wwb:' => '👩‍👩‍👦',
    ':family-wwg:' => '👩‍👩‍👧',
    ':handshake-dark-skin-tone-light-skin-tone:' => '🫱🏿‍🫲🏻',
    ':handshake-dark-skin-tone-medium-dark-skin-tone:' => '🫱🏿‍🫲🏾',
    ':handshake-dark-skin-tone-medium-light-skin-tone:' => '🫱🏿‍🫲🏼',
    ':handshake-dark-skin-tone-medium-skin-tone:' => '🫱🏿‍🫲🏽',
    ':handshake-light-skin-tone-dark-skin-tone:' => '🫱🏻‍🫲🏿',
    ':handshake-light-skin-tone-medium-dark-skin-tone:' => '🫱🏻‍🫲🏾',
    ':handshake-light-skin-tone-medium-light-skin-tone:' => '🫱🏻‍🫲🏼',
    ':handshake-light-skin-tone-medium-skin-tone:' => '🫱🏻‍🫲🏽',
    ':handshake-medium-dark-skin-tone-dark-skin-tone:' => '🫱🏾‍🫲🏿',
    ':handshake-medium-dark-skin-tone-light-skin-tone:' => '🫱🏾‍🫲🏻',
    ':handshake-medium-dark-skin-tone-medium-light-skin-tone:' => '🫱🏾‍🫲🏼',
    ':handshake-medium-dark-skin-tone-medium-skin-tone:' => '🫱🏾‍🫲🏽',
    ':handshake-medium-light-skin-tone-dark-skin-tone:' => '🫱🏼‍🫲🏿',
    ':handshake-medium-light-skin-tone-light-skin-tone:' => '🫱🏼‍🫲🏻',
    ':handshake-medium-light-skin-tone-medium-dark-skin-tone:' => '🫱🏼‍🫲🏾',
    ':handshake-medium-light-skin-tone-medium-skin-tone:' => '🫱🏼‍🫲🏽',
    ':handshake-medium-skin-tone-dark-skin-tone:' => '🫱🏽‍🫲🏿',
    ':handshake-medium-skin-tone-light-skin-tone:' => '🫱🏽‍🫲🏻',
    ':handshake-medium-skin-tone-medium-dark-skin-tone:' => '🫱🏽‍🫲🏾',
    ':handshake-medium-skin-tone-medium-light-skin-tone:' => '🫱🏽‍🫲🏼',
    ':health-worker-dark-skin-tone:' => '🧑🏿‍⚕️',
    ':health-worker-light-skin-tone:' => '🧑🏻‍⚕️',
    ':health-worker-medium-dark-skin-tone:' => '🧑🏾‍⚕️',
    ':health-worker-medium-light-skin-tone:' => '🧑🏼‍⚕️',
    ':health-worker-medium-skin-tone:' => '🧑🏽‍⚕️',
    ':judge-dark-skin-tone:' => '🧑🏿‍⚖️',
    ':judge-light-skin-tone:' => '🧑🏻‍⚖️',
    ':judge-medium-dark-skin-tone:' => '🧑🏾‍⚖️',
    ':judge-medium-light-skin-tone:' => '🧑🏼‍⚖️',
    ':judge-medium-skin-tone:' => '🧑🏽‍⚖️',
    ':man-biking-dark-skin-tone:' => '🚴🏿‍♂️',
    ':man-biking-light-skin-tone:' => '🚴🏻‍♂️',
    ':man-biking-medium-dark-skin-tone:' => '🚴🏾‍♂️',
    ':man-biking-medium-light-skin-tone:' => '🚴🏼‍♂️',
    ':man-biking-medium-skin-tone:' => '🚴🏽‍♂️',
    ':man-bouncing-ball-dark-skin-tone:' => '⛹🏿‍♂️',
    ':man-bouncing-ball-light-skin-tone:' => '⛹🏻‍♂️',
    ':man-bouncing-ball-medium-dark-skin-tone:' => '⛹🏾‍♂️',
    ':man-bouncing-ball-medium-light-skin-tone:' => '⛹🏼‍♂️',
    ':man-bouncing-ball-medium-skin-tone:' => '⛹🏽‍♂️',
    ':man-bowing-dark-skin-tone:' => '🙇🏿‍♂️',
    ':man-bowing-light-skin-tone:' => '🙇🏻‍♂️',
    ':man-bowing-medium-dark-skin-tone:' => '🙇🏾‍♂️',
    ':man-bowing-medium-light-skin-tone:' => '🙇🏼‍♂️',
    ':man-bowing-medium-skin-tone:' => '🙇🏽‍♂️',
    ':man-cartwheeling-dark-skin-tone:' => '🤸🏿‍♂️',
    ':man-cartwheeling-light-skin-tone:' => '🤸🏻‍♂️',
    ':man-cartwheeling-medium-dark-skin-tone:' => '🤸🏾‍♂️',
    ':man-cartwheeling-medium-light-skin-tone:' => '🤸🏼‍♂️',
    ':man-cartwheeling-medium-skin-tone:' => '🤸🏽‍♂️',
    ':man-climbing-dark-skin-tone:' => '🧗🏿‍♂️',
    ':man-climbing-light-skin-tone:' => '🧗🏻‍♂️',
    ':man-climbing-medium-dark-skin-tone:' => '🧗🏾‍♂️',
    ':man-climbing-medium-light-skin-tone:' => '🧗🏼‍♂️',
    ':man-climbing-medium-skin-tone:' => '🧗🏽‍♂️',
    ':man-construction-worker-dark-skin-tone:' => '👷🏿‍♂️',
    ':man-construction-worker-light-skin-tone:' => '👷🏻‍♂️',
    ':man-construction-worker-medium-dark-skin-tone:' => '👷🏾‍♂️',
    ':man-construction-worker-medium-light-skin-tone:' => '👷🏼‍♂️',
    ':man-construction-worker-medium-skin-tone:' => '👷🏽‍♂️',
    ':man-dark-skin-tone-beard:' => '🧔🏿‍♂️',
    ':man-dark-skin-tone-blond-hair:' => '👱🏿‍♂️',
    ':man-detective:' => '🕵️‍♂️',
    ':man-detective-dark-skin-tone:' => '🕵🏿‍♂️',
    ':man-detective-light-skin-tone:' => '🕵🏻‍♂️',
    ':man-detective-medium-dark-skin-tone:' => '🕵🏾‍♂️',
    ':man-detective-medium-light-skin-tone:' => '🕵🏼‍♂️',
    ':man-detective-medium-skin-tone:' => '🕵🏽‍♂️',
    ':man-elf-dark-skin-tone:' => '🧝🏿‍♂️',
    ':man-elf-light-skin-tone:' => '🧝🏻‍♂️',
    ':man-elf-medium-dark-skin-tone:' => '🧝🏾‍♂️',
    ':man-elf-medium-light-skin-tone:' => '🧝🏼‍♂️',
    ':man-elf-medium-skin-tone:' => '🧝🏽‍♂️',
    ':man-facepalming-dark-skin-tone:' => '🤦🏿‍♂️',
    ':man-facepalming-light-skin-tone:' => '🤦🏻‍♂️',
    ':man-facepalming-medium-dark-skin-tone:' => '🤦🏾‍♂️',
    ':man-facepalming-medium-light-skin-tone:' => '🤦🏼‍♂️',
    ':man-facepalming-medium-skin-tone:' => '🤦🏽‍♂️',
    ':man-fairy-dark-skin-tone:' => '🧚🏿‍♂️',
    ':man-fairy-light-skin-tone:' => '🧚🏻‍♂️',
    ':man-fairy-medium-dark-skin-tone:' => '🧚🏾‍♂️',
    ':man-fairy-medium-light-skin-tone:' => '🧚🏼‍♂️',
    ':man-fairy-medium-skin-tone:' => '🧚🏽‍♂️',
    ':man-frowning-dark-skin-tone:' => '🙍🏿‍♂️',
    ':man-frowning-light-skin-tone:' => '🙍🏻‍♂️',
    ':man-frowning-medium-dark-skin-tone:' => '🙍🏾‍♂️',
    ':man-frowning-medium-light-skin-tone:' => '🙍🏼‍♂️',
    ':man-frowning-medium-skin-tone:' => '🙍🏽‍♂️',
    ':man-gesturing-no-dark-skin-tone:' => '🙅🏿‍♂️',
    ':man-gesturing-no-light-skin-tone:' => '🙅🏻‍♂️',
    ':man-gesturing-no-medium-dark-skin-tone:' => '🙅🏾‍♂️',
    ':man-gesturing-no-medium-light-skin-tone:' => '🙅🏼‍♂️',
    ':man-gesturing-no-medium-skin-tone:' => '🙅🏽‍♂️',
    ':man-gesturing-ok-dark-skin-tone:' => '🙆🏿‍♂️',
    ':man-gesturing-ok-light-skin-tone:' => '🙆🏻‍♂️',
    ':man-gesturing-ok-medium-dark-skin-tone:' => '🙆🏾‍♂️',
    ':man-gesturing-ok-medium-light-skin-tone:' => '🙆🏼‍♂️',
    ':man-gesturing-ok-medium-skin-tone:' => '🙆🏽‍♂️',
    ':man-getting-haircut-dark-skin-tone:' => '💇🏿‍♂️',
    ':man-getting-haircut-light-skin-tone:' => '💇🏻‍♂️',
    ':man-getting-haircut-medium-dark-skin-tone:' => '💇🏾‍♂️',
    ':man-getting-haircut-medium-light-skin-tone:' => '💇🏼‍♂️',
    ':man-getting-haircut-medium-skin-tone:' => '💇🏽‍♂️',
    ':man-getting-massage-dark-skin-tone:' => '💆🏿‍♂️',
    ':man-getting-massage-light-skin-tone:' => '💆🏻‍♂️',
    ':man-getting-massage-medium-dark-skin-tone:' => '💆🏾‍♂️',
    ':man-getting-massage-medium-light-skin-tone:' => '💆🏼‍♂️',
    ':man-getting-massage-medium-skin-tone:' => '💆🏽‍♂️',
    ':man-golfing-dark-skin-tone:' => '🏌🏿‍♂️',
    ':man-golfing-light-skin-tone:' => '🏌🏻‍♂️',
    ':man-golfing-medium-dark-skin-tone:' => '🏌🏾‍♂️',
    ':man-golfing-medium-light-skin-tone:' => '🏌🏼‍♂️',
    ':man-golfing-medium-skin-tone:' => '🏌🏽‍♂️',
    ':man-guard-dark-skin-tone:' => '💂🏿‍♂️',
    ':man-guard-light-skin-tone:' => '💂🏻‍♂️',
    ':man-guard-medium-dark-skin-tone:' => '💂🏾‍♂️',
    ':man-guard-medium-light-skin-tone:' => '💂🏼‍♂️',
    ':man-guard-medium-skin-tone:' => '💂🏽‍♂️',
    ':man-health-worker-dark-skin-tone:' => '👨🏿‍⚕️',
    ':man-health-worker-light-skin-tone:' => '👨🏻‍⚕️',
    ':man-health-worker-medium-dark-skin-tone:' => '👨🏾‍⚕️',
    ':man-health-worker-medium-light-skin-tone:' => '👨🏼‍⚕️',
    ':man-health-worker-medium-skin-tone:' => '👨🏽‍⚕️',
    ':man-in-lotus-position-dark-skin-tone:' => '🧘🏿‍♂️',
    ':man-in-lotus-position-light-skin-tone:' => '🧘🏻‍♂️',
    ':man-in-lotus-position-medium-dark-skin-tone:' => '🧘🏾‍♂️',
    ':man-in-lotus-position-medium-light-skin-tone:' => '🧘🏼‍♂️',
    ':man-in-lotus-position-medium-skin-tone:' => '🧘🏽‍♂️',
    ':man-in-steamy-room-dark-skin-tone:' => '🧖🏿‍♂️',
    ':man-in-steamy-room-light-skin-tone:' => '🧖🏻‍♂️',
    ':man-in-steamy-room-medium-dark-skin-tone:' => '🧖🏾‍♂️',
    ':man-in-steamy-room-medium-light-skin-tone:' => '🧖🏼‍♂️',
    ':man-in-steamy-room-medium-skin-tone:' => '🧖🏽‍♂️',
    ':man-in-tuxedo-dark-skin-tone:' => '🤵🏿‍♂️',
    ':man-in-tuxedo-light-skin-tone:' => '🤵🏻‍♂️',
    ':man-in-tuxedo-medium-dark-skin-tone:' => '🤵🏾‍♂️',
    ':man-in-tuxedo-medium-light-skin-tone:' => '🤵🏼‍♂️',
    ':man-in-tuxedo-medium-skin-tone:' => '🤵🏽‍♂️',
    ':man-judge-dark-skin-tone:' => '👨🏿‍⚖️',
    ':man-judge-light-skin-tone:' => '👨🏻‍⚖️',
    ':man-judge-medium-dark-skin-tone:' => '👨🏾‍⚖️',
    ':man-judge-medium-light-skin-tone:' => '👨🏼‍⚖️',
    ':man-judge-medium-skin-tone:' => '👨🏽‍⚖️',
    ':man-juggling-dark-skin-tone:' => '🤹🏿‍♂️',
    ':man-juggling-light-skin-tone:' => '🤹🏻‍♂️',
    ':man-juggling-medium-dark-skin-tone:' => '🤹🏾‍♂️',
    ':man-juggling-medium-light-skin-tone:' => '🤹🏼‍♂️',
    ':man-juggling-medium-skin-tone:' => '🤹🏽‍♂️',
    ':man-kneeling-dark-skin-tone:' => '🧎🏿‍♂️',
    ':man-kneeling-light-skin-tone:' => '🧎🏻‍♂️',
    ':man-kneeling-medium-dark-skin-tone:' => '🧎🏾‍♂️',
    ':man-kneeling-medium-light-skin-tone:' => '🧎🏼‍♂️',
    ':man-kneeling-medium-skin-tone:' => '🧎🏽‍♂️',
    ':man-lifting-weights-dark-skin-tone:' => '🏋🏿‍♂️',
    ':man-lifting-weights-light-skin-tone:' => '🏋🏻‍♂️',
    ':man-lifting-weights-medium-dark-skin-tone:' => '🏋🏾‍♂️',
    ':man-lifting-weights-medium-light-skin-tone:' => '🏋🏼‍♂️',
    ':man-lifting-weights-medium-skin-tone:' => '🏋🏽‍♂️',
    ':man-light-skin-tone-beard:' => '🧔🏻‍♂️',
    ':man-light-skin-tone-blond-hair:' => '👱🏻‍♂️',
    ':man-mage-dark-skin-tone:' => '🧙🏿‍♂️',
    ':man-mage-light-skin-tone:' => '🧙🏻‍♂️',
    ':man-mage-medium-dark-skin-tone:' => '🧙🏾‍♂️',
    ':man-mage-medium-light-skin-tone:' => '🧙🏼‍♂️',
    ':man-mage-medium-skin-tone:' => '🧙🏽‍♂️',
    ':man-medium-dark-skin-tone-beard:' => '🧔🏾‍♂️',
    ':man-medium-dark-skin-tone-blond-hair:' => '👱🏾‍♂️',
    ':man-medium-light-skin-tone-beard:' => '🧔🏼‍♂️',
    ':man-medium-light-skin-tone-blond-hair:' => '👱🏼‍♂️',
    ':man-medium-skin-tone-beard:' => '🧔🏽‍♂️',
    ':man-medium-skin-tone-blond-hair:' => '👱🏽‍♂️',
    ':man-mountain-biking-dark-skin-tone:' => '🚵🏿‍♂️',
    ':man-mountain-biking-light-skin-tone:' => '🚵🏻‍♂️',
    ':man-mountain-biking-medium-dark-skin-tone:' => '🚵🏾‍♂️',
    ':man-mountain-biking-medium-light-skin-tone:' => '🚵🏼‍♂️',
    ':man-mountain-biking-medium-skin-tone:' => '🚵🏽‍♂️',
    ':man-pilot-dark-skin-tone:' => '👨🏿‍✈️',
    ':man-pilot-light-skin-tone:' => '👨🏻‍✈️',
    ':man-pilot-medium-dark-skin-tone:' => '👨🏾‍✈️',
    ':man-pilot-medium-light-skin-tone:' => '👨🏼‍✈️',
    ':man-pilot-medium-skin-tone:' => '👨🏽‍✈️',
    ':man-playing-handball-dark-skin-tone:' => '🤾🏿‍♂️',
    ':man-playing-handball-light-skin-tone:' => '🤾🏻‍♂️',
    ':man-playing-handball-medium-dark-skin-tone:' => '🤾🏾‍♂️',
    ':man-playing-handball-medium-light-skin-tone:' => '🤾🏼‍♂️',
    ':man-playing-handball-medium-skin-tone:' => '🤾🏽‍♂️',
    ':man-playing-water-polo-dark-skin-tone:' => '🤽🏿‍♂️',
    ':man-playing-water-polo-light-skin-tone:' => '🤽🏻‍♂️',
    ':man-playing-water-polo-medium-dark-skin-tone:' => '🤽🏾‍♂️',
    ':man-playing-water-polo-medium-light-skin-tone:' => '🤽🏼‍♂️',
    ':man-playing-water-polo-medium-skin-tone:' => '🤽🏽‍♂️',
    ':man-police-officer-dark-skin-tone:' => '👮🏿‍♂️',
    ':man-police-officer-light-skin-tone:' => '👮🏻‍♂️',
    ':man-police-officer-medium-dark-skin-tone:' => '👮🏾‍♂️',
    ':man-police-officer-medium-light-skin-tone:' => '👮🏼‍♂️',
    ':man-police-officer-medium-skin-tone:' => '👮🏽‍♂️',
    ':man-pouting-dark-skin-tone:' => '🙎🏿‍♂️',
    ':man-pouting-light-skin-tone:' => '🙎🏻‍♂️',
    ':man-pouting-medium-dark-skin-tone:' => '🙎🏾‍♂️',
    ':man-pouting-medium-light-skin-tone:' => '🙎🏼‍♂️',
    ':man-pouting-medium-skin-tone:' => '🙎🏽‍♂️',
    ':man-raising-hand-dark-skin-tone:' => '🙋🏿‍♂️',
    ':man-raising-hand-light-skin-tone:' => '🙋🏻‍♂️',
    ':man-raising-hand-medium-dark-skin-tone:' => '🙋🏾‍♂️',
    ':man-raising-hand-medium-light-skin-tone:' => '🙋🏼‍♂️',
    ':man-raising-hand-medium-skin-tone:' => '🙋🏽‍♂️',
    ':man-rowing-boat-dark-skin-tone:' => '🚣🏿‍♂️',
    ':man-rowing-boat-light-skin-tone:' => '🚣🏻‍♂️',
    ':man-rowing-boat-medium-dark-skin-tone:' => '🚣🏾‍♂️',
    ':man-rowing-boat-medium-light-skin-tone:' => '🚣🏼‍♂️',
    ':man-rowing-boat-medium-skin-tone:' => '🚣🏽‍♂️',
    ':man-running-dark-skin-tone:' => '🏃🏿‍♂️',
    ':man-running-light-skin-tone:' => '🏃🏻‍♂️',
    ':man-running-medium-dark-skin-tone:' => '🏃🏾‍♂️',
    ':man-running-medium-light-skin-tone:' => '🏃🏼‍♂️',
    ':man-running-medium-skin-tone:' => '🏃🏽‍♂️',
    ':man-shrugging-dark-skin-tone:' => '🤷🏿‍♂️',
    ':man-shrugging-light-skin-tone:' => '🤷🏻‍♂️',
    ':man-shrugging-medium-dark-skin-tone:' => '🤷🏾‍♂️',
    ':man-shrugging-medium-light-skin-tone:' => '🤷🏼‍♂️',
    ':man-shrugging-medium-skin-tone:' => '🤷🏽‍♂️',
    ':man-standing-dark-skin-tone:' => '🧍🏿‍♂️',
    ':man-standing-light-skin-tone:' => '🧍🏻‍♂️',
    ':man-standing-medium-dark-skin-tone:' => '🧍🏾‍♂️',
    ':man-standing-medium-light-skin-tone:' => '🧍🏼‍♂️',
    ':man-standing-medium-skin-tone:' => '🧍🏽‍♂️',
    ':man-superhero-dark-skin-tone:' => '🦸🏿‍♂️',
    ':man-superhero-light-skin-tone:' => '🦸🏻‍♂️',
    ':man-superhero-medium-dark-skin-tone:' => '🦸🏾‍♂️',
    ':man-superhero-medium-light-skin-tone:' => '🦸🏼‍♂️',
    ':man-superhero-medium-skin-tone:' => '🦸🏽‍♂️',
    ':man-supervillain-dark-skin-tone:' => '🦹🏿‍♂️',
    ':man-supervillain-light-skin-tone:' => '🦹🏻‍♂️',
    ':man-supervillain-medium-dark-skin-tone:' => '🦹🏾‍♂️',
    ':man-supervillain-medium-light-skin-tone:' => '🦹🏼‍♂️',
    ':man-supervillain-medium-skin-tone:' => '🦹🏽‍♂️',
    ':man-surfing-dark-skin-tone:' => '🏄🏿‍♂️',
    ':man-surfing-light-skin-tone:' => '🏄🏻‍♂️',
    ':man-surfing-medium-dark-skin-tone:' => '🏄🏾‍♂️',
    ':man-surfing-medium-light-skin-tone:' => '🏄🏼‍♂️',
    ':man-surfing-medium-skin-tone:' => '🏄🏽‍♂️',
    ':man-swimming-dark-skin-tone:' => '🏊🏿‍♂️',
    ':man-swimming-light-skin-tone:' => '🏊🏻‍♂️',
    ':man-swimming-medium-dark-skin-tone:' => '🏊🏾‍♂️',
    ':man-swimming-medium-light-skin-tone:' => '🏊🏼‍♂️',
    ':man-swimming-medium-skin-tone:' => '🏊🏽‍♂️',
    ':man-tipping-hand-dark-skin-tone:' => '💁🏿‍♂️',
    ':man-tipping-hand-light-skin-tone:' => '💁🏻‍♂️',
    ':man-tipping-hand-medium-dark-skin-tone:' => '💁🏾‍♂️',
    ':man-tipping-hand-medium-light-skin-tone:' => '💁🏼‍♂️',
    ':man-tipping-hand-medium-skin-tone:' => '💁🏽‍♂️',
    ':man-vampire-dark-skin-tone:' => '🧛🏿‍♂️',
    ':man-vampire-light-skin-tone:' => '🧛🏻‍♂️',
    ':man-vampire-medium-dark-skin-tone:' => '🧛🏾‍♂️',
    ':man-vampire-medium-light-skin-tone:' => '🧛🏼‍♂️',
    ':man-vampire-medium-skin-tone:' => '🧛🏽‍♂️',
    ':man-walking-dark-skin-tone:' => '🚶🏿‍♂️',
    ':man-walking-light-skin-tone:' => '🚶🏻‍♂️',
    ':man-walking-medium-dark-skin-tone:' => '🚶🏾‍♂️',
    ':man-walking-medium-light-skin-tone:' => '🚶🏼‍♂️',
    ':man-walking-medium-skin-tone:' => '🚶🏽‍♂️',
    ':man-wearing-turban-dark-skin-tone:' => '👳🏿‍♂️',
    ':man-wearing-turban-light-skin-tone:' => '👳🏻‍♂️',
    ':man-wearing-turban-medium-dark-skin-tone:' => '👳🏾‍♂️',
    ':man-wearing-turban-medium-light-skin-tone:' => '👳🏼‍♂️',
    ':man-wearing-turban-medium-skin-tone:' => '👳🏽‍♂️',
    ':man-with-veil-dark-skin-tone:' => '👰🏿‍♂️',
    ':man-with-veil-light-skin-tone:' => '👰🏻‍♂️',
    ':man-with-veil-medium-dark-skin-tone:' => '👰🏾‍♂️',
    ':man-with-veil-medium-light-skin-tone:' => '👰🏼‍♂️',
    ':man-with-veil-medium-skin-tone:' => '👰🏽‍♂️',
    ':mermaid-dark-skin-tone:' => '🧜🏿‍♀️',
    ':mermaid-light-skin-tone:' => '🧜🏻‍♀️',
    ':mermaid-medium-dark-skin-tone:' => '🧜🏾‍♀️',
    ':mermaid-medium-light-skin-tone:' => '🧜🏼‍♀️',
    ':mermaid-medium-skin-tone:' => '🧜🏽‍♀️',
    ':merman-dark-skin-tone:' => '🧜🏿‍♂️',
    ':merman-light-skin-tone:' => '🧜🏻‍♂️',
    ':merman-medium-dark-skin-tone:' => '🧜🏾‍♂️',
    ':merman-medium-light-skin-tone:' => '🧜🏼‍♂️',
    ':merman-medium-skin-tone:' => '🧜🏽‍♂️',
    ':person-kneeling-facing-right-dark-skin-tone:' => '🧎🏿‍➡️',
    ':person-kneeling-facing-right-light-skin-tone:' => '🧎🏻‍➡️',
    ':person-kneeling-facing-right-medium-dark-skin-tone:' => '🧎🏾‍➡️',
    ':person-kneeling-facing-right-medium-light-skin-tone:' => '🧎🏼‍➡️',
    ':person-kneeling-facing-right-medium-skin-tone:' => '🧎🏽‍➡️',
    ':person-running-facing-right-dark-skin-tone:' => '🏃🏿‍➡️',
    ':person-running-facing-right-light-skin-tone:' => '🏃🏻‍➡️',
    ':person-running-facing-right-medium-dark-skin-tone:' => '🏃🏾‍➡️',
    ':person-running-facing-right-medium-light-skin-tone:' => '🏃🏼‍➡️',
    ':person-running-facing-right-medium-skin-tone:' => '🏃🏽‍➡️',
    ':person-walking-facing-right-dark-skin-tone:' => '🚶🏿‍➡️',
    ':person-walking-facing-right-light-skin-tone:' => '🚶🏻‍➡️',
    ':person-walking-facing-right-medium-dark-skin-tone:' => '🚶🏾‍➡️',
    ':person-walking-facing-right-medium-light-skin-tone:' => '🚶🏼‍➡️',
    ':person-walking-facing-right-medium-skin-tone:' => '🚶🏽‍➡️',
    ':pilot-dark-skin-tone:' => '🧑🏿‍✈️',
    ':pilot-light-skin-tone:' => '🧑🏻‍✈️',
    ':pilot-medium-dark-skin-tone:' => '🧑🏾‍✈️',
    ':pilot-medium-light-skin-tone:' => '🧑🏼‍✈️',
    ':pilot-medium-skin-tone:' => '🧑🏽‍✈️',
    ':woman-biking-dark-skin-tone:' => '🚴🏿‍♀️',
    ':woman-biking-light-skin-tone:' => '🚴🏻‍♀️',
    ':woman-biking-medium-dark-skin-tone:' => '🚴🏾‍♀️',
    ':woman-biking-medium-light-skin-tone:' => '🚴🏼‍♀️',
    ':woman-biking-medium-skin-tone:' => '🚴🏽‍♀️',
    ':woman-bouncing-ball-dark-skin-tone:' => '⛹🏿‍♀️',
    ':woman-bouncing-ball-light-skin-tone:' => '⛹🏻‍♀️',
    ':woman-bouncing-ball-medium-dark-skin-tone:' => '⛹🏾‍♀️',
    ':woman-bouncing-ball-medium-light-skin-tone:' => '⛹🏼‍♀️',
    ':woman-bouncing-ball-medium-skin-tone:' => '⛹🏽‍♀️',
    ':woman-bowing-dark-skin-tone:' => '🙇🏿‍♀️',
    ':woman-bowing-light-skin-tone:' => '🙇🏻‍♀️',
    ':woman-bowing-medium-dark-skin-tone:' => '🙇🏾‍♀️',
    ':woman-bowing-medium-light-skin-tone:' => '🙇🏼‍♀️',
    ':woman-bowing-medium-skin-tone:' => '🙇🏽‍♀️',
    ':woman-cartwheeling-dark-skin-tone:' => '🤸🏿‍♀️',
    ':woman-cartwheeling-light-skin-tone:' => '🤸🏻‍♀️',
    ':woman-cartwheeling-medium-dark-skin-tone:' => '🤸🏾‍♀️',
    ':woman-cartwheeling-medium-light-skin-tone:' => '🤸🏼‍♀️',
    ':woman-cartwheeling-medium-skin-tone:' => '🤸🏽‍♀️',
    ':woman-climbing-dark-skin-tone:' => '🧗🏿‍♀️',
    ':woman-climbing-light-skin-tone:' => '🧗🏻‍♀️',
    ':woman-climbing-medium-dark-skin-tone:' => '🧗🏾‍♀️',
    ':woman-climbing-medium-light-skin-tone:' => '🧗🏼‍♀️',
    ':woman-climbing-medium-skin-tone:' => '🧗🏽‍♀️',
    ':woman-construction-worker-dark-skin-tone:' => '👷🏿‍♀️',
    ':woman-construction-worker-light-skin-tone:' => '👷🏻‍♀️',
    ':woman-construction-worker-medium-dark-skin-tone:' => '👷🏾‍♀️',
    ':woman-construction-worker-medium-light-skin-tone:' => '👷🏼‍♀️',
    ':woman-construction-worker-medium-skin-tone:' => '👷🏽‍♀️',
    ':woman-dark-skin-tone-beard:' => '🧔🏿‍♀️',
    ':woman-dark-skin-tone-blond-hair:' => '👱🏿‍♀️',
    ':woman-detective:' => '🕵️‍♀️',
    ':woman-detective-dark-skin-tone:' => '🕵🏿‍♀️',
    ':woman-detective-light-skin-tone:' => '🕵🏻‍♀️',
    ':woman-detective-medium-dark-skin-tone:' => '🕵🏾‍♀️',
    ':woman-detective-medium-light-skin-tone:' => '🕵🏼‍♀️',
    ':woman-detective-medium-skin-tone:' => '🕵🏽‍♀️',
    ':woman-elf-dark-skin-tone:' => '🧝🏿‍♀️',
    ':woman-elf-light-skin-tone:' => '🧝🏻‍♀️',
    ':woman-elf-medium-dark-skin-tone:' => '🧝🏾‍♀️',
    ':woman-elf-medium-light-skin-tone:' => '🧝🏼‍♀️',
    ':woman-elf-medium-skin-tone:' => '🧝🏽‍♀️',
    ':woman-facepalming-dark-skin-tone:' => '🤦🏿‍♀️',
    ':woman-facepalming-light-skin-tone:' => '🤦🏻‍♀️',
    ':woman-facepalming-medium-dark-skin-tone:' => '🤦🏾‍♀️',
    ':woman-facepalming-medium-light-skin-tone:' => '🤦🏼‍♀️',
    ':woman-facepalming-medium-skin-tone:' => '🤦🏽‍♀️',
    ':woman-fairy-dark-skin-tone:' => '🧚🏿‍♀️',
    ':woman-fairy-light-skin-tone:' => '🧚🏻‍♀️',
    ':woman-fairy-medium-dark-skin-tone:' => '🧚🏾‍♀️',
    ':woman-fairy-medium-light-skin-tone:' => '🧚🏼‍♀️',
    ':woman-fairy-medium-skin-tone:' => '🧚🏽‍♀️',
    ':woman-frowning-dark-skin-tone:' => '🙍🏿‍♀️',
    ':woman-frowning-light-skin-tone:' => '🙍🏻‍♀️',
    ':woman-frowning-medium-dark-skin-tone:' => '🙍🏾‍♀️',
    ':woman-frowning-medium-light-skin-tone:' => '🙍🏼‍♀️',
    ':woman-frowning-medium-skin-tone:' => '🙍🏽‍♀️',
    ':woman-gesturing-no-dark-skin-tone:' => '🙅🏿‍♀️',
    ':woman-gesturing-no-light-skin-tone:' => '🙅🏻‍♀️',
    ':woman-gesturing-no-medium-dark-skin-tone:' => '🙅🏾‍♀️',
    ':woman-gesturing-no-medium-light-skin-tone:' => '🙅🏼‍♀️',
    ':woman-gesturing-no-medium-skin-tone:' => '🙅🏽‍♀️',
    ':woman-gesturing-ok-dark-skin-tone:' => '🙆🏿‍♀️',
    ':woman-gesturing-ok-light-skin-tone:' => '🙆🏻‍♀️',
    ':woman-gesturing-ok-medium-dark-skin-tone:' => '🙆🏾‍♀️',
    ':woman-gesturing-ok-medium-light-skin-tone:' => '🙆🏼‍♀️',
    ':woman-gesturing-ok-medium-skin-tone:' => '🙆🏽‍♀️',
    ':woman-getting-haircut-dark-skin-tone:' => '💇🏿‍♀️',
    ':woman-getting-haircut-light-skin-tone:' => '💇🏻‍♀️',
    ':woman-getting-haircut-medium-dark-skin-tone:' => '💇🏾‍♀️',
    ':woman-getting-haircut-medium-light-skin-tone:' => '💇🏼‍♀️',
    ':woman-getting-haircut-medium-skin-tone:' => '💇🏽‍♀️',
    ':woman-getting-massage-dark-skin-tone:' => '💆🏿‍♀️',
    ':woman-getting-massage-light-skin-tone:' => '💆🏻‍♀️',
    ':woman-getting-massage-medium-dark-skin-tone:' => '💆🏾‍♀️',
    ':woman-getting-massage-medium-light-skin-tone:' => '💆🏼‍♀️',
    ':woman-getting-massage-medium-skin-tone:' => '💆🏽‍♀️',
    ':woman-golfing-dark-skin-tone:' => '🏌🏿‍♀️',
    ':woman-golfing-light-skin-tone:' => '🏌🏻‍♀️',
    ':woman-golfing-medium-dark-skin-tone:' => '🏌🏾‍♀️',
    ':woman-golfing-medium-light-skin-tone:' => '🏌🏼‍♀️',
    ':woman-golfing-medium-skin-tone:' => '🏌🏽‍♀️',
    ':woman-guard-dark-skin-tone:' => '💂🏿‍♀️',
    ':woman-guard-light-skin-tone:' => '💂🏻‍♀️',
    ':woman-guard-medium-dark-skin-tone:' => '💂🏾‍♀️',
    ':woman-guard-medium-light-skin-tone:' => '💂🏼‍♀️',
    ':woman-guard-medium-skin-tone:' => '💂🏽‍♀️',
    ':woman-health-worker-dark-skin-tone:' => '👩🏿‍⚕️',
    ':woman-health-worker-light-skin-tone:' => '👩🏻‍⚕️',
    ':woman-health-worker-medium-dark-skin-tone:' => '👩🏾‍⚕️',
    ':woman-health-worker-medium-light-skin-tone:' => '👩🏼‍⚕️',
    ':woman-health-worker-medium-skin-tone:' => '👩🏽‍⚕️',
    ':woman-in-lotus-position-dark-skin-tone:' => '🧘🏿‍♀️',
    ':woman-in-lotus-position-light-skin-tone:' => '🧘🏻‍♀️',
    ':woman-in-lotus-position-medium-dark-skin-tone:' => '🧘🏾‍♀️',
    ':woman-in-lotus-position-medium-light-skin-tone:' => '🧘🏼‍♀️',
    ':woman-in-lotus-position-medium-skin-tone:' => '🧘🏽‍♀️',
    ':woman-in-steamy-room-dark-skin-tone:' => '🧖🏿‍♀️',
    ':woman-in-steamy-room-light-skin-tone:' => '🧖🏻‍♀️',
    ':woman-in-steamy-room-medium-dark-skin-tone:' => '🧖🏾‍♀️',
    ':woman-in-steamy-room-medium-light-skin-tone:' => '🧖🏼‍♀️',
    ':woman-in-steamy-room-medium-skin-tone:' => '🧖🏽‍♀️',
    ':woman-in-tuxedo-dark-skin-tone:' => '🤵🏿‍♀️',
    ':woman-in-tuxedo-light-skin-tone:' => '🤵🏻‍♀️',
    ':woman-in-tuxedo-medium-dark-skin-tone:' => '🤵🏾‍♀️',
    ':woman-in-tuxedo-medium-light-skin-tone:' => '🤵🏼‍♀️',
    ':woman-in-tuxedo-medium-skin-tone:' => '🤵🏽‍♀️',
    ':woman-judge-dark-skin-tone:' => '👩🏿‍⚖️',
    ':woman-judge-light-skin-tone:' => '👩🏻‍⚖️',
    ':woman-judge-medium-dark-skin-tone:' => '👩🏾‍⚖️',
    ':woman-judge-medium-light-skin-tone:' => '👩🏼‍⚖️',
    ':woman-judge-medium-skin-tone:' => '👩🏽‍⚖️',
    ':woman-juggling-dark-skin-tone:' => '🤹🏿‍♀️',
    ':woman-juggling-light-skin-tone:' => '🤹🏻‍♀️',
    ':woman-juggling-medium-dark-skin-tone:' => '🤹🏾‍♀️',
    ':woman-juggling-medium-light-skin-tone:' => '🤹🏼‍♀️',
    ':woman-juggling-medium-skin-tone:' => '🤹🏽‍♀️',
    ':woman-kneeling-dark-skin-tone:' => '🧎🏿‍♀️',
    ':woman-kneeling-light-skin-tone:' => '🧎🏻‍♀️',
    ':woman-kneeling-medium-dark-skin-tone:' => '🧎🏾‍♀️',
    ':woman-kneeling-medium-light-skin-tone:' => '🧎🏼‍♀️',
    ':woman-kneeling-medium-skin-tone:' => '🧎🏽‍♀️',
    ':woman-lifting-weights-dark-skin-tone:' => '🏋🏿‍♀️',
    ':woman-lifting-weights-light-skin-tone:' => '🏋🏻‍♀️',
    ':woman-lifting-weights-medium-dark-skin-tone:' => '🏋🏾‍♀️',
    ':woman-lifting-weights-medium-light-skin-tone:' => '🏋🏼‍♀️',
    ':woman-lifting-weights-medium-skin-tone:' => '🏋🏽‍♀️',
    ':woman-light-skin-tone-beard:' => '🧔🏻‍♀️',
    ':woman-light-skin-tone-blond-hair:' => '👱🏻‍♀️',
    ':woman-mage-dark-skin-tone:' => '🧙🏿‍♀️',
    ':woman-mage-light-skin-tone:' => '🧙🏻‍♀️',
    ':woman-mage-medium-dark-skin-tone:' => '🧙🏾‍♀️',
    ':woman-mage-medium-light-skin-tone:' => '🧙🏼‍♀️',
    ':woman-mage-medium-skin-tone:' => '🧙🏽‍♀️',
    ':woman-medium-dark-skin-tone-beard:' => '🧔🏾‍♀️',
    ':woman-medium-dark-skin-tone-blond-hair:' => '👱🏾‍♀️',
    ':woman-medium-light-skin-tone-beard:' => '🧔🏼‍♀️',
    ':woman-medium-light-skin-tone-blond-hair:' => '👱🏼‍♀️',
    ':woman-medium-skin-tone-beard:' => '🧔🏽‍♀️',
    ':woman-medium-skin-tone-blond-hair:' => '👱🏽‍♀️',
    ':woman-mountain-biking-dark-skin-tone:' => '🚵🏿‍♀️',
    ':woman-mountain-biking-light-skin-tone:' => '🚵🏻‍♀️',
    ':woman-mountain-biking-medium-dark-skin-tone:' => '🚵🏾‍♀️',
    ':woman-mountain-biking-medium-light-skin-tone:' => '🚵🏼‍♀️',
    ':woman-mountain-biking-medium-skin-tone:' => '🚵🏽‍♀️',
    ':woman-pilot-dark-skin-tone:' => '👩🏿‍✈️',
    ':woman-pilot-light-skin-tone:' => '👩🏻‍✈️',
    ':woman-pilot-medium-dark-skin-tone:' => '👩🏾‍✈️',
    ':woman-pilot-medium-light-skin-tone:' => '👩🏼‍✈️',
    ':woman-pilot-medium-skin-tone:' => '👩🏽‍✈️',
    ':woman-playing-handball-dark-skin-tone:' => '🤾🏿‍♀️',
    ':woman-playing-handball-light-skin-tone:' => '🤾🏻‍♀️',
    ':woman-playing-handball-medium-dark-skin-tone:' => '🤾🏾‍♀️',
    ':woman-playing-handball-medium-light-skin-tone:' => '🤾🏼‍♀️',
    ':woman-playing-handball-medium-skin-tone:' => '🤾🏽‍♀️',
    ':woman-playing-water-polo-dark-skin-tone:' => '🤽🏿‍♀️',
    ':woman-playing-water-polo-light-skin-tone:' => '🤽🏻‍♀️',
    ':woman-playing-water-polo-medium-dark-skin-tone:' => '🤽🏾‍♀️',
    ':woman-playing-water-polo-medium-light-skin-tone:' => '🤽🏼‍♀️',
    ':woman-playing-water-polo-medium-skin-tone:' => '🤽🏽‍♀️',
    ':woman-police-officer-dark-skin-tone:' => '👮🏿‍♀️',
    ':woman-police-officer-light-skin-tone:' => '👮🏻‍♀️',
    ':woman-police-officer-medium-dark-skin-tone:' => '👮🏾‍♀️',
    ':woman-police-officer-medium-light-skin-tone:' => '👮🏼‍♀️',
    ':woman-police-officer-medium-skin-tone:' => '👮🏽‍♀️',
    ':woman-pouting-dark-skin-tone:' => '🙎🏿‍♀️',
    ':woman-pouting-light-skin-tone:' => '🙎🏻‍♀️',
    ':woman-pouting-medium-dark-skin-tone:' => '🙎🏾‍♀️',
    ':woman-pouting-medium-light-skin-tone:' => '🙎🏼‍♀️',
    ':woman-pouting-medium-skin-tone:' => '🙎🏽‍♀️',
    ':woman-raising-hand-dark-skin-tone:' => '🙋🏿‍♀️',
    ':woman-raising-hand-light-skin-tone:' => '🙋🏻‍♀️',
    ':woman-raising-hand-medium-dark-skin-tone:' => '🙋🏾‍♀️',
    ':woman-raising-hand-medium-light-skin-tone:' => '🙋🏼‍♀️',
    ':woman-raising-hand-medium-skin-tone:' => '🙋🏽‍♀️',
    ':woman-rowing-boat-dark-skin-tone:' => '🚣🏿‍♀️',
    ':woman-rowing-boat-light-skin-tone:' => '🚣🏻‍♀️',
    ':woman-rowing-boat-medium-dark-skin-tone:' => '🚣🏾‍♀️',
    ':woman-rowing-boat-medium-light-skin-tone:' => '🚣🏼‍♀️',
    ':woman-rowing-boat-medium-skin-tone:' => '🚣🏽‍♀️',
    ':woman-running-dark-skin-tone:' => '🏃🏿‍♀️',
    ':woman-running-light-skin-tone:' => '🏃🏻‍♀️',
    ':woman-running-medium-dark-skin-tone:' => '🏃🏾‍♀️',
    ':woman-running-medium-light-skin-tone:' => '🏃🏼‍♀️',
    ':woman-running-medium-skin-tone:' => '🏃🏽‍♀️',
    ':woman-shrugging-dark-skin-tone:' => '🤷🏿‍♀️',
    ':woman-shrugging-light-skin-tone:' => '🤷🏻‍♀️',
    ':woman-shrugging-medium-dark-skin-tone:' => '🤷🏾‍♀️',
    ':woman-shrugging-medium-light-skin-tone:' => '🤷🏼‍♀️',
    ':woman-shrugging-medium-skin-tone:' => '🤷🏽‍♀️',
    ':woman-standing-dark-skin-tone:' => '🧍🏿‍♀️',
    ':woman-standing-light-skin-tone:' => '🧍🏻‍♀️',
    ':woman-standing-medium-dark-skin-tone:' => '🧍🏾‍♀️',
    ':woman-standing-medium-light-skin-tone:' => '🧍🏼‍♀️',
    ':woman-standing-medium-skin-tone:' => '🧍🏽‍♀️',
    ':woman-superhero-dark-skin-tone:' => '🦸🏿‍♀️',
    ':woman-superhero-light-skin-tone:' => '🦸🏻‍♀️',
    ':woman-superhero-medium-dark-skin-tone:' => '🦸🏾‍♀️',
    ':woman-superhero-medium-light-skin-tone:' => '🦸🏼‍♀️',
    ':woman-superhero-medium-skin-tone:' => '🦸🏽‍♀️',
    ':woman-supervillain-dark-skin-tone:' => '🦹🏿‍♀️',
    ':woman-supervillain-light-skin-tone:' => '🦹🏻‍♀️',
    ':woman-supervillain-medium-dark-skin-tone:' => '🦹🏾‍♀️',
    ':woman-supervillain-medium-light-skin-tone:' => '🦹🏼‍♀️',
    ':woman-supervillain-medium-skin-tone:' => '🦹🏽‍♀️',
    ':woman-surfing-dark-skin-tone:' => '🏄🏿‍♀️',
    ':woman-surfing-light-skin-tone:' => '🏄🏻‍♀️',
    ':woman-surfing-medium-dark-skin-tone:' => '🏄🏾‍♀️',
    ':woman-surfing-medium-light-skin-tone:' => '🏄🏼‍♀️',
    ':woman-surfing-medium-skin-tone:' => '🏄🏽‍♀️',
    ':woman-swimming-dark-skin-tone:' => '🏊🏿‍♀️',
    ':woman-swimming-light-skin-tone:' => '🏊🏻‍♀️',
    ':woman-swimming-medium-dark-skin-tone:' => '🏊🏾‍♀️',
    ':woman-swimming-medium-light-skin-tone:' => '🏊🏼‍♀️',
    ':woman-swimming-medium-skin-tone:' => '🏊🏽‍♀️',
    ':woman-tipping-hand-dark-skin-tone:' => '💁🏿‍♀️',
    ':woman-tipping-hand-light-skin-tone:' => '💁🏻‍♀️',
    ':woman-tipping-hand-medium-dark-skin-tone:' => '💁🏾‍♀️',
    ':woman-tipping-hand-medium-light-skin-tone:' => '💁🏼‍♀️',
    ':woman-tipping-hand-medium-skin-tone:' => '💁🏽‍♀️',
    ':woman-vampire-dark-skin-tone:' => '🧛🏿‍♀️',
    ':woman-vampire-light-skin-tone:' => '🧛🏻‍♀️',
    ':woman-vampire-medium-dark-skin-tone:' => '🧛🏾‍♀️',
    ':woman-vampire-medium-light-skin-tone:' => '🧛🏼‍♀️',
    ':woman-vampire-medium-skin-tone:' => '🧛🏽‍♀️',
    ':woman-walking-dark-skin-tone:' => '🚶🏿‍♀️',
    ':woman-walking-light-skin-tone:' => '🚶🏻‍♀️',
    ':woman-walking-medium-dark-skin-tone:' => '🚶🏾‍♀️',
    ':woman-walking-medium-light-skin-tone:' => '🚶🏼‍♀️',
    ':woman-walking-medium-skin-tone:' => '🚶🏽‍♀️',
    ':woman-wearing-turban-dark-skin-tone:' => '👳🏿‍♀️',
    ':woman-wearing-turban-light-skin-tone:' => '👳🏻‍♀️',
    ':woman-wearing-turban-medium-dark-skin-tone:' => '👳🏾‍♀️',
    ':woman-wearing-turban-medium-light-skin-tone:' => '👳🏼‍♀️',
    ':woman-wearing-turban-medium-skin-tone:' => '👳🏽‍♀️',
    ':woman-with-veil-dark-skin-tone:' => '👰🏿‍♀️',
    ':woman-with-veil-light-skin-tone:' => '👰🏻‍♀️',
    ':woman-with-veil-medium-dark-skin-tone:' => '👰🏾‍♀️',
    ':woman-with-veil-medium-light-skin-tone:' => '👰🏼‍♀️',
    ':woman-with-veil-medium-skin-tone:' => '👰🏽‍♀️',
    ':man-heart-man:' => '👨‍❤️‍👨',
    ':man-in-manual-wheelchair-facing-right:' => '👨‍🦽‍➡️',
    ':man-in-motorized-wheelchair-facing-right:' => '👨‍🦼‍➡️',
    ':man-with-white-cane-facing-right:' => '👨‍🦯‍➡️',
    ':person-in-manual-wheelchair-facing-right:' => '🧑‍🦽‍➡️',
    ':person-in-motorized-wheelchair-facing-right:' => '🧑‍🦼‍➡️',
    ':person-with-white-cane-facing-right:' => '🧑‍🦯‍➡️',
    ':woman-heart-man:' => '👩‍❤️‍👨',
    ':woman-heart-woman:' => '👩‍❤️‍👩',
    ':woman-in-manual-wheelchair-facing-right:' => '👩‍🦽‍➡️',
    ':woman-in-motorized-wheelchair-facing-right:' => '👩‍🦼‍➡️',
    ':woman-with-white-cane-facing-right:' => '👩‍🦯‍➡️',
    ':couple-mm:' => '👨‍❤️‍👨',
    ':couple-ww:' => '👩‍❤️‍👩',
    ':family-adult-adult-child-child:' => '🧑‍🧑‍🧒‍🧒',
    ':flag-england:' => '🏴󠁧󠁢󠁥󠁮󠁧󠁿',
    ':flag-scotland:' => '🏴󠁧󠁢󠁳󠁣󠁴󠁿',
    ':flag-wales:' => '🏴󠁧󠁢󠁷󠁬󠁳󠁿',
    ':man-kneeling-facing-right:' => '🧎‍♂️‍➡️',
    ':man-man-boy-boy:' => '👨‍👨‍👦‍👦',
    ':man-man-girl-boy:' => '👨‍👨‍👧‍👦',
    ':man-man-girl-girl:' => '👨‍👨‍👧‍👧',
    ':man-running-facing-right:' => '🏃‍♂️‍➡️',
    ':man-walking-facing-right:' => '🚶‍♂️‍➡️',
    ':man-woman-boy-boy:' => '👨‍👩‍👦‍👦',
    ':man-woman-girl-boy:' => '👨‍👩‍👧‍👦',
    ':man-woman-girl-girl:' => '👨‍👩‍👧‍👧',
    ':woman-kneeling-facing-right:' => '🧎‍♀️‍➡️',
    ':woman-running-facing-right:' => '🏃‍♀️‍➡️',
    ':woman-walking-facing-right:' => '🚶‍♀️‍➡️',
    ':woman-woman-boy-boy:' => '👩‍👩‍👦‍👦',
    ':woman-woman-girl-boy:' => '👩‍👩‍👧‍👦',
    ':woman-woman-girl-girl:' => '👩‍👩‍👧‍👧',
    ':couplekiss-man-man:' => '👨‍❤‍💋‍👨',
    ':couplekiss-man-woman:' => '👩‍❤‍💋‍👨',
    ':couplekiss-woman-woman:' => '👩‍❤‍💋‍👩',
    ':england:' => '🏴󠁧󠁢󠁥󠁮󠁧󠁿',
    ':family-man-man-boy-boy:' => '👨‍👨‍👦‍👦',
    ':family-man-man-girl-boy:' => '👨‍👨‍👧‍👦',
    ':family-man-man-girl-girl:' => '👨‍👨‍👧‍👧',
    ':family-man-woman-boy-boy:' => '👨‍👩‍👦‍👦',
    ':family-man-woman-girl-boy:' => '👨‍👩‍👧‍👦',
    ':family-man-woman-girl-girl:' => '👨‍👩‍👧‍👧',
    ':family-mmbb:' => '👨‍👨‍👦‍👦',
    ':family-mmgb:' => '👨‍👨‍👧‍👦',
    ':family-mmgg:' => '👨‍👨‍👧‍👧',
    ':family-mwbb:' => '👨‍👩‍👦‍👦',
    ':family-mwgb:' => '👨‍👩‍👧‍👦',
    ':family-mwgg:' => '👨‍👩‍👧‍👧',
    ':family-woman-woman-boy-boy:' => '👩‍👩‍👦‍👦',
    ':family-woman-woman-girl-boy:' => '👩‍👩‍👧‍👦',
    ':family-woman-woman-girl-girl:' => '👩‍👩‍👧‍👧',
    ':family-wwbb:' => '👩‍👩‍👦‍👦',
    ':family-wwgb:' => '👩‍👩‍👧‍👦',
    ':family-wwgg:' => '👩‍👩‍👧‍👧',
    ':man-in-manual-wheelchair-facing-right-dark-skin-tone:' => '👨🏿‍🦽‍➡️',
    ':man-in-manual-wheelchair-facing-right-light-skin-tone:' => '👨🏻‍🦽‍➡️',
    ':man-in-manual-wheelchair-facing-right-medium-dark-skin-tone:' => '👨🏾‍🦽‍➡️',
    ':man-in-manual-wheelchair-facing-right-medium-light-skin-tone:' => '👨🏼‍🦽‍➡️',
    ':man-in-manual-wheelchair-facing-right-medium-skin-tone:' => '👨🏽‍🦽‍➡️',
    ':man-in-motorized-wheelchair-facing-right-dark-skin-tone:' => '👨🏿‍🦼‍➡️',
    ':man-in-motorized-wheelchair-facing-right-light-skin-tone:' => '👨🏻‍🦼‍➡️',
    ':man-in-motorized-wheelchair-facing-right-medium-dark-skin-tone:' => '👨🏾‍🦼‍➡️',
    ':man-in-motorized-wheelchair-facing-right-medium-light-skin-tone:' => '👨🏼‍🦼‍➡️',
    ':man-in-motorized-wheelchair-facing-right-medium-skin-tone:' => '👨🏽‍🦼‍➡️',
    ':man-with-white-cane-facing-right-dark-skin-tone:' => '👨🏿‍🦯‍➡️',
    ':man-with-white-cane-facing-right-light-skin-tone:' => '👨🏻‍🦯‍➡️',
    ':man-with-white-cane-facing-right-medium-dark-skin-tone:' => '👨🏾‍🦯‍➡️',
    ':man-with-white-cane-facing-right-medium-light-skin-tone:' => '👨🏼‍🦯‍➡️',
    ':man-with-white-cane-facing-right-medium-skin-tone:' => '👨🏽‍🦯‍➡️',
    ':men-holding-hands-dark-skin-tone-light-skin-tone:' => '👨🏿‍🤝‍👨🏻',
    ':men-holding-hands-dark-skin-tone-medium-dark-skin-tone:' => '👨🏿‍🤝‍👨🏾',
    ':men-holding-hands-dark-skin-tone-medium-light-skin-tone:' => '👨🏿‍🤝‍👨🏼',
    ':men-holding-hands-dark-skin-tone-medium-skin-tone:' => '👨🏿‍🤝‍👨🏽',
    ':men-holding-hands-light-skin-tone-dark-skin-tone:' => '👨🏻‍🤝‍👨🏿',
    ':men-holding-hands-light-skin-tone-medium-dark-skin-tone:' => '👨🏻‍🤝‍👨🏾',
    ':men-holding-hands-light-skin-tone-medium-light-skin-tone:' => '👨🏻‍🤝‍👨🏼',
    ':men-holding-hands-light-skin-tone-medium-skin-tone:' => '👨🏻‍🤝‍👨🏽',
    ':men-holding-hands-medium-dark-skin-tone-dark-skin-tone:' => '👨🏾‍🤝‍👨🏿',
    ':men-holding-hands-medium-dark-skin-tone-light-skin-tone:' => '👨🏾‍🤝‍👨🏻',
    ':men-holding-hands-medium-dark-skin-tone-medium-light-skin-tone:' => '👨🏾‍🤝‍👨🏼',
    ':men-holding-hands-medium-dark-skin-tone-medium-skin-tone:' => '👨🏾‍🤝‍👨🏽',
    ':men-holding-hands-medium-light-skin-tone-dark-skin-tone:' => '👨🏼‍🤝‍👨🏿',
    ':men-holding-hands-medium-light-skin-tone-light-skin-tone:' => '👨🏼‍🤝‍👨🏻',
    ':men-holding-hands-medium-light-skin-tone-medium-dark-skin-tone:' => '👨🏼‍🤝‍👨🏾',
    ':men-holding-hands-medium-light-skin-tone-medium-skin-tone:' => '👨🏼‍🤝‍👨🏽',
    ':men-holding-hands-medium-skin-tone-dark-skin-tone:' => '👨🏽‍🤝‍👨🏿',
    ':men-holding-hands-medium-skin-tone-light-skin-tone:' => '👨🏽‍🤝‍👨🏻',
    ':men-holding-hands-medium-skin-tone-medium-dark-skin-tone:' => '👨🏽‍🤝‍👨🏾',
    ':men-holding-hands-medium-skin-tone-medium-light-skin-tone:' => '👨🏽‍🤝‍👨🏼',
    ':people-holding-hands-dark-skin-tone:' => '🧑🏿‍🤝‍🧑🏿',
    ':people-holding-hands-dark-skin-tone-light-skin-tone:' => '🧑🏿‍🤝‍🧑🏻',
    ':people-holding-hands-dark-skin-tone-medium-dark-skin-tone:' => '🧑🏿‍🤝‍🧑🏾',
    ':people-holding-hands-dark-skin-tone-medium-light-skin-tone:' => '🧑🏿‍🤝‍🧑🏼',
    ':people-holding-hands-dark-skin-tone-medium-skin-tone:' => '🧑🏿‍🤝‍🧑🏽',
    ':people-holding-hands-light-skin-tone:' => '🧑🏻‍🤝‍🧑🏻',
    ':people-holding-hands-light-skin-tone-dark-skin-tone:' => '🧑🏻‍🤝‍🧑🏿',
    ':people-holding-hands-light-skin-tone-medium-dark-skin-tone:' => '🧑🏻‍🤝‍🧑🏾',
    ':people-holding-hands-light-skin-tone-medium-light-skin-tone:' => '🧑🏻‍🤝‍🧑🏼',
    ':people-holding-hands-light-skin-tone-medium-skin-tone:' => '🧑🏻‍🤝‍🧑🏽',
    ':people-holding-hands-medium-dark-skin-tone:' => '🧑🏾‍🤝‍🧑🏾',
    ':people-holding-hands-medium-dark-skin-tone-dark-skin-tone:' => '🧑🏾‍🤝‍🧑🏿',
    ':people-holding-hands-medium-dark-skin-tone-light-skin-tone:' => '🧑🏾‍🤝‍🧑🏻',
    ':people-holding-hands-medium-dark-skin-tone-medium-light-skin-tone:' => '🧑🏾‍🤝‍🧑🏼',
    ':people-holding-hands-medium-dark-skin-tone-medium-skin-tone:' => '🧑🏾‍🤝‍🧑🏽',
    ':people-holding-hands-medium-light-skin-tone:' => '🧑🏼‍🤝‍🧑🏼',
    ':people-holding-hands-medium-light-skin-tone-dark-skin-tone:' => '🧑🏼‍🤝‍🧑🏿',
    ':people-holding-hands-medium-light-skin-tone-light-skin-tone:' => '🧑🏼‍🤝‍🧑🏻',
    ':people-holding-hands-medium-light-skin-tone-medium-dark-skin-tone:' => '🧑🏼‍🤝‍🧑🏾',
    ':people-holding-hands-medium-light-skin-tone-medium-skin-tone:' => '🧑🏼‍🤝‍🧑🏽',
    ':people-holding-hands-medium-skin-tone:' => '🧑🏽‍🤝‍🧑🏽',
    ':people-holding-hands-medium-skin-tone-dark-skin-tone:' => '🧑🏽‍🤝‍🧑🏿',
    ':people-holding-hands-medium-skin-tone-light-skin-tone:' => '🧑🏽‍🤝‍🧑🏻',
    ':people-holding-hands-medium-skin-tone-medium-dark-skin-tone:' => '🧑🏽‍🤝‍🧑🏾',
    ':people-holding-hands-medium-skin-tone-medium-light-skin-tone:' => '🧑🏽‍🤝‍🧑🏼',
    ':person-in-manual-wheelchair-facing-right-dark-skin-tone:' => '🧑🏿‍🦽‍➡️',
    ':person-in-manual-wheelchair-facing-right-light-skin-tone:' => '🧑🏻‍🦽‍➡️',
    ':person-in-manual-wheelchair-facing-right-medium-dark-skin-tone:' => '🧑🏾‍🦽‍➡️',
    ':person-in-manual-wheelchair-facing-right-medium-light-skin-tone:' => '🧑🏼‍🦽‍➡️',
    ':person-in-manual-wheelchair-facing-right-medium-skin-tone:' => '🧑🏽‍🦽‍➡️',
    ':person-in-motorized-wheelchair-facing-right-dark-skin-tone:' => '🧑🏿‍🦼‍➡️',
    ':person-in-motorized-wheelchair-facing-right-light-skin-tone:' => '🧑🏻‍🦼‍➡️',
    ':person-in-motorized-wheelchair-facing-right-medium-dark-skin-tone:' => '🧑🏾‍🦼‍➡️',
    ':person-in-motorized-wheelchair-facing-right-medium-light-skin-tone:' => '🧑🏼‍🦼‍➡️',
    ':person-in-motorized-wheelchair-facing-right-medium-skin-tone:' => '🧑🏽‍🦼‍➡️',
    ':person-with-white-cane-facing-right-dark-skin-tone:' => '🧑🏿‍🦯‍➡️',
    ':person-with-white-cane-facing-right-light-skin-tone:' => '🧑🏻‍🦯‍➡️',
    ':person-with-white-cane-facing-right-medium-dark-skin-tone:' => '🧑🏾‍🦯‍➡️',
    ':person-with-white-cane-facing-right-medium-light-skin-tone:' => '🧑🏼‍🦯‍➡️',
    ':person-with-white-cane-facing-right-medium-skin-tone:' => '🧑🏽‍🦯‍➡️',
    ':scotland:' => '🏴󠁧󠁢󠁳󠁣󠁴󠁿',
    ':wales:' => '🏴󠁧󠁢󠁷󠁬󠁳󠁿',
    ':woman-and-man-holding-hands-dark-skin-tone-light-skin-tone:' => '👩🏿‍🤝‍👨🏻',
    ':woman-and-man-holding-hands-dark-skin-tone-medium-dark-skin-tone:' => '👩🏿‍🤝‍👨🏾',
    ':woman-and-man-holding-hands-dark-skin-tone-medium-light-skin-tone:' => '👩🏿‍🤝‍👨🏼',
    ':woman-and-man-holding-hands-dark-skin-tone-medium-skin-tone:' => '👩🏿‍🤝‍👨🏽',
    ':woman-and-man-holding-hands-light-skin-tone-dark-skin-tone:' => '👩🏻‍🤝‍👨🏿',
    ':woman-and-man-holding-hands-light-skin-tone-medium-dark-skin-tone:' => '👩🏻‍🤝‍👨🏾',
    ':woman-and-man-holding-hands-light-skin-tone-medium-light-skin-tone:' => '👩🏻‍🤝‍👨🏼',
    ':woman-and-man-holding-hands-light-skin-tone-medium-skin-tone:' => '👩🏻‍🤝‍👨🏽',
    ':woman-and-man-holding-hands-medium-dark-skin-tone-dark-skin-tone:' => '👩🏾‍🤝‍👨🏿',
    ':woman-and-man-holding-hands-medium-dark-skin-tone-light-skin-tone:' => '👩🏾‍🤝‍👨🏻',
    ':woman-and-man-holding-hands-medium-dark-skin-tone-medium-light-skin-tone:' => '👩🏾‍🤝‍👨🏼',
    ':woman-and-man-holding-hands-medium-dark-skin-tone-medium-skin-tone:' => '👩🏾‍🤝‍👨🏽',
    ':woman-and-man-holding-hands-medium-light-skin-tone-dark-skin-tone:' => '👩🏼‍🤝‍👨🏿',
    ':woman-and-man-holding-hands-medium-light-skin-tone-light-skin-tone:' => '👩🏼‍🤝‍👨🏻',
    ':woman-and-man-holding-hands-medium-light-skin-tone-medium-dark-skin-tone:' => '👩🏼‍🤝‍👨🏾',
    ':woman-and-man-holding-hands-medium-light-skin-tone-medium-skin-tone:' => '👩🏼‍🤝‍👨🏽',
    ':woman-and-man-holding-hands-medium-skin-tone-dark-skin-tone:' => '👩🏽‍🤝‍👨🏿',
    ':woman-and-man-holding-hands-medium-skin-tone-light-skin-tone:' => '👩🏽‍🤝‍👨🏻',
    ':woman-and-man-holding-hands-medium-skin-tone-medium-dark-skin-tone:' => '👩🏽‍🤝‍👨🏾',
    ':woman-and-man-holding-hands-medium-skin-tone-medium-light-skin-tone:' => '👩🏽‍🤝‍👨🏼',
    ':woman-in-manual-wheelchair-facing-right-dark-skin-tone:' => '👩🏿‍🦽‍➡️',
    ':woman-in-manual-wheelchair-facing-right-light-skin-tone:' => '👩🏻‍🦽‍➡️',
    ':woman-in-manual-wheelchair-facing-right-medium-dark-skin-tone:' => '👩🏾‍🦽‍➡️',
    ':woman-in-manual-wheelchair-facing-right-medium-light-skin-tone:' => '👩🏼‍🦽‍➡️',
    ':woman-in-manual-wheelchair-facing-right-medium-skin-tone:' => '👩🏽‍🦽‍➡️',
    ':woman-in-motorized-wheelchair-facing-right-dark-skin-tone:' => '👩🏿‍🦼‍➡️',
    ':woman-in-motorized-wheelchair-facing-right-light-skin-tone:' => '👩🏻‍🦼‍➡️',
    ':woman-in-motorized-wheelchair-facing-right-medium-dark-skin-tone:' => '👩🏾‍🦼‍➡️',
    ':woman-in-motorized-wheelchair-facing-right-medium-light-skin-tone:' => '👩🏼‍🦼‍➡️',
    ':woman-in-motorized-wheelchair-facing-right-medium-skin-tone:' => '👩🏽‍🦼‍➡️',
    ':woman-with-white-cane-facing-right-dark-skin-tone:' => '👩🏿‍🦯‍➡️',
    ':woman-with-white-cane-facing-right-light-skin-tone:' => '👩🏻‍🦯‍➡️',
    ':woman-with-white-cane-facing-right-medium-dark-skin-tone:' => '👩🏾‍🦯‍➡️',
    ':woman-with-white-cane-facing-right-medium-light-skin-tone:' => '👩🏼‍🦯‍➡️',
    ':woman-with-white-cane-facing-right-medium-skin-tone:' => '👩🏽‍🦯‍➡️',
    ':women-holding-hands-dark-skin-tone-light-skin-tone:' => '👩🏿‍🤝‍👩🏻',
    ':women-holding-hands-dark-skin-tone-medium-dark-skin-tone:' => '👩🏿‍🤝‍👩🏾',
    ':women-holding-hands-dark-skin-tone-medium-light-skin-tone:' => '👩🏿‍🤝‍👩🏼',
    ':women-holding-hands-dark-skin-tone-medium-skin-tone:' => '👩🏿‍🤝‍👩🏽',
    ':women-holding-hands-light-skin-tone-dark-skin-tone:' => '👩🏻‍🤝‍👩🏿',
    ':women-holding-hands-light-skin-tone-medium-dark-skin-tone:' => '👩🏻‍🤝‍👩🏾',
    ':women-holding-hands-light-skin-tone-medium-light-skin-tone:' => '👩🏻‍🤝‍👩🏼',
    ':women-holding-hands-light-skin-tone-medium-skin-tone:' => '👩🏻‍🤝‍👩🏽',
    ':women-holding-hands-medium-dark-skin-tone-dark-skin-tone:' => '👩🏾‍🤝‍👩🏿',
    ':women-holding-hands-medium-dark-skin-tone-light-skin-tone:' => '👩🏾‍🤝‍👩🏻',
    ':women-holding-hands-medium-dark-skin-tone-medium-light-skin-tone:' => '👩🏾‍🤝‍👩🏼',
    ':women-holding-hands-medium-dark-skin-tone-medium-skin-tone:' => '👩🏾‍🤝‍👩🏽',
    ':women-holding-hands-medium-light-skin-tone-dark-skin-tone:' => '👩🏼‍🤝‍👩🏿',
    ':women-holding-hands-medium-light-skin-tone-light-skin-tone:' => '👩🏼‍🤝‍👩🏻',
    ':women-holding-hands-medium-light-skin-tone-medium-dark-skin-tone:' => '👩🏼‍🤝‍👩🏾',
    ':women-holding-hands-medium-light-skin-tone-medium-skin-tone:' => '👩🏼‍🤝‍👩🏽',
    ':women-holding-hands-medium-skin-tone-dark-skin-tone:' => '👩🏽‍🤝‍👩🏿',
    ':women-holding-hands-medium-skin-tone-light-skin-tone:' => '👩🏽‍🤝‍👩🏻',
    ':women-holding-hands-medium-skin-tone-medium-dark-skin-tone:' => '👩🏽‍🤝‍👩🏾',
    ':women-holding-hands-medium-skin-tone-medium-light-skin-tone:' => '👩🏽‍🤝‍👩🏼',
    ':man-kiss-man:' => '👨‍❤️‍💋‍👨',
    ':woman-kiss-man:' => '👩‍❤️‍💋‍👨',
    ':woman-kiss-woman:' => '👩‍❤️‍💋‍👩',
    ':couple-with-heart-man-man-dark-skin-tone:' => '👨🏿‍❤️‍👨🏿',
    ':couple-with-heart-man-man-dark-skin-tone-light-skin-tone:' => '👨🏿‍❤️‍👨🏻',
    ':couple-with-heart-man-man-dark-skin-tone-medium-dark-skin-tone:' => '👨🏿‍❤️‍👨🏾',
    ':couple-with-heart-man-man-dark-skin-tone-medium-light-skin-tone:' => '👨🏿‍❤️‍👨🏼',
    ':couple-with-heart-man-man-dark-skin-tone-medium-skin-tone:' => '👨🏿‍❤️‍👨🏽',
    ':couple-with-heart-man-man-light-skin-tone:' => '👨🏻‍❤️‍👨🏻',
    ':couple-with-heart-man-man-light-skin-tone-dark-skin-tone:' => '👨🏻‍❤️‍👨🏿',
    ':couple-with-heart-man-man-light-skin-tone-medium-dark-skin-tone:' => '👨🏻‍❤️‍👨🏾',
    ':couple-with-heart-man-man-light-skin-tone-medium-light-skin-tone:' => '👨🏻‍❤️‍👨🏼',
    ':couple-with-heart-man-man-light-skin-tone-medium-skin-tone:' => '👨🏻‍❤️‍👨🏽',
    ':couple-with-heart-man-man-medium-dark-skin-tone:' => '👨🏾‍❤️‍👨🏾',
    ':couple-with-heart-man-man-medium-dark-skin-tone-dark-skin-tone:' => '👨🏾‍❤️‍👨🏿',
    ':couple-with-heart-man-man-medium-dark-skin-tone-light-skin-tone:' => '👨🏾‍❤️‍👨🏻',
    ':couple-with-heart-man-man-medium-dark-skin-tone-medium-light-skin-tone:' => '👨🏾‍❤️‍👨🏼',
    ':couple-with-heart-man-man-medium-dark-skin-tone-medium-skin-tone:' => '👨🏾‍❤️‍👨🏽',
    ':couple-with-heart-man-man-medium-light-skin-tone:' => '👨🏼‍❤️‍👨🏼',
    ':couple-with-heart-man-man-medium-light-skin-tone-dark-skin-tone:' => '👨🏼‍❤️‍👨🏿',
    ':couple-with-heart-man-man-medium-light-skin-tone-light-skin-tone:' => '👨🏼‍❤️‍👨🏻',
    ':couple-with-heart-man-man-medium-light-skin-tone-medium-dark-skin-tone:' => '👨🏼‍❤️‍👨🏾',
    ':couple-with-heart-man-man-medium-light-skin-tone-medium-skin-tone:' => '👨🏼‍❤️‍👨🏽',
    ':couple-with-heart-man-man-medium-skin-tone:' => '👨🏽‍❤️‍👨🏽',
    ':couple-with-heart-man-man-medium-skin-tone-dark-skin-tone:' => '👨🏽‍❤️‍👨🏿',
    ':couple-with-heart-man-man-medium-skin-tone-light-skin-tone:' => '👨🏽‍❤️‍👨🏻',
    ':couple-with-heart-man-man-medium-skin-tone-medium-dark-skin-tone:' => '👨🏽‍❤️‍👨🏾',
    ':couple-with-heart-man-man-medium-skin-tone-medium-light-skin-tone:' => '👨🏽‍❤️‍👨🏼',
    ':couple-with-heart-person-person-dark-skin-tone-light-skin-tone:' => '🧑🏿‍❤️‍🧑🏻',
    ':couple-with-heart-person-person-dark-skin-tone-medium-dark-skin-tone:' => '🧑🏿‍❤️‍🧑🏾',
    ':couple-with-heart-person-person-dark-skin-tone-medium-light-skin-tone:' => '🧑🏿‍❤️‍🧑🏼',
    ':couple-with-heart-person-person-dark-skin-tone-medium-skin-tone:' => '🧑🏿‍❤️‍🧑🏽',
    ':couple-with-heart-person-person-light-skin-tone-dark-skin-tone:' => '🧑🏻‍❤️‍🧑🏿',
    ':couple-with-heart-person-person-light-skin-tone-medium-dark-skin-tone:' => '🧑🏻‍❤️‍🧑🏾',
    ':couple-with-heart-person-person-light-skin-tone-medium-light-skin-tone:' => '🧑🏻‍❤️‍🧑🏼',
    ':couple-with-heart-person-person-light-skin-tone-medium-skin-tone:' => '🧑🏻‍❤️‍🧑🏽',
    ':couple-with-heart-person-person-medium-dark-skin-tone-dark-skin-tone:' => '🧑🏾‍❤️‍🧑🏿',
    ':couple-with-heart-person-person-medium-dark-skin-tone-light-skin-tone:' => '🧑🏾‍❤️‍🧑🏻',
    ':couple-with-heart-person-person-medium-dark-skin-tone-medium-light-skin-tone:' => '🧑🏾‍❤️‍🧑🏼',
    ':couple-with-heart-person-person-medium-dark-skin-tone-medium-skin-tone:' => '🧑🏾‍❤️‍🧑🏽',
    ':couple-with-heart-person-person-medium-light-skin-tone-dark-skin-tone:' => '🧑🏼‍❤️‍🧑🏿',
    ':couple-with-heart-person-person-medium-light-skin-tone-light-skin-tone:' => '🧑🏼‍❤️‍🧑🏻',
    ':couple-with-heart-person-person-medium-light-skin-tone-medium-dark-skin-tone:' => '🧑🏼‍❤️‍🧑🏾',
    ':couple-with-heart-person-person-medium-light-skin-tone-medium-skin-tone:' => '🧑🏼‍❤️‍🧑🏽',
    ':couple-with-heart-person-person-medium-skin-tone-dark-skin-tone:' => '🧑🏽‍❤️‍🧑🏿',
    ':couple-with-heart-person-person-medium-skin-tone-light-skin-tone:' => '🧑🏽‍❤️‍🧑🏻',
    ':couple-with-heart-person-person-medium-skin-tone-medium-dark-skin-tone:' => '🧑🏽‍❤️‍🧑🏾',
    ':couple-with-heart-person-person-medium-skin-tone-medium-light-skin-tone:' => '🧑🏽‍❤️‍🧑🏼',
    ':couple-with-heart-woman-man-dark-skin-tone:' => '👩🏿‍❤️‍👨🏿',
    ':couple-with-heart-woman-man-dark-skin-tone-light-skin-tone:' => '👩🏿‍❤️‍👨🏻',
    ':couple-with-heart-woman-man-dark-skin-tone-medium-dark-skin-tone:' => '👩🏿‍❤️‍👨🏾',
    ':couple-with-heart-woman-man-dark-skin-tone-medium-light-skin-tone:' => '👩🏿‍❤️‍👨🏼',
    ':couple-with-heart-woman-man-dark-skin-tone-medium-skin-tone:' => '👩🏿‍❤️‍👨🏽',
    ':couple-with-heart-woman-man-light-skin-tone:' => '👩🏻‍❤️‍👨🏻',
    ':couple-with-heart-woman-man-light-skin-tone-dark-skin-tone:' => '👩🏻‍❤️‍👨🏿',
    ':couple-with-heart-woman-man-light-skin-tone-medium-dark-skin-tone:' => '👩🏻‍❤️‍👨🏾',
    ':couple-with-heart-woman-man-light-skin-tone-medium-light-skin-tone:' => '👩🏻‍❤️‍👨🏼',
    ':couple-with-heart-woman-man-light-skin-tone-medium-skin-tone:' => '👩🏻‍❤️‍👨🏽',
    ':couple-with-heart-woman-man-medium-dark-skin-tone:' => '👩🏾‍❤️‍👨🏾',
    ':couple-with-heart-woman-man-medium-dark-skin-tone-dark-skin-tone:' => '👩🏾‍❤️‍👨🏿',
    ':couple-with-heart-woman-man-medium-dark-skin-tone-light-skin-tone:' => '👩🏾‍❤️‍👨🏻',
    ':couple-with-heart-woman-man-medium-dark-skin-tone-medium-light-skin-tone:' => '👩🏾‍❤️‍👨🏼',
    ':couple-with-heart-woman-man-medium-dark-skin-tone-medium-skin-tone:' => '👩🏾‍❤️‍👨🏽',
    ':couple-with-heart-woman-man-medium-light-skin-tone:' => '👩🏼‍❤️‍👨🏼',
    ':couple-with-heart-woman-man-medium-light-skin-tone-dark-skin-tone:' => '👩🏼‍❤️‍👨🏿',
    ':couple-with-heart-woman-man-medium-light-skin-tone-light-skin-tone:' => '👩🏼‍❤️‍👨🏻',
    ':couple-with-heart-woman-man-medium-light-skin-tone-medium-dark-skin-tone:' => '👩🏼‍❤️‍👨🏾',
    ':couple-with-heart-woman-man-medium-light-skin-tone-medium-skin-tone:' => '👩🏼‍❤️‍👨🏽',
    ':couple-with-heart-woman-man-medium-skin-tone:' => '👩🏽‍❤️‍👨🏽',
    ':couple-with-heart-woman-man-medium-skin-tone-dark-skin-tone:' => '👩🏽‍❤️‍👨🏿',
    ':couple-with-heart-woman-man-medium-skin-tone-light-skin-tone:' => '👩🏽‍❤️‍👨🏻',
    ':couple-with-heart-woman-man-medium-skin-tone-medium-dark-skin-tone:' => '👩🏽‍❤️‍👨🏾',
    ':couple-with-heart-woman-man-medium-skin-tone-medium-light-skin-tone:' => '👩🏽‍❤️‍👨🏼',
    ':couple-with-heart-woman-woman-dark-skin-tone:' => '👩🏿‍❤️‍👩🏿',
    ':couple-with-heart-woman-woman-dark-skin-tone-light-skin-tone:' => '👩🏿‍❤️‍👩🏻',
    ':couple-with-heart-woman-woman-dark-skin-tone-medium-dark-skin-tone:' => '👩🏿‍❤️‍👩🏾',
    ':couple-with-heart-woman-woman-dark-skin-tone-medium-light-skin-tone:' => '👩🏿‍❤️‍👩🏼',
    ':couple-with-heart-woman-woman-dark-skin-tone-medium-skin-tone:' => '👩🏿‍❤️‍👩🏽',
    ':couple-with-heart-woman-woman-light-skin-tone:' => '👩🏻‍❤️‍👩🏻',
    ':couple-with-heart-woman-woman-light-skin-tone-dark-skin-tone:' => '👩🏻‍❤️‍👩🏿',
    ':couple-with-heart-woman-woman-light-skin-tone-medium-dark-skin-tone:' => '👩🏻‍❤️‍👩🏾',
    ':couple-with-heart-woman-woman-light-skin-tone-medium-light-skin-tone:' => '👩🏻‍❤️‍👩🏼',
    ':couple-with-heart-woman-woman-light-skin-tone-medium-skin-tone:' => '👩🏻‍❤️‍👩🏽',
    ':couple-with-heart-woman-woman-medium-dark-skin-tone:' => '👩🏾‍❤️‍👩🏾',
    ':couple-with-heart-woman-woman-medium-dark-skin-tone-dark-skin-tone:' => '👩🏾‍❤️‍👩🏿',
    ':couple-with-heart-woman-woman-medium-dark-skin-tone-light-skin-tone:' => '👩🏾‍❤️‍👩🏻',
    ':couple-with-heart-woman-woman-medium-dark-skin-tone-medium-light-skin-tone:' => '👩🏾‍❤️‍👩🏼',
    ':couple-with-heart-woman-woman-medium-dark-skin-tone-medium-skin-tone:' => '👩🏾‍❤️‍👩🏽',
    ':couple-with-heart-woman-woman-medium-light-skin-tone:' => '👩🏼‍❤️‍👩🏼',
    ':couple-with-heart-woman-woman-medium-light-skin-tone-dark-skin-tone:' => '👩🏼‍❤️‍👩🏿',
    ':couple-with-heart-woman-woman-medium-light-skin-tone-light-skin-tone:' => '👩🏼‍❤️‍👩🏻',
    ':couple-with-heart-woman-woman-medium-light-skin-tone-medium-dark-skin-tone:' => '👩🏼‍❤️‍👩🏾',
    ':couple-with-heart-woman-woman-medium-light-skin-tone-medium-skin-tone:' => '👩🏼‍❤️‍👩🏽',
    ':couple-with-heart-woman-woman-medium-skin-tone:' => '👩🏽‍❤️‍👩🏽',
    ':couple-with-heart-woman-woman-medium-skin-tone-dark-skin-tone:' => '👩🏽‍❤️‍👩🏿',
    ':couple-with-heart-woman-woman-medium-skin-tone-light-skin-tone:' => '👩🏽‍❤️‍👩🏻',
    ':couple-with-heart-woman-woman-medium-skin-tone-medium-dark-skin-tone:' => '👩🏽‍❤️‍👩🏾',
    ':couple-with-heart-woman-woman-medium-skin-tone-medium-light-skin-tone:' => '👩🏽‍❤️‍👩🏼',
    ':kiss-mm:' => '👨‍❤️‍💋‍👨',
    ':kiss-woman-man:' => '👩‍❤️‍💋‍👨',
    ':kiss-ww:' => '👩‍❤️‍💋‍👩',
    ':man-kneeling-facing-right-dark-skin-tone:' => '🧎🏿‍♂️‍➡️',
    ':man-kneeling-facing-right-light-skin-tone:' => '🧎🏻‍♂️‍➡️',
    ':man-kneeling-facing-right-medium-dark-skin-tone:' => '🧎🏾‍♂️‍➡️',
    ':man-kneeling-facing-right-medium-light-skin-tone:' => '🧎🏼‍♂️‍➡️',
    ':man-kneeling-facing-right-medium-skin-tone:' => '🧎🏽‍♂️‍➡️',
    ':man-running-facing-right-dark-skin-tone:' => '🏃🏿‍♂️‍➡️',
    ':man-running-facing-right-light-skin-tone:' => '🏃🏻‍♂️‍➡️',
    ':man-running-facing-right-medium-dark-skin-tone:' => '🏃🏾‍♂️‍➡️',
    ':man-running-facing-right-medium-light-skin-tone:' => '🏃🏼‍♂️‍➡️',
    ':man-running-facing-right-medium-skin-tone:' => '🏃🏽‍♂️‍➡️',
    ':man-walking-facing-right-dark-skin-tone:' => '🚶🏿‍♂️‍➡️',
    ':man-walking-facing-right-light-skin-tone:' => '🚶🏻‍♂️‍➡️',
    ':man-walking-facing-right-medium-dark-skin-tone:' => '🚶🏾‍♂️‍➡️',
    ':man-walking-facing-right-medium-light-skin-tone:' => '🚶🏼‍♂️‍➡️',
    ':man-walking-facing-right-medium-skin-tone:' => '🚶🏽‍♂️‍➡️',
    ':woman-kneeling-facing-right-dark-skin-tone:' => '🧎🏿‍♀️‍➡️',
    ':woman-kneeling-facing-right-light-skin-tone:' => '🧎🏻‍♀️‍➡️',
    ':woman-kneeling-facing-right-medium-dark-skin-tone:' => '🧎🏾‍♀️‍➡️',
    ':woman-kneeling-facing-right-medium-light-skin-tone:' => '🧎🏼‍♀️‍➡️',
    ':woman-kneeling-facing-right-medium-skin-tone:' => '🧎🏽‍♀️‍➡️',
    ':woman-running-facing-right-dark-skin-tone:' => '🏃🏿‍♀️‍➡️',
    ':woman-running-facing-right-light-skin-tone:' => '🏃🏻‍♀️‍➡️',
    ':woman-running-facing-right-medium-dark-skin-tone:' => '🏃🏾‍♀️‍➡️',
    ':woman-running-facing-right-medium-light-skin-tone:' => '🏃🏼‍♀️‍➡️',
    ':woman-running-facing-right-medium-skin-tone:' => '🏃🏽‍♀️‍➡️',
    ':woman-walking-facing-right-dark-skin-tone:' => '🚶🏿‍♀️‍➡️',
    ':woman-walking-facing-right-light-skin-tone:' => '🚶🏻‍♀️‍➡️',
    ':woman-walking-facing-right-medium-dark-skin-tone:' => '🚶🏾‍♀️‍➡️',
    ':woman-walking-facing-right-medium-light-skin-tone:' => '🚶🏼‍♀️‍➡️',
    ':woman-walking-facing-right-medium-skin-tone:' => '🚶🏽‍♀️‍➡️',
    ':kiss-man-man-dark-skin-tone:' => '👨🏿‍❤️‍💋‍👨🏿',
    ':kiss-man-man-dark-skin-tone-light-skin-tone:' => '👨🏿‍❤️‍💋‍👨🏻',
    ':kiss-man-man-dark-skin-tone-medium-dark-skin-tone:' => '👨🏿‍❤️‍💋‍👨🏾',
    ':kiss-man-man-dark-skin-tone-medium-light-skin-tone:' => '👨🏿‍❤️‍💋‍👨🏼',
    ':kiss-man-man-dark-skin-tone-medium-skin-tone:' => '👨🏿‍❤️‍💋‍👨🏽',
    ':kiss-man-man-light-skin-tone:' => '👨🏻‍❤️‍💋‍👨🏻',
    ':kiss-man-man-light-skin-tone-dark-skin-tone:' => '👨🏻‍❤️‍💋‍👨🏿',
    ':kiss-man-man-light-skin-tone-medium-dark-skin-tone:' => '👨🏻‍❤️‍💋‍👨🏾',
    ':kiss-man-man-light-skin-tone-medium-light-skin-tone:' => '👨🏻‍❤️‍💋‍👨🏼',
    ':kiss-man-man-light-skin-tone-medium-skin-tone:' => '👨🏻‍❤️‍💋‍👨🏽',
    ':kiss-man-man-medium-dark-skin-tone:' => '👨🏾‍❤️‍💋‍👨🏾',
    ':kiss-man-man-medium-dark-skin-tone-dark-skin-tone:' => '👨🏾‍❤️‍💋‍👨🏿',
    ':kiss-man-man-medium-dark-skin-tone-light-skin-tone:' => '👨🏾‍❤️‍💋‍👨🏻',
    ':kiss-man-man-medium-dark-skin-tone-medium-light-skin-tone:' => '👨🏾‍❤️‍💋‍👨🏼',
    ':kiss-man-man-medium-dark-skin-tone-medium-skin-tone:' => '👨🏾‍❤️‍💋‍👨🏽',
    ':kiss-man-man-medium-light-skin-tone:' => '👨🏼‍❤️‍💋‍👨🏼',
    ':kiss-man-man-medium-light-skin-tone-dark-skin-tone:' => '👨🏼‍❤️‍💋‍👨🏿',
    ':kiss-man-man-medium-light-skin-tone-light-skin-tone:' => '👨🏼‍❤️‍💋‍👨🏻',
    ':kiss-man-man-medium-light-skin-tone-medium-dark-skin-tone:' => '👨🏼‍❤️‍💋‍👨🏾',
    ':kiss-man-man-medium-light-skin-tone-medium-skin-tone:' => '👨🏼‍❤️‍💋‍👨🏽',
    ':kiss-man-man-medium-skin-tone:' => '👨🏽‍❤️‍💋‍👨🏽',
    ':kiss-man-man-medium-skin-tone-dark-skin-tone:' => '👨🏽‍❤️‍💋‍👨🏿',
    ':kiss-man-man-medium-skin-tone-light-skin-tone:' => '👨🏽‍❤️‍💋‍👨🏻',
    ':kiss-man-man-medium-skin-tone-medium-dark-skin-tone:' => '👨🏽‍❤️‍💋‍👨🏾',
    ':kiss-man-man-medium-skin-tone-medium-light-skin-tone:' => '👨🏽‍❤️‍💋‍👨🏼',
    ':kiss-person-person-dark-skin-tone-light-skin-tone:' => '🧑🏿‍❤️‍💋‍🧑🏻',
    ':kiss-person-person-dark-skin-tone-medium-dark-skin-tone:' => '🧑🏿‍❤️‍💋‍🧑🏾',
    ':kiss-person-person-dark-skin-tone-medium-light-skin-tone:' => '🧑🏿‍❤️‍💋‍🧑🏼',
    ':kiss-person-person-dark-skin-tone-medium-skin-tone:' => '🧑🏿‍❤️‍💋‍🧑🏽',
    ':kiss-person-person-light-skin-tone-dark-skin-tone:' => '🧑🏻‍❤️‍💋‍🧑🏿',
    ':kiss-person-person-light-skin-tone-medium-dark-skin-tone:' => '🧑🏻‍❤️‍💋‍🧑🏾',
    ':kiss-person-person-light-skin-tone-medium-light-skin-tone:' => '🧑🏻‍❤️‍💋‍🧑🏼',
    ':kiss-person-person-light-skin-tone-medium-skin-tone:' => '🧑🏻‍❤️‍💋‍🧑🏽',
    ':kiss-person-person-medium-dark-skin-tone-dark-skin-tone:' => '🧑🏾‍❤️‍💋‍🧑🏿',
    ':kiss-person-person-medium-dark-skin-tone-light-skin-tone:' => '🧑🏾‍❤️‍💋‍🧑🏻',
    ':kiss-person-person-medium-dark-skin-tone-medium-light-skin-tone:' => '🧑🏾‍❤️‍💋‍🧑🏼',
    ':kiss-person-person-medium-dark-skin-tone-medium-skin-tone:' => '🧑🏾‍❤️‍💋‍🧑🏽',
    ':kiss-person-person-medium-light-skin-tone-dark-skin-tone:' => '🧑🏼‍❤️‍💋‍🧑🏿',
    ':kiss-person-person-medium-light-skin-tone-light-skin-tone:' => '🧑🏼‍❤️‍💋‍🧑🏻',
    ':kiss-person-person-medium-light-skin-tone-medium-dark-skin-tone:' => '🧑🏼‍❤️‍💋‍🧑🏾',
    ':kiss-person-person-medium-light-skin-tone-medium-skin-tone:' => '🧑🏼‍❤️‍💋‍🧑🏽',
    ':kiss-person-person-medium-skin-tone-dark-skin-tone:' => '🧑🏽‍❤️‍💋‍🧑🏿',
    ':kiss-person-person-medium-skin-tone-light-skin-tone:' => '🧑🏽‍❤️‍💋‍🧑🏻',
    ':kiss-person-person-medium-skin-tone-medium-dark-skin-tone:' => '🧑🏽‍❤️‍💋‍🧑🏾',
    ':kiss-person-person-medium-skin-tone-medium-light-skin-tone:' => '🧑🏽‍❤️‍💋‍🧑🏼',
    ':kiss-woman-man-dark-skin-tone:' => '👩🏿‍❤️‍💋‍👨🏿',
    ':kiss-woman-man-dark-skin-tone-light-skin-tone:' => '👩🏿‍❤️‍💋‍👨🏻',
    ':kiss-woman-man-dark-skin-tone-medium-dark-skin-tone:' => '👩🏿‍❤️‍💋‍👨🏾',
    ':kiss-woman-man-dark-skin-tone-medium-light-skin-tone:' => '👩🏿‍❤️‍💋‍👨🏼',
    ':kiss-woman-man-dark-skin-tone-medium-skin-tone:' => '👩🏿‍❤️‍💋‍👨🏽',
    ':kiss-woman-man-light-skin-tone:' => '👩🏻‍❤️‍💋‍👨🏻',
    ':kiss-woman-man-light-skin-tone-dark-skin-tone:' => '👩🏻‍❤️‍💋‍👨🏿',
    ':kiss-woman-man-light-skin-tone-medium-dark-skin-tone:' => '👩🏻‍❤️‍💋‍👨🏾',
    ':kiss-woman-man-light-skin-tone-medium-light-skin-tone:' => '👩🏻‍❤️‍💋‍👨🏼',
    ':kiss-woman-man-light-skin-tone-medium-skin-tone:' => '👩🏻‍❤️‍💋‍👨🏽',
    ':kiss-woman-man-medium-dark-skin-tone:' => '👩🏾‍❤️‍💋‍👨🏾',
    ':kiss-woman-man-medium-dark-skin-tone-dark-skin-tone:' => '👩🏾‍❤️‍💋‍👨🏿',
    ':kiss-woman-man-medium-dark-skin-tone-light-skin-tone:' => '👩🏾‍❤️‍💋‍👨🏻',
    ':kiss-woman-man-medium-dark-skin-tone-medium-light-skin-tone:' => '👩🏾‍❤️‍💋‍👨🏼',
    ':kiss-woman-man-medium-dark-skin-tone-medium-skin-tone:' => '👩🏾‍❤️‍💋‍👨🏽',
    ':kiss-woman-man-medium-light-skin-tone:' => '👩🏼‍❤️‍💋‍👨🏼',
    ':kiss-woman-man-medium-light-skin-tone-dark-skin-tone:' => '👩🏼‍❤️‍💋‍👨🏿',
    ':kiss-woman-man-medium-light-skin-tone-light-skin-tone:' => '👩🏼‍❤️‍💋‍👨🏻',
    ':kiss-woman-man-medium-light-skin-tone-medium-dark-skin-tone:' => '👩🏼‍❤️‍💋‍👨🏾',
    ':kiss-woman-man-medium-light-skin-tone-medium-skin-tone:' => '👩🏼‍❤️‍💋‍👨🏽',
    ':kiss-woman-man-medium-skin-tone:' => '👩🏽‍❤️‍💋‍👨🏽',
    ':kiss-woman-man-medium-skin-tone-dark-skin-tone:' => '👩🏽‍❤️‍💋‍👨🏿',
    ':kiss-woman-man-medium-skin-tone-light-skin-tone:' => '👩🏽‍❤️‍💋‍👨🏻',
    ':kiss-woman-man-medium-skin-tone-medium-dark-skin-tone:' => '👩🏽‍❤️‍💋‍👨🏾',
    ':kiss-woman-man-medium-skin-tone-medium-light-skin-tone:' => '👩🏽‍❤️‍💋‍👨🏼',
    ':kiss-woman-woman-dark-skin-tone:' => '👩🏿‍❤️‍💋‍👩🏿',
    ':kiss-woman-woman-dark-skin-tone-light-skin-tone:' => '👩🏿‍❤️‍💋‍👩🏻',
    ':kiss-woman-woman-dark-skin-tone-medium-dark-skin-tone:' => '👩🏿‍❤️‍💋‍👩🏾',
    ':kiss-woman-woman-dark-skin-tone-medium-light-skin-tone:' => '👩🏿‍❤️‍💋‍👩🏼',
    ':kiss-woman-woman-dark-skin-tone-medium-skin-tone:' => '👩🏿‍❤️‍💋‍👩🏽',
    ':kiss-woman-woman-light-skin-tone:' => '👩🏻‍❤️‍💋‍👩🏻',
    ':kiss-woman-woman-light-skin-tone-dark-skin-tone:' => '👩🏻‍❤️‍💋‍👩🏿',
    ':kiss-woman-woman-light-skin-tone-medium-dark-skin-tone:' => '👩🏻‍❤️‍💋‍👩🏾',
    ':kiss-woman-woman-light-skin-tone-medium-light-skin-tone:' => '👩🏻‍❤️‍💋‍👩🏼',
    ':kiss-woman-woman-light-skin-tone-medium-skin-tone:' => '👩🏻‍❤️‍💋‍👩🏽',
    ':kiss-woman-woman-medium-dark-skin-tone:' => '👩🏾‍❤️‍💋‍👩🏾',
    ':kiss-woman-woman-medium-dark-skin-tone-dark-skin-tone:' => '👩🏾‍❤️‍💋‍👩🏿',
    ':kiss-woman-woman-medium-dark-skin-tone-light-skin-tone:' => '👩🏾‍❤️‍💋‍👩🏻',
    ':kiss-woman-woman-medium-dark-skin-tone-medium-light-skin-tone:' => '👩🏾‍❤️‍💋‍👩🏼',
    ':kiss-woman-woman-medium-dark-skin-tone-medium-skin-tone:' => '👩🏾‍❤️‍💋‍👩🏽',
    ':kiss-woman-woman-medium-light-skin-tone:' => '👩🏼‍❤️‍💋‍👩🏼',
    ':kiss-woman-woman-medium-light-skin-tone-dark-skin-tone:' => '👩🏼‍❤️‍💋‍👩🏿',
    ':kiss-woman-woman-medium-light-skin-tone-light-skin-tone:' => '👩🏼‍❤️‍💋‍👩🏻',
    ':kiss-woman-woman-medium-light-skin-tone-medium-dark-skin-tone:' => '👩🏼‍❤️‍💋‍👩🏾',
    ':kiss-woman-woman-medium-light-skin-tone-medium-skin-tone:' => '👩🏼‍❤️‍💋‍👩🏽',
    ':kiss-woman-woman-medium-skin-tone:' => '👩🏽‍❤️‍💋‍👩🏽',
    ':kiss-woman-woman-medium-skin-tone-dark-skin-tone:' => '👩🏽‍❤️‍💋‍👩🏿',
    ':kiss-woman-woman-medium-skin-tone-light-skin-tone:' => '👩🏽‍❤️‍💋‍👩🏻',
    ':kiss-woman-woman-medium-skin-tone-medium-dark-skin-tone:' => '👩🏽‍❤️‍💋‍👩🏾',
    ':kiss-woman-woman-medium-skin-tone-medium-light-skin-tone:' => '👩🏽‍❤️‍💋‍👩🏼',
];
